/**
 * Source code
 * https://css-tricks.com/creating-a-clock-with-the-new-css-sin-and-cos-trigonometry-functions/
 */
import { ChangeDetectionStrategy, ChangeDetectorRef, Component, ElementRef, HostBinding, Inject, OnInit, forwardRef } from '@angular/core';
import { IFieldInfo, IStringTextBoxControl, RangeCheckResult, ReferenceComponent, ServiceProviderService, StringFieldConverterService } from '@blaise/core';
import { DateTime } from 'luxon';

@Component({
    selector: 'app-clock',
    templateUrl: './clock.component.html',
    styleUrls: ['./clock.component.scss'],
    changeDetection: ChangeDetectionStrategy.OnPush
})
export class ClockComponent extends ReferenceComponent<IStringTextBoxControl> implements OnInit {
    // what are hostbindings??
    @HostBinding('style.--_dm') public minutes: string;
    @HostBinding('style.--_dh') public hours: string;

    /**
     * properties
     */
    public selectedTime = '';
    public convertedTime = '';

    /**
     * boolean flag if a time is selected
     */
    get timeSelected(): boolean {
        return !!this.convertedTime;
    }

    /**
     * flag wether the value is stored in the FieldInfo
     */
    get valueStored(): boolean {
        return this.timeSelected && this.convertedTime === this.fieldInfo.DataValue.ValueAsString;
    }

    /**
     * constructor of the component is used to inject dependencies
     */
    public constructor(
        @Inject(forwardRef(() => ServiceProviderService)) protected override sp: ServiceProviderService,
        protected override el: ElementRef,
        protected override cd: ChangeDetectorRef,
        protected converter: StringFieldConverterService
    ) {
        super(sp, el, cd);
    }

    /**
     * On Init lifecycle hook of Angular
     */
    ngOnInit() {
        super.ngOnInit();

        const time = DateTime.now();
        const hour = -3600 * (time.hour % 12);
        const minutes = -60 * time.minute;

        this.minutes = `${minutes}s`;
        this.hours = `${hour + minutes}s`;
    }

    /**
     * set the value of the clock as the selected time
     */
    handleClick = () => {
        console.info('A custom log message after clicking on a element');
        this.selectedTime = DateTime.now().toISO();
        this.convertedTime = this.selectedTime;
    };

    /**
     * event when clicked on the OK button
     */
    handleClickOk = () => {
        console.info('A custom log message after executing a function');
        // get the value of the field reference
        const fieldInfo: Optional<IFieldInfo> = this.fieldInfo;
        if (fieldInfo && this.convertedTime) {
            // configure answer
            this.converter.convertFromString(this.convertedTime, fieldInfo);
            // validate answer
            const validationResult = this.converter.isValid(this.convertedTime, fieldInfo.ValueType);
            if (validationResult === RangeCheckResult.Ok) {
                this.converter.removeRangeCheckErrors(fieldInfo);
                // notify observers
                this.fieldInfo = fieldInfo;
            }
            // execute on value changed actions
            this.executeActions(this.dataObject.OnValueChanged);
            // if needed auto-enter
            this.applyAutoEnter(this.dataObject.AutoEnter, this.converter, fieldInfo);
        }
    };

    /**
     * event when clicked on the clear button
     */
    handleClickClear = () => {
        this.selectedTime = '';
        this.converter.setEmptyAnswer(this.fieldInfo);
    };

    /**
     * event fired when a converted time event is emitted
     * @param converted
     */
    handleConvertedTime = (converted: DateTime) => {
        this.convertedTime = converted.toISO();
    };
}
