declare global {
    type Arr<T> = ReadonlyArray<T> | Array<T>;
    /**
     * Array constructor extension.
     */
    interface ArrayConstructor {
        /**
         * Array.isNullOrEmpty returns true if the given value is undefined, null or an array with a length of zero.
         * @param {Unknown<Array<any>>} arr The optional nullable array to validate.
         * @returns {boolean} true if the given array is defined, not null and has minimum one element defined on it.
         * ```
         * const foo: Unknown<Array<string>> = service.getListOfFoo();
         * const bar: boolean = Array.isNullOrEmpty(foo); // true if foo is undefined, null or has a length of 0, otherwise false
         * ```
         */
        isNullOrEmpty<T>(arr: Unknown<Arr<T>>): boolean;
        /**
         * Array.isPopulated performs an array length check and type check cast.
         * This alleviates the need for using non-null assertion operators or optional chaining after a null check.
         * @param {Unknown<Array<any>>} arr The optional nullable array to validate and type cast
         * @returns {boolean} true if the given array is not null or undefined and has a length of at least one AND performs a type cast on the object.
         * ```
         * const foo: Unknown<Array<string>> = service.getListOfFoo();
         * if (Array.isPopulated(foo)) {  // true if foo is defined, not null or has a length of at least 1, otherwise false
         *     const foolen: number = foo.length(); // >= 1
         * }
         * ```
         */
        isPopulated<T>(arr: Unknown<Arr<T>>): arr is Arr<T>;
        /**
         * Returns an empty array
         */
        readonly EMPTY: [];
    }
    /**
     * Array type extension
     */
    interface Array<T> {
        /**
         * Array.isEmpty performs an array length check
         * @returns {boolean} true if the array on which the action is performed has a length of at least 1
         * ```
         * let foo: string[] = [];
         * let bar: boolean = foo.isEmpty(); //true
         * ```
         */
        isEmpty(this: Arr<T>): boolean;
        /**
         * Array.containsAny validates if this array has any elements and optionally if the value of these elements match any of those in the given values array.
         * @param {Unknown<Array<any>>} values T[] optional values to search for
         * @returns {boolean} true if the array on which the action is performed contains any (of the optionally given) values.
         * ```
         * let foo: string[] = ['apple', 'banana', 'orange', 'pear', 'peach'];
         * bar = foo.includesAny(); // true
         * bar = foo.includesAny(['pineapple', 'banana']); // true
         * ```
         */
        includesAny(this: Arr<T>, values: Unknown<Arr<T>>): boolean;
    }
}
export {};
