import { IAriaOptions } from '../../../typedefinitions/models/IAriaOptions';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
/**
 * Accessibility class
 * [ARIA](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA) for more information.
 * [ARIA cheat sheet](http://karlgroves-sandbox.com/CheatSheets/ARIA-Cheatsheet.html)
 */
export declare class AriaOptions implements IAriaOptions {
    private control;
    private field;
    /**
     * Indicates whether the page is optimized for accessibility and uses a stylesheet-less version
     */
    UseOptimizedNoStylesheetVersion: boolean;
    /**
     * Identifies the currently active descendant of a composite widget. Used to deal with multiple focusable children, i.e. in a tree menu
     */
    activeDescendant: string;
    /**
     * Indicates whether assistive technologies will present all, or only parts of, the changed region based on the change notifications defined by the aria-relevant attribute.
     * See related aria-relevant.
     */
    atomic: boolean;
    /**
     * Indicates whether user input completion suggestions are provided.
     */
    autoComplete: string;
    /**
     * Indicates whether an element, and its subtree, are currently being updated
     */
    busy: boolean;
    /**
     * Indicates the current "checked" state of checkboxes, radio buttons, and other widgets. See related aria-pressed and aria-selected.
     */
    checked: boolean;
    /**
     * Identifies the element (or elements) that describes the object. See related aria-labelledby.
     */
    describedBy: string;
    /**
     * Indicates that the element is perceivable but disabled, so it is not editable or otherwise operable. See related aria-hidden and aria-readonly.
     */
    disabled: Optional<boolean>;
    /**
     * Indicates whether the element, or another grouping element it controls, is currently expanded or collapsed.
     */
    expanded: boolean;
    /**
     * Indicates that the element and all of its descendants are not visible or perceivable to any user as implemented by the author. See related aria-disabled.
     */
    hidden: boolean;
    /**
     * Indicates the entered value does not conform to the format expected by the application.
     */
    invalid: boolean;
    /**
     * Defines a string value that labels the current element.
     */
    label: string;
    /**
     * Defines a string value that labels the current element.
     */
    labelledBy: string;
    /**
     * Defines a string value that labels the current element.
     */
    labelFor?: string;
    /**
     * Indicates that an element will be updated, and describes the types of updates the user agents, assistive technologies, and user can expect from the live region.
     */
    live: string;
    /**
     * Identifies an element (or elements) in order to define a visual, functional, or contextual parent/child relationship
     * between DOM elements where the DOM hierarchy cannot be used to represent the relationship. See related aria-controls.
     */
    owns: string;
    /**
     * Indicates that the element is not editable, but is otherwise operable. See related aria-disabled.
     */
    AriaReadOnly: boolean;
    /**
     * Indicates what user agent change notifications (additions, removals, etc.) assistive technologies will receive within a live region. See related aria-atomic.
     */
    relevant: string;
    /**
     * Indicates that user input is required on the element before a form may be submitted.
     */
    required: boolean;
    /**
     * Indicates the current "selected" state of various widgets. See related aria-checked and aria-pressed.
     */
    selected: boolean;
    /**
     * Element role property based on the control type and the changeability of its visibility
     */
    role: string;
    /**
     * Aria class constructor
     */
    constructor();
    /**
     * Sets the value of the private field "control" and updates aria properties. Used in the base component on handle control update.
     * @param control
     */
    setControl(control: IBaseControl): void;
    /**
     * Sets the value of the private field "field" and updates aria properties. Used in the reference component on subscribe to reference.
     * @param field
     */
    setField(field: IFieldInfo): void;
    /**
     * Cleanup elements generated for ARIA
     */
    destroy(): void;
    /**
     * Updates the aria class properties
     */
    update(): void;
    private setAriaAutocomplete;
    private setAriaRequired;
    /**
     * If the control has a watermark, sets the aria described by based on the watermark
     */
    private setAriaDescribedBy;
    /**
     * Append descriptive element to the dom
     */
    private createDescribedByElement;
    /**
     * Remove descriptive element from the dom
     */
    private removeDescribedByElement;
    /**
     * If the control is checkable,
     * sets the aria checked based on the comparison result of the control's reference code with the values from referenced field's data value's value as string.
     */
    private setAriaChecked;
    /**
     * Sets the aria label based on the control's screen reader text value.
     */
    private setAriaLabel;
    /**
     * Sets the aria label based on the control's screen reader text value.
     */
    private setAriaLabelFor;
    /**
     * Sets the aria labelled-by based on the control's labelledBy property.
     */
    private setAriaLabelledBy;
    /**
     * Sets the aria disabled based on the control's enable state
     */
    private setAriaDisabled;
    /**
     * Sets the aria hidden based on the control's visibility
     */
    private setAriaHidden;
    /**
     * Set the aria-invalid attribute based on the errors
     */
    private setAriaInvalid;
    /**
     * Sets the aria live based on the control type
     */
    private setAriaLive;
    /**
     * Sets the role based on the control type
     */
    private setRole;
    private isCheckable;
    private isChecked;
    private isErrorControl;
    private isTextControl;
    private hasWaterMark;
}
