import { ActionsEventHandler } from '../../../actions/actions-event-handler';
import { IActionsEventHandler } from '../../../../../typedefinitions/models/IActionsEventHandler';
import { IAudioElement } from '../../../../../typedefinitions/models/richText/elements/IAudioElement';
import { IButtonElement } from '../../../../../typedefinitions/models/richText/elements/IButtonElement';
import { IBrush } from '../../../../../typedefinitions/models/IBrush';
import { IClickActionsElement } from '../../../../../typedefinitions/models/richText/elements/IClickActionsElement';
import { IColor } from '../../../../../typedefinitions/models/IColor';
import { IEllipseElement } from '../../../../../typedefinitions/models/richText/elements/IEllipseElement';
import { IHyperlinkElement } from '../../../../../typedefinitions/models/richText/elements/IHyperlinkElement';
import { IImageElement } from '../../../../../typedefinitions/models/richText/elements/IImageElement';
import { ILabelElement } from '../../../../../typedefinitions/models/richText/elements/ILabelElement';
import { ILineElement } from '../../../../../typedefinitions/models/richText/elements/ILineElement';
import { IRectangleElement } from '../../../../../typedefinitions/models/richText/elements/IRectangleElement';
import { IRunElement } from '../../../../../typedefinitions/models/richText/elements/IRunElement';
import { IShapeElement } from '../../../../../typedefinitions/models/richText/elements/IShapeElement';
import { ITextBoxElement } from '../../../../../typedefinitions/models/richText/elements/ITextBoxElement';
import { ITextElement } from '../../../../../typedefinitions/models/richText/elements/ITextElement';
import { ITimerElement } from '../../../../../typedefinitions/models/richText/elements/ITimerElement';
import { IVideoElement } from '../../../../../typedefinitions/models/richText/elements/IVideoElement';
import { BorderStyle } from '../../../../../typedefinitions/enums/BorderStyle';
import { ElementKind } from '../../../../../typedefinitions/enums/ElementKind';
import { Visibility as VisibilityValue } from '../../../../../typedefinitions/enums/Visibility';
/**
 * Abstract run element base class
 */
export declare abstract class RunElement implements IRunElement {
    /**
     * Run element type
     */
    Kind: ElementKind;
    /**
     * Element name
     */
    Name: string;
    /**
     * Element's label element reference
     */
    LabelledBy: string;
    /**
     * Accessibility role
     */
    AccessibilityRole: string;
    /**
     * Identifier string
     */
    ID: string;
    /**
     * Element background settings
     */
    Background: Optional<IBrush>;
    /**
     * Enabled/Disabled flag indicating whether the element can be interacted with
     */
    Enabled: boolean;
    /**
     * Screen reader text
     */
    ScreenReaderText: Optional<string>;
    /**
     * Flag indicating whether keyboard focus should be shown or not
     */
    ShowKeyboardFocus: boolean;
    /**
     * Value used to determine the elements place in the page's tabbing order
     */
    TabIndex: number;
    /**
     * Optional Text displayed near the element when hovering over the element
     */
    TooltipText: Optional<string>;
    /**
     * Visibility setting
     */
    Visibility: VisibilityValue;
    /**
     * The outline-style property specifies the style of the outline
     */
    OutlineStyle: BorderStyle;
    /**
     * The outline-width property specifies the width of the outline
     */
    OutlineWidth: number;
    /**
     * The outline-color property is used to set the color of the outline
     */
    OutlineColor: IColor;
    /**
     * The outline-offset property adds space between an outline and the edge/border of an element.
     * The space between an element and its outline is transparent.
     */
    OutlineOffset: number;
    /**
     * Actions to execute on an element focus event
     */
    OnGotFocus?: IActionsEventHandler | undefined;
    /**
     * Actions to execute on an element blur event
     */
    OnLostFocus?: IActionsEventHandler | undefined;
    /**
     * On mouse down event handler
     */
    OnMouseDown?: ActionsEventHandler | undefined;
    /**
     * On mouse up event handler
     */
    OnMouseUp?: ActionsEventHandler | undefined;
    /**
     * On mouse enter event handler
     */
    OnMouseEnter?: ActionsEventHandler | undefined;
    /**
     * On mouse leave event handler
     */
    OnMouseLeave?: ActionsEventHandler | undefined;
    /**
     * Run element class constructor
     * @param Kind Run Element kind
     * @param ID Run element identifier string
     * @param Name Run element name
     * @param Enabled Flag indicating if the user can interact with the run element
     * @param LabelledBy Run element label reference
     * @param AccessibilityRole Accessibility role for the run element
     * @param ShowKeyboardFocus Flag indicating whether keyboard focus should be shown or not
     * @param TabIndex tab index for the run element
     * @param Visibility invisibility setting (Visible, Hidden or Collapsed)
     * @param OutlineStyle The outline-style property specifies the style of the outline
     * @param OutlineWidth The outline-width property specifies the width of the outline
     * @param OutlineColor The outline-color property is used to set the color of the outline
     * @param OutlineOffset The outline-offset property adds space between an outline and the edge/border of an element
     * @param Background Background settings for the run element
     * @param ScreenReaderText Screen reader text
     * @param TooltipText Optional tooltip text
     * @param OnGotFocus Optional, on focus received event handler
     * @param OnLostFocus Optional, on focus lost event handler
     * @param OnMouseDown Optional, on mouse down event handler
     * @param OnMouseUp Optional, on mouse up event handler
     * @param OnMouseEnter Optional, on mouse enter event handler
     * @param OnMouseLeave Optional, on mouse leave event handler
     * @protected
     */
    protected constructor(
    /**
     * Run element type
     */
    Kind: ElementKind, 
    /**
     * Element name
     */
    Name: string, 
    /**
     * Element's label element reference
     */
    LabelledBy: string, 
    /**
     * Accessibility role
     */
    AccessibilityRole: string, 
    /**
     * Identifier string
     */
    ID: string, 
    /**
     * Element background settings
     */
    Background: Optional<IBrush>, 
    /**
     * Enabled/Disabled flag indicating whether the element can be interacted with
     */
    Enabled: boolean, 
    /**
     * Screen reader text
     */
    ScreenReaderText: Optional<string>, 
    /**
     * Flag indicating whether keyboard focus should be shown or not
     */
    ShowKeyboardFocus: boolean, 
    /**
     * Value used to determine the elements place in the page's tabbing order
     */
    TabIndex: number, 
    /**
     * Optional Text displayed near the element when hovering over the element
     */
    TooltipText: Optional<string>, 
    /**
     * Visibility setting
     */
    Visibility: VisibilityValue, 
    /**
     * The outline-style property specifies the style of the outline
     */
    OutlineStyle: BorderStyle, 
    /**
     * The outline-width property specifies the width of the outline
     */
    OutlineWidth: number, 
    /**
     * The outline-color property is used to set the color of the outline
     */
    OutlineColor: IColor, 
    /**
     * The outline-offset property adds space between an outline and the edge/border of an element.
     * The space between an element and its outline is transparent.
     */
    OutlineOffset: number, 
    /**
     * Actions to execute on an element focus event
     */
    OnGotFocus?: IActionsEventHandler | undefined, 
    /**
     * Actions to execute on an element blur event
     */
    OnLostFocus?: IActionsEventHandler | undefined, 
    /**
     * On mouse down event handler
     */
    OnMouseDown?: ActionsEventHandler | undefined, 
    /**
     * On mouse up event handler
     */
    OnMouseUp?: ActionsEventHandler | undefined, 
    /**
     * On mouse enter event handler
     */
    OnMouseEnter?: ActionsEventHandler | undefined, 
    /**
     * On mouse leave event handler
     */
    OnMouseLeave?: ActionsEventHandler | undefined);
    /**
     * Checks if the base run element is an audio element
     * @param runElement
     */
    static isAudioElement(runElement: IRunElement): runElement is IAudioElement;
    /**
     * Checks if the base run element is a button element
     * @param runElement
     */
    static isButtonElement(runElement: IRunElement): runElement is IButtonElement;
    /**
     * Checks if the base run element is an ellipse element
     * @param runElement
     */
    static isEllipseElement(runElement: IRunElement): runElement is IEllipseElement;
    /**
     * Checks if the base run element is a hyperlink element
     * @param runElement
     */
    static isHyperlinkElement(runElement: IRunElement): runElement is IHyperlinkElement;
    /**
     * Checks if the base run element is an image element
     * @param runElement
     */
    static isImageElement(runElement: IRunElement): runElement is IImageElement;
    /**
     * Checks if the base run element is a label element
     * @param runElement
     */
    static isLabelElement(runElement: IRunElement): runElement is ILabelElement;
    /**
     * Checks if the base run element is a line element
     * @param runElement
     */
    static isLineElement(runElement: IRunElement): runElement is ILineElement;
    /**
     * Checks if the base run element is a rectangle element
     * @param runElement
     */
    static isRectangleElement(runElement: IRunElement): runElement is IRectangleElement;
    /**
     * Checks if the base run element is a base shape element
     * @param runElement
     */
    static isShapeElement(runElement: IRunElement): runElement is IShapeElement;
    /**
     * Checks if the base run element is a textbox element
     * @param runElement
     */
    static isTextBoxElement(runElement: IRunElement): runElement is ITextBoxElement;
    /**
     * Checks if the base run element is a text element
     * @param runElement
     */
    static isTextElement(runElement: IRunElement): runElement is ITextElement;
    /**
     * Checks if the base run element is a timer element
     * @param runElement
     */
    static isTimerElement(runElement: IRunElement): runElement is ITimerElement;
    /**
     * Checks if the base run element is a video element
     * @param runElement
     */
    static isVideoElement(runElement: IRunElement): runElement is IVideoElement;
    /**
     * Checks if the base run element is of a type that has a string text property
     * @param runElement
     */
    static hasTextString(runElement: IRunElement): runElement is IHyperlinkElement | ILabelElement | ITextElement;
    /**
     * Checks if the base run element is a click actions element
     * @param runElement
     */
    static isClickActionsElement(runElement: IRunElement): runElement is IClickActionsElement;
    /**
     * Converts the run element to a html element string
     * @returns string element outer html string
     */
    abstract toHTML(): string;
    /**
     * Converts the run element to plain text
     * @returns string element text
     */
    abstract toPlainText(): string;
}
