import { OnInit, OnDestroy, AfterViewInit, ElementRef, ChangeDetectorRef, Type } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { AriaOptions } from '../../classes/aria/aria-options';
import { Watermark } from '../../classes/controls/properties/watermark';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { CSSStyleObject } from '../../../typedefinitions/models/style/CSSStyleObject';
import { IActionsEventHandler } from '../../../typedefinitions/models/IActionsEventHandler';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import { IBaseComponentViewModel2 } from '../../../typedefinitions/models/view/IBaseViewModel';
import { IControlContainerControl } from '../../../typedefinitions/models/controls/IControlContainerControl';
import { IControlInfo } from '../../../typedefinitions/models/IControlInfo';
import { IControlSize } from '../../services/sizetree/IControlSize';
import { IDimension } from '../../../typedefinitions/models/IDimension';
import { IHasWatermark } from '../../../typedefinitions/models/controls/properties/IHasWatermark';
import { IHasFont, IHasFontName, IHasFontObject } from '../../../typedefinitions/models/controls/properties/IHasFont';
import { IHasKeyboardFocus } from '../../../typedefinitions/models/controls/properties/IHasKeyboardFocus';
import { IHasTabIndex } from '../../../typedefinitions/models/controls/properties/IHasTabIndex';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { IUnit } from '../../../typedefinitions/models/IUnit';
import { ControlKind } from '../../../typedefinitions/enums/ControlKind';
import { UnitType } from '../../../typedefinitions/enums/UnitType';
import { HorizontalAlignment } from '../../../typedefinitions/enums/HorizontalAlignment';
import { VerticalAlignment } from '../../../typedefinitions/enums/VerticalAlignment';
import * as i0 from "@angular/core";
/**
 * The base component class. Makes sure all basic properties are properly loaded and accessible. Allows overriding of functions where needed.
 */
export declare abstract class BaseComponent<T extends IBaseControl> implements IBaseComponentViewModel2, OnInit, OnDestroy, AfterViewInit {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    private controlSubscription?;
    /**
     * object for inline styling style
     */
    private _style;
    /**
     * object for css classes
     */
    private _cssClass;
    private _controlSize;
    /**
     * object for styling through css variables
     */
    protected cssStyle: CSSStyleObject;
    /**
     * The referenced control that is being observed for changes.
     */
    protected controlSubject: Optional<BehaviorSubject<IBaseControl>>;
    /**
     * Object containing watermark info for controls
     */
    protected watermark?: Watermark;
    /**
     * View child used for determining the auto-width size value
     */
    protected autoWidthElementRef: ElementRef;
    /**
     * View child used for determining the auto-height size value
     */
    protected autoHeightElementRef: ElementRef;
    /**
     * HTML element from the component element wrapper reference
     */
    protected get element(): Nullable<HTMLElement>;
    /**
     * HTML element used for determining the controls auto width size
     */
    protected get autoWidthElement(): Nullable<HTMLElement>;
    /**
     * HTML element used for determining the controls auto height size
     */
    protected get autoHeightElement(): Nullable<HTMLElement>;
    /**
     * Counter for detected changes in width
     */
    static detectChangesWidthCounter: number;
    /**
     * Counter for detected changes in height
     */
    static detectChangesHeightCounter: number;
    /**
     * Counter for detected size tree ready changes
     */
    static detectChangesReadyCounter: number;
    /**
     * Control data-object
     */
    dataObject: T;
    /**
     * Control container id
     */
    parentId: string;
    /**
     * Control container type
     */
    parentType: string;
    /**
     * Control type
     */
    type: Type<BaseComponent<IBaseControl>>;
    /**
     * Nullable control size object getter
     */
    get controlSize(): Nullable<IControlSize>;
    /**
     * Nullable control size object setter
     */
    set controlSize(value: Nullable<IControlSize>);
    /**
     * Control's css style declaration object getter
     */
    get style(): CSSStyleObject;
    /**
     * Control's css class list getter
     */
    get cssClass(): string[];
    /**
     * Control's width object
     */
    width: IUnit;
    /**
     * Control's height object
     */
    height: IUnit;
    /**
     * Control's horizontal alignment property
     */
    horizontalAlignment: HorizontalAlignment;
    /**
     * Control's vertical alignment property
     */
    verticalAlignment: VerticalAlignment;
    /**
     * Control's horizontal text alignment property
     */
    horizontalTextAlignment: number;
    /**
     * Control's vertical text alignment property
     */
    verticalTextAlignment: number;
    /**
     * Flag that indicates whether the control contains rich text or not
     */
    containsRichText: boolean;
    /**
     * Control's aria bindings object
     */
    ariaOptions: AriaOptions;
    /**
     * Control's id
     * @returns string
     */
    get controlId(): string;
    /**
     * Control's kind/type
     * @returns ControlKind
     */
    get controlKind(): ControlKind;
    /**
     * Flag indicating if the control is disabled
     * @returns boolean
     */
    get isEnabled(): boolean;
    /**
     * Flag indicating if the control is visible
     * @returns boolean
     */
    get isVisible(): boolean;
    /**
     * Control's html disabled attribute text value
     * @returns Optional<string>
     */
    get disabled(): Optional<string>;
    /**
     * Control's tab-index attribute value
     * @returns Optional<number>
     */
    get tabIndex(): Optional<number>;
    /**
     * Flag indicating if the width unit type is set to auto
     * @returns boolean
     */
    get hasAutoWidth(): boolean;
    /**
     * Flag indicating if the height unit type is set to auto
     * @returns boolean
     */
    get hasAutoHeight(): boolean;
    /**
     * Read-only property width unit type. default: Auto
     * @returns UnitType
     */
    get widthUnitType(): UnitType;
    /**
     * Read-only property height unit type. default: Auto
     * @returns UnitType
     */
    get heightUnitType(): UnitType;
    /**
     * The watermark text value
     * @returns Optional<string> the watermark text is there is a watermark with a text that is not empty, null or undefined, otherwise returns undefined
     */
    get watermarkText(): Optional<string>;
    /**
     * Retrieves the watermark text length
     * @returns number the watermark text length
     */
    get watermarkTextLength(): number;
    /**
     * Flag to enable/disable css vars
     * @returns boolean
     */
    get useCssVars(): boolean;
    /**
     * Host-bound width css style property
     * @returns Optional<string>
     */
    get elementWidth(): Optional<string>;
    /**
     * Host-bound height css style property
     * @returns Optional<string>
     */
    get elementHeight(): Optional<string>;
    /**
     * Host-bound display css style property
     * @returns Optional<string>
     */
    get elementDisplay(): Optional<string>;
    /**
     * Vertical alignment of the element in its parent through the host-bound align-self property
     * @returns Optional<string>
     */
    get elementAlignSelf(): Optional<string>;
    /**
     * Horizontal alignment of the element in its parent through the host-bound align-self property
     * @returns Optional<string>
     */
    get elementJustifySelf(): Optional<string>;
    /**
     * Host-bound vertical text alignment property
     * @returns Optional<string>
     */
    get elementVerticalTextAlignment(): Optional<string>;
    /**
     * Host-bound horizontal text alignment property
     * @returns Optional<string>
     */
    get elementHorizontalTextAlignment(): Optional<string>;
    /**
     * host-bound grid-template-rows container control property
     */
    elementTemplateRows: string;
    /**
     * host-bound grid-template-columns container control property
     */
    elementTemplateColumns: string;
    /**
     * host-bound grid-column-start container control property
     */
    elementColumnStart: number;
    /**
     * host-bound grid-column-end container control property
     */
    elementColumnEnd: number;
    /**
     * host-bound grid-row-start container control property
     */
    elementRowStart: number;
    /**
     * host-bound grid-row-end container control property
     */
    elementRowEnd: number;
    /**
     * host-bound columns container control property
     */
    elementColumns: number;
    /**
     * host-bound rows container control property
     */
    elementRows: number;
    /**
     * The host-bound background property is a shorthand property for multiple background properties.
     * @returns Optional<string>
     */
    get elementBackground(): Optional<string>;
    /**
     * The host-bound background-clip property defines how far the background (color or image) should extend within an element.
     * @returns Optional<string>
     */
    get elementBackgroundClip(): Optional<string>;
    /**
     * The host-bound background-image property sets one or more background images for an element.
     * @returns Optional<string>
     */
    get elementBackgroundImage(): Optional<string>;
    /**
     * The host-bound background-position property sets the starting position of a background image.
     * @returns Optional<string>
     */
    get elementBackgroundPosition(): Optional<string>;
    /**
     * The host-bound background-repeat property sets if/how a background image will be repeated.
     * @returns Optional<string>
     */
    get elementBackgroundRepeat(): Optional<string>;
    /**
     * The host-bound background-size property specifies the size of the background images.
     * @returns Optional<string>
     */
    get elementBackgroundSize(): Optional<string>;
    /**
     * The opacity property sets the opacity level for the element.
     * @returns Optional<string>
     */
    get elementOpacity(): Optional<string>;
    /**
     * The host-bound border-color property sets the color of an element's four borders. This property can have from one to four values.
     * @returns Optional<string>
     */
    get elementBorderColor(): Optional<string>;
    /**
     * The host-bound border-radius property defines the radius of the element's corners.
     * @returns Optional<string>
     */
    get elementBorderRadius(): Optional<string>;
    /**
     * The host-bound border-bottom-left-radius property defines the radius of the element's bottom-left corner.
     * @returns Optional<string>
     */
    get elementBorderBottomLeftRadius(): Optional<string>;
    /**
     * The host-bound border-bottom-right-radius property defines the radius of the element's bottom-right corner.
     * @returns Optional<string>
     */
    get elementBorderBottomRightRadius(): Optional<string>;
    /**
     * The host-bound border-top-left-radius property defines the radius of the element's top-left corner.
     * @returns Optional<string>
     */
    get elementBorderTopLeftRadius(): Optional<string>;
    /**
     * The host-bound border-top-right-radius property defines the radius of the element's top-right corner.
     * @returns Optional<string>
     */
    get elementBorderTopRightRadius(): Optional<string>;
    /**
     * The host-bound border-style property sets the style of an element's four borders. This property can have from one to four of the following values: none|hidden|dotted|dashed|solid|double|groove|ridge|inset|outset|initial|inherit.
     * @returns Optional<string>
     */
    get elementBorderStyle(): Optional<string>;
    /**
     * The host-bound border-width property sets the width of an element's four borders. This property can have from one to four values of the following values: medium|thin|thick|length|initial|inherit.
     * @returns Optional<string>
     */
    get elementBorderWidth(): Optional<string>;
    /**
     * The host-bound margin property sets the margins for an element.
     * @returns Optional<string>
     */
    get elementMargin(): Optional<string>;
    /**
     * The host-bound padding property sets the element's space between its content and its border.
     * @returns Optional<string>
     */
    get elementPadding(): Optional<string>;
    /**
     * The host-bound overflow-x property specifies whether to clip the content, add a scroll bar, or display overflow content of a block-level element, when it overflows at the left and right edges.
     * @returns Optional<string>
     */
    get elementOverflowX(): Optional<string>;
    /**
     * The host-bound overflow-y property specifies whether to clip the content, add a scroll bar, or display overflow content of a block-level element, when it overflows at the top and bottom edges.
     * @returns Optional<string>
     */
    get elementOverflowY(): Optional<string>;
    /**
     * The host-bound text-align property specifies the horizontal alignment of text in an element.
     * @returns Optional<string>
     */
    get elementTextAlign(): Optional<string>;
    /**
     * The visibility property specifies whether an element is visible.
     * @returns Optional<string>
     */
    get elementVisibility(): Optional<string>;
    /**
     * The host-bound line-height property specifies the text line height.
     * @returns Optional<string>
     */
    get elementLineHeight(): Optional<string>;
    /**
     * The host-bound font-color property specifies the text color of an element.
     * @returns Optional<string>
     */
    get elementFontColor(): Optional<string>;
    /**
     * The host-bound font-family property specifies the font for an element, it can hold several font names as a fallback system for possible browser-unsupported fonts.
     * @returns Optional<string>
     */
    get elementFontFamily(): Optional<string>;
    /**
     * The host-bound font-size property sets the size of a font. Values can be medium|xx-small|x-small|small|large|x-large|xx-large|smaller|larger|length-unit(px, em, ...)|initial|inherit;
     * @returns Optional<string>
     */
    get elementFontSize(): Optional<string>;
    /**
     * The host-bound font-style property specifies the font style for a text.
     * @returns Optional<string>
     */
    get elementFontStyle(): Optional<string>;
    /**
     * The host-bound font-weight property sets how thick or thin characters in text should be displayed.
     * @returns Optional<string>
     */
    get elementFontWeight(): Optional<string>;
    /**
     * The host-bound font-decoration property sets text decoration for an element (underline, strikethrough, ...).
     * @returns Optional<string>
     */
    get elementFontDecoration(): Optional<string>;
    /**
     * The color property of the watermark font
     * @returns Optional<string>
     */
    get watermarkFontColor(): Optional<string>;
    /**
     * The watermark font family property
     * @returns Optional<string>
     */
    get watermarkFontFamily(): Optional<string>;
    /**
     * The watermark font size property
     * @returns Optional<string>
     */
    get watermarkFontSize(): Optional<string>;
    /**
     * The leaning font style property of the watermark font
     * @returns Optional<string>
     */
    get watermarkFontStyle(): Optional<string>;
    /**
     * The watermark font weight
     * @returns Optional<string>
     */
    get watermarkFontWeight(): Optional<string>;
    /**
     * The decoration property of the watermark font
     * @returns Optional<string>
     */
    get watermarkFontDecoration(): Optional<string>;
    /**
     * IOS platform indicator for IOS specific solutions
     * @returns boolean
     */
    protected get isIOS(): boolean;
    /**
     * Base component class constructor.
     * @param sp The service provider service provides easy access to several commonly used services
     * @param el Wrapper around a native element inside a View
     * @param cd Base class for Angular Views, provides change detection functionality.
     */
    protected constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Control container type check cast
     * @param control Base control
     * @returns IControlContainerControl the control as a control container control if it fits the condition
     */
    static isControlContainerComponent(control: IBaseControl): control is IControlContainerControl;
    /**
     * A callback method that is invoked immediately after the default change detector has checked the directive's data-bound properties for the first time,
     * and before any of the view or content children have been checked.
     * It is invoked only once when the component is instantiated.
     */
    ngOnInit(): void;
    /**
     * A callback method that is invoked immediately after Angular has completed initialization of a component's view.
     * It is invoked only once when the view is instantiated.
     * If the component contains rich text, this callback method adds click-event listeners, if needed.
     */
    ngAfterViewInit(): void;
    /**
     * A callback method that performs custom clean-up, invoked immediately after the directive is destroyed.
     */
    ngOnDestroy(): void;
    /**
     * Override this method in subclasses to process control changes.
     * @param newDataObject Updated data object
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    /**
     * Executes all actions defined in a given action event handler on the control
     * @param actionsEventHandler object containing a name and one or more actions
     */
    executeActions(actionsEventHandler?: IActionsEventHandler): void;
    /**
     * Retrieves the width and/or height of the control
     * @returns IDimension Css style declaration object containing the control width and/or height
     */
    getDimensions(): IDimension;
    /**
     * Returns the name of the constructor object. For example: 'StringTextboxComponent'.
     * @returns string
     */
    getComponentName(): string;
    /**
     * Return the array of css classes to apply
     * @returns Array<string>
     */
    getCssClasses(): string[];
    /**
     * Create a base array of css class names
     * @param includeWatermarkClass
     * @returns Array<string> an array of css classes to apply
     */
    getFontCssClasses(includeWatermarkClass?: boolean): string[];
    /**
     * Applies the styles
     * Override in other components to assign specific values.
     * @returns CSSStyleObject
     */
    getStyleObject(): CSSStyleObject;
    /**
     * Size-tree width
     */
    sizeTreeSetWidth(): void;
    /**
     * Size-tree height
     */
    sizeTreeSetHeight(): void;
    /**
     * Retrieves the width that the browser assigned to the element, if this is an auto-sized leaf control.
     * Note: This function must be overridden in the grid-, table- and panel-control as their control-sizes are not an instance of a leaf control size.
     */
    setContentWidth(): void;
    /**
     * Retrieves the height that the browser assigned to the element, if this is an auto-sized leaf control.
     * Note: This function must be overridden in the grid-, table- and panel-control as their control-sizes are not an instance of a leaf control size.
     */
    setContentHeight(): void;
    /**
     * Size-tree ready
     */
    sizeTreeReady(): void;
    /**
     * Determine the current position of the component.
     * @returns Nullable<DOMRect>
     */
    getPosition(): Nullable<DOMRect>;
    /**
     * Return the set of related controls.
     * This method Will be overridden in some controls.
     * @returns Array<IControlInfo>
     */
    getNeighbours(): IControlInfo[];
    /**
     * Return the object version. This version should be bumped when the IBaseComponentViewModel interface changes to maintain compatibility with custom applications.
     * @returns number
     */
    getVersion(): number;
    /**
     * Returns the default/base navigation strategy, unless it is overridden
     * @returns INavigationModeStrategy
     */
    getKeyboardNavigationStrategy(): INavigationModeStrategy;
    /**
     * Returns the keyboard insert strategy when overridden, otherwise (default) null
     * @returns Nullable<INavigationModeStrategy>
     */
    getKeyboardInsertStrategy(): Nullable<INavigationModeStrategy>;
    /**
     * Return the keyboard empty strategy when overridden, otherwise (default) EmptyStrategy
     * @returns INavigationModeStrategy
     */
    getKeyboardEmptyStrategy(): INavigationModeStrategy;
    /**
     * Sets text from a paste command on the component
     * @param text Text to set on the control
     */ setText(text: string): void;
    /**
     * Clears the text from the component after a cut command
     */
    clearText(): void;
    /**
     * Register the component in the size tree
     * @param connectToTree flag
     */
    protected configureControlSize(connectToTree?: boolean): void;
    /**
     * Get values to assign to the controlSize object
     */
    protected updateControlSize(): void;
    /**
     * Override this method in container controls.
     * @returns Array<IControlSize>
     */
    protected createChildControlSizes(): IControlSize[];
    /**
     * Entry point for handling styling and dimensions
     */
    protected applyStylesAndDimensions(): void;
    /**
     * Sets the component's width unit property from the stylable properties
     * @protected
     */
    protected setWidthFromStylableProperties(): void;
    /**
     * Sets the component's height unit property from the stylable properties
     * @protected
     */
    protected setHeightFromStylableProperties(): void;
    /**
     * Type cast check validates the `Watermark` property object of a given base control object and expands the type if valid
     * @param dataObject the base control object to check/type cast
     * @returns IBaseControl with IHasWatermark properties
     * @protected
     */
    protected hasWaterMark(dataObject: IBaseControl): dataObject is IBaseControl & IHasWatermark;
    /**
     * Checks if a given watermark object is not null or undefined, doesn't have a font name defined, but does have font info values on its font property
     * @param watermark the watermark object to check
     * @returns boolean
     * @protected
     */
    protected watermarkHasFontObject(watermark?: Optional<Watermark>): boolean;
    /**
     * Type cast check validates the `Font: IFontInfo` property of a given watermark object for a non-null value and expands the type of the waterwark object if valid
     * @param watermark the watermark object to check/type cast
     * @returns Watermark with IHasFontObject properties
     * @protected
     */
    private isWatermarkWithFontObject;
    /**
     * Base control `FontName`|`Font` properties type cast check
     * @param obj the base control object to check/type cast
     * @returns Object with IHasFont properties
     * @protected
     */
    protected hasFontProperties<T>(obj: T): obj is T & IHasFont;
    /**
     * Base control `FontName` string property type cast check
     * @param obj the (base control) object to check/type cast
     * @returns Object with IHasFontName properties
     * @protected
     */
    protected hasFontName<T>(obj: T): obj is T & IHasFontName;
    /**
     * Base control `Font` object type cast check
     * @param obj the (base control) object to check/type cast
     * @returns Object with IHasFontObject properties
     * @protected
     */
    protected useFontObject<T>(obj: T): obj is T & IHasFontObject;
    /**
     * Base control `FontName` type cast check for CSS variables and combined fonts
     * @param obj the (base control) object to check/type cast
     * @returns Object with IHasFont and IHasFontName properties
     * @protected
     */
    protected useCombinedFont<T>(obj: T): obj is T & IHasFont & IHasFontName;
    /**
     * Base control `ShowKeyboardFocus` boolean property type cast check
     * @param dataObject the base control object to check/type cast
     * @returns IBaseControl with IHasKeyboardFocus properties
     * @protected
     */
    protected hasKeyboardFocus(dataObject: IBaseControl): dataObject is IBaseControl & IHasKeyboardFocus;
    /**
     * Base control `TabIndex` number property type cast check
     * @param dataObject the base control object to check/type cast
     * @returns IBaseControl with IHasTabIndex properties
     * @protected
     */
    protected hasTabIndex(dataObject: IBaseControl): dataObject is IBaseControl & IHasTabIndex;
    private handleControlChanged;
    /**
     * Retrieves the dimension string value of a component's width/height unit definition
     * @param unit Unit definition
     * @param margin The horizontal/vertical margin of the component
     * @returns string
     * @description
     *    Auto -> auto
     *    Pixels -> <unitValue>px
     *    Stretch -> calc(100% - margin(px))
     */
    private convertIUnitToString;
    private applyCssVars;
    private logSizeTreeInfo;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BaseComponent<any>, "ng-component", never, { "dataObject": { "alias": "dataObject"; "required": false; }; "parentId": { "alias": "parentId"; "required": false; }; "parentType": { "alias": "parentType"; "required": false; }; }, {}, never, never, false, never>;
}
