import { ChangeDetectorRef, ElementRef, EventEmitter, NgZone } from '@angular/core';
import { DateTime, DurationLike } from 'luxon';
import { ColorService } from '../../../services/color.service';
import { StyleGeneratorService } from '../../../services/style-generator.service';
import { CSSStyleObject } from '../../../../typedefinitions/models/style/CSSStyleObject';
import { ICalendarItem } from '../../../../typedefinitions/models/ICalendarItem';
import { IDatePickerSettings } from '../../../../typedefinitions/models/controls/properties/date-picker-settings/IDatePickerSettings';
import { IDateConstraints } from '../../../../typedefinitions/models/controls/properties/date-picker-settings/IDateConstraints';
import { CalendarView } from '../../../../typedefinitions/enums/CalendarView';
import * as i0 from "@angular/core";
/**
 * The base component class for the calendar view components
 */
export declare abstract class CalendarBaseViewComponent {
    /**
     * Element reference
     */
    protected el: ElementRef;
    /**
     * Change detector reference
     */
    protected cd: ChangeDetectorRef;
    /**
     * Executes work outside the Angular zone
     */
    protected ngZone: NgZone;
    /**
     * Provides functionality for converting a color object into a css style string
     */
    protected colorService: ColorService;
    /**
     * Style generator service
     */
    protected styleGeneratorService: StyleGeneratorService;
    /**
     * Calendar view name `decade`, `month`, `year`
     * @protected
     */
    protected abstract readonly viewName: string;
    /**
     * Calendar date format for decade: `year`, for month: `yyyyMMdd` and for year: `yyyyMM`
     * @protected
     */
    protected abstract readonly dateFormat: string;
    /**
     * The id of the active cell
     */
    protected activeCell: string;
    /**
     * ARIA active descendant
     */
    protected ariaActiveDescendant: string;
    /**
     * Calendar items to populate and show on the view
     */
    calendarItems: ICalendarItem[][];
    /**
     * The currently active / focused date
     */
    viewDate: DateTime;
    /**
     * Visibility flag for the view component
     */
    viewIsVisible: boolean;
    /**
     * The currently selected date of the calendar component
     */
    selectedDate: DateTime;
    /**
     * The id of the input control of which the calendar is an extension
     */
    componentId: string;
    /**
     * Component layout settings
     */
    datePickerSettings: IDatePickerSettings;
    /**
     * Component date restriction settings
     */
    dateConstraints: IDateConstraints;
    /**
     * Component's header css style declaration object
     */
    headerStyle: CSSStyleDeclaration;
    /**
     * Component's body css style declaration object
     */
    bodyStyle: CSSStyleDeclaration;
    /**
     * Event thrown when a new view date has been selected
     */
    viewDateChanged: EventEmitter<DateTime>;
    /**
     * Event thrown another calendar view should be selected
     */
    toggleCalendarView: EventEmitter<CalendarView>;
    /**
     * Event thrown when the calendar view should be closed/hidden
     */
    closeDatePickerEvent: EventEmitter<any>;
    /**
     * Text shown on the view header
     */
    label: string;
    /**
     * Calendar view header cell css style declaration object
     */
    headerCellStyle: CSSStyleObject;
    /**
     * Calendar view body cell css style declaration object
     */
    bodyCellStyle: CSSStyleObject;
    /**
     * Composes the id of the calendar view's previous item group
     */
    get prevItemGroupId(): string;
    /**
     * Composes the id of the calendar view's next item group
     */
    get nextItemGroupId(): string;
    /**
     * Composes the id of the calendar view's switch view
     */
    get switchViewId(): string;
    /**
     * Returns the calendar view's tab index (0 when the calendar view is visible, 1 when it is not)
     */
    get tabIndex(): number;
    /**
     * The calendar view components' base class constructor
     * @param el Element reference
     * @param cd Change detector reference
     * @param ngZone Executes work outside the Angular zone
     * @param colorService Provides functionality for converting a color object into a css style string
     * @param styleGeneratorService Style generator service
     */
    protected constructor(
    /**
     * Element reference
     */
    el: ElementRef, 
    /**
     * Change detector reference
     */
    cd: ChangeDetectorRef, 
    /**
     * Executes work outside the Angular zone
     */
    ngZone: NgZone, 
    /**
     * Provides functionality for converting a color object into a css style string
     */
    colorService: ColorService, 
    /**
     * Style generator service
     */
    styleGeneratorService: StyleGeneratorService);
    /**
     * Returns a string id for a cell based on its date value
     * @param date The date value to base the id of the cell on
     */
    getCellId(date: DateTime): string;
    /**
     * Checks a cell against the active cell id, if there's a match, the cell is active.
     * @param calendarItem cell information
     */
    isActiveCell(calendarItem: ICalendarItem): boolean;
    /**
     * Focuses the active cell when the view component receives focus
     */
    handleFocus(): void;
    /**
     * Sets the cell's hover background color on the target when the mouse cursor is above it
     * @param event mouse event information
     * @param calendarItem (optional) calendar item provides extra information on the target
     */ onMouseOver(event: MouseEvent, calendarItem?: ICalendarItem): void;
    /**
     * Sets the cell's background color on the target when the mouse cursor is no longer above it
     * @param event mouse event information
     * @param calendarItem calendar item information by which we determine the background color
     */
    onMouseOut(event: MouseEvent, calendarItem: ICalendarItem): void;
    /**
     * Regenerates the calendar view using a given date as reference point
     * @param date Date used to regenerate the view
     */
    abstract regenerate(date: DateTime): void;
    /**
     * Determines the background color using the calendar cell item information
     * @param calendarItem cell information used to determine the result
     */
    abstract determineBackgroundColor(calendarItem: ICalendarItem): string;
    /**
     * The calendar view's event handler for the keyboard's key down event
     * @param event Keyboard event information
     */
    handleKeyDown(event: KeyboardEvent): boolean;
    /**
     * Handles the previous item group keyboard command
     * @param event Keyboard event information
     * @protected
     */
    protected abstract previousItemGroup(event: KeyboardEvent): boolean;
    /**
     * Handles the next item group keyboard command
     * @param event Keyboard event information
     * @protected
     */
    protected abstract nextItemGroup(event: KeyboardEvent): boolean;
    /**
     * Handles the previous item row keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected abstract previousItemRow(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * Handles the next item row keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected abstract nextItemRow(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * Handles the previous item keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected abstract previousItem(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * Handles the next item keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected abstract nextItem(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * Handles the select item keyboard command
     * @param event Keyboard event information
     * @protected
     */
    protected abstract selectItem(event: KeyboardEvent): boolean;
    /**
     * Sets a given date as the view date, selects and activates the view date's cell
     * @param date The date to set as view date
     * @protected
     */
    protected setViewDate(date: DateTime): void;
    /**
     * Set a given HTML table cell element as the active cell and focus that cell
     * @param cell The cell to select
     * @protected
     */
    protected selectCell(cell: Nullable<HTMLTableCellElement>): void;
    /**
     * Tries to retrieve a HTML table cell element by a given id
     * @param id The id of the cell to retrieve
     * @protected
     */
    protected getCellById(id: string): Nullable<HTMLTableCellElement>;
    /**
     * Generates a display label for a cell based on its value
     * @param date The date-time value on which to base the label
     * @protected
     */
    protected abstract generateLabel(date: DateTime): void;
    /**
     * Sets a given cell as active (by id)
     * @param id The id of the cell to mark as active
     * @private
     */
    private setActiveCell;
    /**
     * Focuses the active cell after the microtask queue is empty.
     */
    private focusActiveCell;
    static ɵfac: i0.ɵɵFactoryDeclaration<CalendarBaseViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CalendarBaseViewComponent, "ng-component", never, { "viewDate": { "alias": "viewDate"; "required": false; }; "viewIsVisible": { "alias": "viewIsVisible"; "required": false; }; "selectedDate": { "alias": "selectedDate"; "required": false; }; "componentId": { "alias": "componentId"; "required": false; }; "datePickerSettings": { "alias": "datePickerSettings"; "required": false; }; "dateConstraints": { "alias": "dateConstraints"; "required": false; }; "headerStyle": { "alias": "headerStyle"; "required": false; }; "bodyStyle": { "alias": "bodyStyle"; "required": false; }; }, { "viewDateChanged": "viewDateChanged"; "toggleCalendarView": "toggleCalendarView"; "closeDatePickerEvent": "closeDatePickerEvent"; }, never, never, false, never>;
}
