import { ElementRef, EventEmitter, OnInit, ChangeDetectorRef, NgZone } from '@angular/core';
import { DateTime, DurationLike } from 'luxon';
import { CalendarBaseViewComponent } from './calendar-base-view.component';
import { CultureInfoService } from '../../../services/culture-info.service';
import { RenderStateService } from '../../../services/renderstate.service';
import { StyleGeneratorService } from '../../../services/style-generator.service';
import { ICalendarItem } from '../../../../typedefinitions/models/ICalendarItem';
import { ColorService } from '../../../services/color.service';
import * as i0 from "@angular/core";
/**
 * The calendar's month view component class
 */
export declare class CalendarMonthViewComponent extends CalendarBaseViewComponent implements OnInit {
    private cultureInfoService;
    private renderStateService;
    private firstDayOfWeek;
    /**
     * Decade calendar view name
     * @protected
     */
    protected readonly viewName = "month";
    /**
     * Month date format
     * @protected
     */
    protected readonly dateFormat = "yyyyMMdd";
    /**
     * Readonly flag indicating if the header labels should be shown
     */
    dayNamesVisible: boolean;
    /**
     * The header label texts
     */
    dayLabels: string[];
    /**
     * Event Subject on which to emit a date change when a new date has been selected
     */
    selectedDateChanged: EventEmitter<DateTime>;
    /**
     * Calendar month view component class constructor
     * @param el View element reference
     * @param cd Change detector reference
     * @param ngZone executes work outside the Angular zone
     * @param colorService Provides functionality for converting a color object into a css style string.
     * @param cultureInfoService Used for storing and consulting culture settings
     * @param renderStateService Provides functionality for managing the render state information as provided by the server
     * @param styleGeneratorService Style generator service
     */
    constructor(el: ElementRef, cd: ChangeDetectorRef, ngZone: NgZone, colorService: ColorService, cultureInfoService: CultureInfoService, renderStateService: RenderStateService, styleGeneratorService: StyleGeneratorService);
    /**
     * Initializes header texts and styles for the month view component
     */
    ngOnInit(): void;
    /**
     * Sets a given date as selected, emits the selected date changed event and updates the view.
     * @param date the date to set as selected
     * @param dateIsDisabled flag indicating if the given date is enabled
     * @param event (optional) The mouse event when triggered by a mouse click event
     */
    selectDate(date: DateTime, dateIsDisabled: boolean, event?: MouseEvent): void;
    /**
     * If allowed, shows the next month in the calendar view
     * @param date
     */
    nextMonth(date?: DateTime): void;
    /**
     * If allowed, shows the previous month in the calendar view
     * @param date
     */
    previousMonth(date?: DateTime): void;
    /**
     * Checks if any day of the next month is selectable and prevents further navigation if not
     */
    canNavigateToNextMonth(): boolean;
    /**
     * Checks if any day of the previous month is selectable and prevents further navigation if not
     */
    canNavigateToPreviousMonth(): boolean;
    /**
     * Notifies the date control of a view date change and switched to the year view
     */
    switchToYearView(): void;
    /**
     * @inheritDoc
     * Regenerates the calendar view using a given date as reference point
     * @param date Date used to regenerate the view
     */
    regenerate(date: DateTime): void;
    /**
     * @inheritDoc
     * Determines the background color using the calendar cell item information
     * @param calendarItem date cell information used to determine the result
     */
    determineBackgroundColor(calendarItem: ICalendarItem): string;
    /**
     * @inheritDoc
     * Sets the cell's hover background color on the target when the mouse cursor is above it
     * @param event mouse event information
     * @param day day calendar item provides extra information on the target
     */
    onMouseOver(event: MouseEvent, day: ICalendarItem): void;
    /**
     * @inheritDoc
     * Handles the previous item group keyboard command
     * @param event Keyboard event information
     * @protected
     */
    protected previousItemGroup(event: KeyboardEvent): boolean;
    /**
     * @inheritDoc
     * Handles the next item group keyboard command
     * @param event Keyboard event information
     * @protected
     */
    protected nextItemGroup(event: KeyboardEvent): boolean;
    /**
     * @inheritDoc
     * Handles the previous item row keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected previousItemRow(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * @inheritDoc
     * Handles the next item row keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected nextItemRow(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * @inheritDoc
     * Handles the previous item keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected previousItem(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * @inheritDoc
     * Handles the next item keyboard command
     * @param event Keyboard event information
     * @param duration The mutation amount
     * @protected
     */
    protected nextItem(event: KeyboardEvent, duration?: DurationLike): boolean;
    /**
     * @inheritDoc
     * Handles the select item keyboard command
     * @param event Keyboard event information
     * @protected
     */
    protected selectItem(event: KeyboardEvent): boolean;
    /**
     * @inheritDoc
     * Sets a given date as the view date, selects and activates the view date's cell
     * @param date The date to set as view date
     * @protected
     */
    protected setViewDate(date: DateTime): void;
    /**
     * @inheritDoc
     * Generates a display label for a cell based on its value
     * @param date The date-time value on which to base the label
     * @protected
     */
    protected generateLabel(date: DateTime): void;
    private generateDaysForCurrentMonth;
    private dateIsOutOfDateRange;
    private dateIsDisabledInDatePicker;
    private convertToDateTime;
    private dateListContainsDate;
    static ɵfac: i0.ɵɵFactoryDeclaration<CalendarMonthViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CalendarMonthViewComponent, "bl5-calendar-month-view", never, {}, { "selectedDateChanged": "selectedDateChanged"; }, never, never, false, never>;
}
