import { AfterViewInit, ChangeDetectorRef, ElementRef, NgZone, OnDestroy, OnInit } from '@angular/core';
import { DateTime } from 'luxon';
import { ReferenceComponent } from '../reference/reference.component';
import { CalendarMonthViewComponent } from './calendar/calendar-month-view.component';
import { CalendarYearViewComponent } from './calendar/calendar-year-view.component';
import { CalendarDecadeViewComponent } from './calendar/calendar-decade-view.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { DateFieldConverterService } from '../../services/converters/date-field-converter.service';
import { FieldConverterService } from '../../services/converters/field-converter.service';
import { IDateControl } from '../../../typedefinitions/models/controls/IDateControl';
import { IDateConstraints } from '../../../typedefinitions/models/controls/properties/date-picker-settings/IDateConstraints';
import { IDatePickerSettings } from '../../../typedefinitions/models/controls/properties/date-picker-settings/IDatePickerSettings';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { CalendarView } from '../../../typedefinitions/enums/CalendarView';
import * as i0 from "@angular/core";
/**
 * Date component class
 */
export declare class DateComponent extends ReferenceComponent<IDateControl> implements OnInit, AfterViewInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Date component element wrapper
     */
    el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Date field converter service
     */
    protected converter: DateFieldConverterService;
    /**
     * Service for working around the change detection of Angular
     */
    private ngZone;
    /**
     * Culture info
     */
    private get cultureInfo();
    private get shortDatePattern();
    private get sanitizedFromShortDateFormat();
    private get sanitizedToShortDateFormat();
    private get maskShortDatePattern();
    /**
     * The date separator as defined in the culture info
     * @private
     */
    private get defaultDateSeparator();
    private get datePatternParts();
    private get datePatternPartsCount();
    private get datePatternKeyArray();
    /**
     * Edit mask
     */
    private mask;
    /**
     * Date change subject
     */
    private dateChange;
    /**
     * Date change handler subscription
     */
    private dateChangeSubscription?;
    /**
     * Flag indicating if time should be included in DataValue
     */
    private includeTime;
    /**
     * Date picker button element reference
     * static : false since it is wrapped in an ngIf or an ngFor, accessible in ngAfterViewInit
     */
    private buttonRef;
    /**
     * Date input element reference
     * static : false since it is wrapped in an ngIf or an ngFor, accessible in ngOnInit
     */
    private inputRef;
    /**
     * Returns the complete field Information (including date constraints) required for validation
     */
    protected get fieldInfo(): Optional<IFieldInfo>;
    /**
     * The referenced field or field property info.
     * This setter triggers the next emit of the field subscription and set the event source ID to the current control.
     * This allows the control to ignore events that were generated by the control itself.
     * @param fieldInfo Field info
     */
    protected set fieldInfo(fieldInfo: Optional<IFieldInfo>);
    /**
     * Calendar month view child
     * static : false since it is wrapped in an ngIf or an ngFor, accessible in ngAfterViewInit
     */
    monthViewChild: CalendarMonthViewComponent;
    /**
     * Calendar year view child
     * static : false since it is wrapped in an ngIf or an ngFor, accessible in ngAfterViewInit
     */
    yearViewChild: CalendarYearViewComponent;
    /**
     * Calendar decade view child
     * static : false since it is wrapped in an ngIf or an ngFor, accessible in ngAfterViewInit
     */
    decadeViewChild: CalendarDecadeViewComponent;
    /**
     * Date constraints readonly property
     */
    get dateConstraints(): IDateConstraints;
    /**
     * Date picker settings readonly property
     */
    get datePickerSettings(): IDatePickerSettings;
    /**
     * Date picker css classes
     */
    datePickerClasses: string[];
    /**
     * Date picker css style object
     */
    calendarStyle: any;
    /**
     * Date picker view header css style object
     */
    headerStyle: any;
    /**
     * Date picker view body css style object
     */
    bodyStyle: any;
    /**
     * View date
     */
    viewDate: DateTime;
    /**
     * Selected date
     */
    private _selectedDate;
    /**
     * Selected date getter
     */
    get selectedDate(): DateTime;
    /**
     * Selected date setter
     */
    set selectedDate(value: DateTime);
    /**
     * current/last active calendar view
     */
    calendarView: CalendarView;
    /**
     * Flag indicating if the current active date picker view is the month view
     */
    get isMonthView(): boolean;
    /**
     * Flag indicating if the current active date picker view is the year view
     */
    get isYearView(): boolean;
    /**
     * Flag indicating if the current active date picker view is the decade view
     */
    get isDecadeView(): boolean;
    /**
     * Input element's css classes
     */
    inputClasses: string[];
    /**
     * Input element's css classes excluding font related classes
     */
    cssClassesWithoutFonts: string[];
    /**
     * Flag indicating if the date picker button and views are available for use
     */
    hasDatePickerAppearance: boolean;
    /**
     * Flag indicating if any of the date picker views are currently visible
     */
    datePickerIsVisible: boolean;
    /**
     * Selected or user inputted date
     */
    model: string;
    /**
     * Aria accessibility flag property is expanded. True when the date picker is visible, otherwise false.
     */
    isExpanded: boolean;
    /**
     * Readonly date picker button id string
     */
    get buttonId(): string;
    /**
     * Date component class constructor
     * @param sp Service provider service
     * @param el Element wrapper reference object
     * @param cd Change detector reference
     * @param converter Date field converter service
     * @param ngZone
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Date component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * Date field converter service
     */
    converter: DateFieldConverterService, 
    /**
     * Service for working around the change detection of Angular
     */
    ngZone: NgZone);
    /**
     * A callback method that is invoked immediately after the default change detector has checked the directive's data-bound properties for the first time,
     * and before any of the view or content children have been checked.
     * It is invoked only once when the directive is instantiated.
     * Extends the parent control's on init function, adds event listeners and subscriptions.
     */
    ngOnInit(): void;
    /**
     * A callback method that performs custom clean-up, invoked immediately after the directive is destroyed, extends the base control function.
     * Extends the parent control's on destroy function, un-subscribes from all subscriptions.
     */
    ngOnDestroy(): void;
    /**
     * Sets the edit-mask after view initialization
     */
    ngAfterViewInit(): void;
    /**
     * Fired on every keystroke
     */
    onKeyUp(event: KeyboardEvent): void;
    /**
     * Finalizes the date on the blur event of the component's input element
     */
    onBlur(): void;
    /**
     * Focuses the input when the datepicker is closed
     */
    focusInput(): void;
    /**
     * Process control changes, extends the parent control function, updates control styles.
     * @param newDataObject Updated panel control data object
     */
    handleControlUpdate(newDataObject: IDateControl): void;
    /**
     * Whenever the blur event is triggered or the enter key is hit, check if the entered date is valid.
     *
     * If Y of the inputted value consists of one or two digits, the year will be assumed to be in the current century.
     * Apply assumptions to make it more logical, notify if an assumption has been made.
     * Apply range-check errors
     */
    finalizeDate(): boolean;
    /**
     * Returns the array of css classes to apply, extends the parent control function.
     */
    getCssClasses(): string[];
    /**
     * Sets the selected CalendarView
     * @param calendarView calendar view to select
     * @param regenerate
     */
    setCalendarView(calendarView: CalendarView, regenerate?: boolean): void;
    /**
     * Sets the selected date in the current visible view
     * @param newViewDate date to set
     */
    setViewDate(newViewDate: DateTime): void;
    /**
     * Fired on every keystroke
     * Try to validate the entered date. Only when it becomes valid assign it to the field and
     * trigger a subscription update, execute action and apply the autoEnter
     *
     */
    onDateChanged(date: string | DateTime): void;
    /**
     * Toggles the visibility of the date picker
     * @param event keyboard or mouse event
     */
    toggleDatePicker(event: KeyboardEvent | MouseEvent): void;
    /**
     * Closes the date picker
     */
    closeDatePicker(): void;
    /**
     * Sets the selected date as the new date, closes the date picker
     * @param date
     */
    pickDate(date: any): void;
    /**
     * Overrides the base class' get font css class function and writes the font related classes to a separate array to apply on the date control (sub)elements
     */
    getFontCssClasses(): string[];
    /**
     * Overrides the base components set content width function if the control size is set to auto and there are font sizes available by which to determine the width.
     */
    setContentWidth(): void;
    /**
     * Window events that trigger the list to hide:
     */
    onWindowResize(): void;
    /**
     * Set specific logic for keyboard navigation insert-mode strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for keyboard navigation insert-mode strategy
     */
    getKeyboardEmptyStrategy(): INavigationModeStrategy;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Clears the text from the component after a cut command
     */
    clearText(): void;
    /**
     * Handles the change of values of the corresponding field
     * @param fieldInfo Updated field info
     */
    protected handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Overridden method to apply custom auto enter checking for the date component.
     */
    protected checkAutoEnter(autoEnterEnabled: boolean, converter: FieldConverterService, fieldInfo: IFieldInfo): boolean;
    private isDatePickerLeftAligned;
    private applyFonts;
    private calculatePosition;
    private onWindowScroll;
    private getDateObjectFromValue;
    private setMask;
    private createMask;
    private regenerateCurrentView;
    private getSeparatedDate;
    private pushChange;
    private switchToInsertMode;
    private applyDate;
    private flagFieldAsVisited;
    static ɵfac: i0.ɵɵFactoryDeclaration<DateComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DateComponent, "bl5-date", never, {}, {}, never, never, false, never>;
}
