import { AfterViewInit, ChangeDetectorRef, ElementRef, OnDestroy, OnInit } from '@angular/core';
import { ReferenceComponent } from '../reference/reference.component';
import { EnumerationFieldConverterService } from '../../services/converters/enumeration-field-converter.service';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { SetFieldConverterService } from '../../services/converters/set-field-converter.service';
import { CSSStyleObject } from '../../../typedefinitions/models/style/CSSStyleObject';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IDropdownListControl } from '../../../typedefinitions/models/controls/IDropdownListControl';
import { IHasDropdownList } from '../../../typedefinitions/models/IHasDropdownList';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { ISelectListItem } from '../../../typedefinitions/models/ISelectListItem';
import { DataType } from '../../../typedefinitions/enums/DataType';
import * as i0 from "@angular/core";
/**
 * Dropdown list component class
 */
export declare class DropDownListComponent extends ReferenceComponent<IDropdownListControl> implements IHasDropdownList, OnInit, AfterViewInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el dropdown list component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Enumeration field converter service
     */
    protected enumConverter: EnumerationFieldConverterService;
    /**
     * Set field converter service
     */
    protected setConverter: SetFieldConverterService;
    private buttonElementRef;
    private watermarkSizerRef;
    private listElementRef;
    private displayTextElementRef;
    private onWindowScrollListener;
    private onListScrollListener;
    private dataType;
    private get converter();
    /**
     * The height of the selected item
     */
    private selectedItemHeight;
    /**
     * debounced handleKeyEvent
     */
    private debouncedHandleKeyEvent;
    private debouncedHandleKeyEventSubscription?;
    /**
     * Temporary storage for keystrokes
     */
    private keyEvent;
    /**
     * Dropdown list button html element
     */
    private get buttonElement();
    /**
     * Watermark sizer div html element
     */
    private get watermarkSizer();
    /**
     * Unsorted list html element
     */
    private get listElement();
    /**
     * The selection source
     */
    private get selectionSource();
    /**
     * Value for the maxlength attribute which specifies the maximum number of characters allowed in the input element
     */
    maxLength: Nullable<number>;
    /**
     * Control's data value subscription's value type's data type. Either enumeration for single select or set for a multi-select dropdown list
     */
    get valueDataType(): DataType;
    /**
     * The option list element id
     */
    get optionListId(): string;
    /**
     * Watermark/placeholder font
     */
    watermarkFont: string;
    /**
     * Watermark/placeholder font style
     */
    watermarkFontStyleObj: CSSStyleObject;
    /**
     * Provides text for the list item size determination
     */
    listItemSizerText: string;
    /**
     * Select option item list
     */
    optionList: ISelectListItem[];
    /**
     * Flag indicating if the dropdown option list is populated
     */
    get hasOptions(): boolean;
    /**
     * Readonly property returning the value of the first selected value
     */
    get selectedValue(): string;
    /**
     * Dropdown option list css classes
     */
    optionListClass: string[];
    /**
     * Dropdown option list css styles object
     */
    optionListStyle: CSSStyleObject;
    /**
     * Dropdown option item css styles object
     */
    optionItemStyle: any;
    /**
     * Dropdown option list visible flag
     */
    optionsVisible: boolean;
    /**
     * Dropdown option tab index
     */
    get optionTabIndex(): number;
    /**
     * Flag indicating if the dropdown list is multi-select and shows checkboxes
     */
    get isMultiSelect(): boolean;
    /**
     * Flag indicating whether the list options are currently visible
     */
    get isListOpen(): boolean;
    /**
     * Index of the focused option item
     */
    targetIndex: number;
    /**
     * Display text for the selected language as shown in the button
     */
    displayText: Optional<string>;
    /**
     * Dropdown list component class constructor
     * @param sp The service provider service provides easy access to several commonly used services
     * @param el Element reference object
     * @param cd Change detector reference object
     * @param enumConverter Enumeration field converter service
     * @param setConverter Set field converter service
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el dropdown list component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * Enumeration field converter service
     */
    enumConverter: EnumerationFieldConverterService, 
    /**
     * Set field converter service
     */
    setConverter: SetFieldConverterService);
    /**
     * Initializes subscriptions
     */
    ngOnInit(): void;
    /**
     * Extends parent control function. Adds scroll event listeners on component initialisation
     */
    ngAfterViewInit(): void;
    /**
     * Performs cleanup tasks on component destruction
     */
    ngOnDestroy(): void;
    /**
     * Handle changed field values
     * @param fieldInfo Updated field info
     */
    handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Override this method in subclasses to process control changes.
     * @param newDataObject Updated dropdown list data object
     */
    handleControlUpdate(newDataObject: IDropdownListControl): void;
    /**
     * Calculates the width of the component when set to auto and with stylesheets
     */
    setContentWidth(): void;
    /**
     * Calculates the height of the component when set to auto and with stylesheets
     */
    setContentHeight(): void;
    /**
     * The window resize event triggers the list to hide
     */
    onWindowResize(): void;
    /**
     * The outside click event triggers the list to hide
     */
    onWindowMousedown(event: any): void;
    /**
     * A window swipe event triggers the list to hide
     */
    onWindowTouchMove(event: any): void;
    /**
     * A touch outside event triggers the list to hide
     */
    onWindowTouchEnd(event: any): void;
    /**
     * Handles the click event of the dropdown button
     * @param event Click event object
     */
    handleButtonClick(event: any): void;
    /**
     * Handles any keypress event on the dropdown button
     * @param event Keyboard event object
     */
    handleButtonKeyPress(event: KeyboardEvent): void;
    /**
     * Handles the mouse-over event on the dropdown menu items
     * @param event Click event object
     * @param index number in list
     */
    handleOptionMouseOver(event: Event, index: number): void;
    /**
     * Handles the list component's key press event
     */
    handleListKeyPress(): void;
    /**
     * Handles the selection of a value in the dropdownlist.
     * @param option
     * @param event MouseEvent
     * @param listItem
     */
    handleOptionClick(option?: ISelectListItem, event?: MouseEvent, listItem?: HTMLLIElement): void;
    /**
     * Hides the option list when the user clicks outside it
     */
    onClickOutside(): void;
    /**
     * Creates an option element id based on the option index
     * @param index Option index
     */
    getOptionId(index: number): string;
    /**
     * Creates an option checkbox element id for multi-select dropdown lists based on the option index
     * @param index Option index
     */
    getOptionCheckboxId(index: number): string;
    /**
     * Creates an option label element id based on the option index
     * @param index Option index
     */
    getOptionLabelId(index: number): string;
    /**
     * Retrieves an option item by its value
     * @param value Option value
     */
    getOptionItemByValue(value: string): Optional<ISelectListItem>;
    /**
     * Overrides/Extends the get font css classes function, adds the watermark css class if any
     */
    getFontCssClasses(): string[];
    /**
     * Set specific logic for keyboard navigation insert-mode strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for keyboard navigation navigation-mode strategy
     */
    getKeyboardNavigationStrategy(): INavigationModeStrategy;
    /**
     * Retrieves the empty strategy for keyboard
     */
    getKeyboardEmptyStrategy(): INavigationModeStrategy;
    /**
     * Selects a targeted value
     */
    selectValue(): void;
    /**
     * Selects the next page in a list with options that exceed the set page size
     */
    previousPage(): void;
    /**
     * Selects the next page in a list with options that exceed the set page size
     */
    nextPage(): void;
    /**
     * Selects the previous value
     */
    previousValue(): void;
    /**
     * Selects the next value
     */
    nextValue(): void;
    /**
     * Selects the first value
     */
    firstValue(): void;
    /**
     * Selects the last value
     */
    lastValue(): void;
    /**
     * Shows the dropdown option list
     */
    openDropDownList(): void;
    /**
     * Hides the dropdown option list
     */
    closeDropDownList(): void;
    /**
     * Sets focus to the dropdown select button
     */
    focusTextbox(): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Clears the text from the component after a cut command
     */
    clearText(): void;
    /**
     * Resets the option list style and positioning
     */
    protected resetList(): void;
    /**
     * Extends base functionality of the apply-styles-and-dimensions function and applies option list styles
     */
    protected applyStylesAndDimensions(): void;
    /**
     * Applies option list css classes
     */
    private setOptionsListClass;
    private setOptionsListBackgroundStyle;
    private setOptionsListFontStyle;
    /**
     * Populates the options list
     * @param fieldInfo Field info
     */
    private setOptions;
    /**
     * Sets the display text after a field update
     * @param fieldInfo Field info
     */
    private setDisplayText;
    /**
     * Set a single selected option
     * @param value Option value
     */
    private setSingleOption;
    /**
     * Sets the maximum amount of selectable options for multi-select dropdown lists
     * @param valueType
     */
    private setMaxLength;
    /**
     * Extract the watermark font so that it can be used on the correct items, the button doesn't have a placeholder attribute,
     * use the Font{0}-wm as Font{0} on the select-text <div>
     */
    private setWatermarkFont;
    private hideList;
    /**
     * Resets list style properties
     */
    private applyOptionListStyle;
    /**
     * Determines in which direction the list should show and brings the list into the viewport
     */
    private showList;
    /**
     * Scroll to the list item with the current target index
     */
    private focusTargetIndex;
    private handleKeyEvent;
    private getPageSize;
    private clearWatermarkFont;
    private hideListOnExternalEvent;
    private onWindowScroll;
    private onListScroll;
    static ɵfac: i0.ɵɵFactoryDeclaration<DropDownListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DropDownListComponent, "bl5-dropdownlist", never, {}, {}, never, never, false, never>;
}
