import { ElementRef, ChangeDetectorRef, OnInit, OnDestroy } from '@angular/core';
import { ResultContainer } from '../../../classes/result-container/result-container';
import { LookupComponent } from '../lookup.component';
import { LookupService } from '../../../services/lookup.service';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { StringFieldConverterService } from '../../../services/converters/string-field-converter.service';
import { CSSStyleObject } from '../../../../typedefinitions/models/style/CSSStyleObject';
import { IFieldInfo } from '../../../../typedefinitions/models/observables/IFieldInfo';
import { ILookupTextBoxControl } from '../../../../typedefinitions/models/controls/ILookupTextBoxControl';
import { ILookupState, IDataRow } from '../../../../typedefinitions/models/server/ILookupState';
import { INavigationModeStrategy } from '../../../../typedefinitions/models/INavigationModeStrategy';
import * as i0 from "@angular/core";
/**
 * Lookup textbox component class
 */
export declare class LookupTextboxComponent extends LookupComponent<ILookupTextBoxControl> implements OnInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Lookup textbox component element wrapper
     */
    el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * converter String field converter service
     */
    protected converter: StringFieldConverterService;
    /**
     * LookupService service for performing lookup searches and handling results
     */
    protected lookupService: LookupService;
    private updatedFromResults;
    private returnField;
    private returnFieldIndex;
    /**
     * object used for font style copying
     */
    private fontStyle;
    /**
     * lookup input element reference
     * static flag = true => the ElementRef is not wrapped in an ngIf or an ngFor, available in ngOnInit
     */
    private lookupInput;
    /**
     * lookup results container element reference
     * static flag = true => the ElementRef is not wrapped in an ngIf or an ngFor, available in ngOnInit
     */
    private lookupResultsContainer;
    /**
     * lookup results table element reference
     * static flag = true => the ElementRef is not wrapped in an ngIf or an ngFor, available in ngOnInit
     */
    private lookupResultsTable;
    /**
     * debounced handleChange
     */
    private debouncedHandleChange;
    private debouncedHandleChangeSubscription;
    /**
     * Select External Record events
     */
    private selectExternalRecordStartSubscription;
    private selectExternalRecordCompletedSubscription;
    /**
     * Active field change
     */
    private activeFieldChangeSubscription;
    /**
     * Lookup value
     */
    lookup: string;
    /**
     * lookup results
     */
    results: IDataRow[];
    /**
     * selected result item
     */
    selectedItem: number;
    /**
     * Names of field for displayable columns
     */
    fieldNames: string[];
    /**
     * Displayed field headers
     */
    headers: Record<string, string>;
    /**
     * Lookup result container style object
     */
    resultContainerObj: ResultContainer;
    /**
     * Maximum number of characters allowed
     */
    maxLength: number;
    /**
     * Value for the size attribute which specifies the visible width, in characters, of the input element
     */
    size: number;
    /**
     * readonly result table id
     */
    get resultsTableId(): string;
    /**
     * lookup answer option item css cell style object
     */
    optionItemStyle: any;
    /**
     * Lookup text box component class constructor
     * @param sp The service provider service provides easy access to regularly used services
     * @param el View element reference
     * @param cd Change detector reference
     * @param converter String field converter service
     * @param lookupService Lookup service for performing searches and handling results
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Lookup textbox component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * converter String field converter service
     */
    converter: StringFieldConverterService, 
    /**
     * LookupService service for performing lookup searches and handling results
     */
    lookupService: LookupService);
    /**
     * Initialize bindings and listeners
     */
    ngOnInit(): void;
    /**
     * Removes listeners, unsubscribes from active subscriptions
     */
    ngOnDestroy(): void;
    /**
     * Processes the updated field info
     * @param fieldInfo updated field info
     */
    handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Update the control with newly received information
     * @param newDataObject Data object
     */
    handleControlUpdate(newDataObject: ILookupTextBoxControl): void;
    /**
     * Update the results table when new lookup results are found, otherwise clear the table
     * @param newLookupState
     */
    handleLookupStateUpdate(newLookupState: ILookupState): void;
    /**
     * Overrides the set content width base implementation to determine the width. The string textbox width depends on the field maximum length and the text-margin.
     * This function only executes when Width property is set to auto
     */
    setContentWidth(): void;
    /**
     * Handles the change of the lookup value
     */
    handleChange(): void;
    /**
     * Allows navigating lookup results with the arrow keys and result selection on enter or space press
     * @param event Keyboard event
     */ handleKey(event: KeyboardEvent): void;
    /**
     * Handles the mouse down event
     */
    handleMouseDown(): void;
    /**
     * Handles the mouse up event
     * @description For WCAG 2.1 changed the mousedown event to mouseup
     * @param event
     */
    handleMouseUp(event: MouseEvent): void;
    /**
     * Sets the hover color on the currently hovered item
     * @param event Mouse event
     * @param index
     */ handleItemMouseOver(event: MouseEvent, index: number): void;
    /**
     * Hides the result list when the user clicks outside it
     */
    onClickOutside(): void;
    /**
     * Hides the result list when the window is resized
     */
    onWindowResize(): void;
    /**
     * Extends the base's getStyleObject function to copy the fontStyle
     */
    getStyleObject(): CSSStyleObject;
    /**
     * Set specific logic for insert strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Retrieves the font css classes and forces the inclusion of the watermark font class
     */
    getFontCssClasses(): string[];
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Sets text from a paste command on the component
     * @param text Text to set on the control
     */
    setText(text: string): void;
    /**
     * Clears the text from the component after a cut command
     */
    clearText(): void;
    /**
     * Extends base functionality of the apply-styles-and-dimensions function and applies option list styles
     */
    protected applyStylesAndDimensions(): void;
    private setElementWidth;
    /**
     * Allows result selection on mouse click
     * @param event Mouse event
     */
    private selectOption;
    private setResultContainerBackgroundStyle;
    private setResultContainerFontStyle;
    private hideResults;
    private showResults;
    /**
     * Stop bubbling the event in order to ignore the default behavior.
     */
    private cancelKeyboardEvent;
    /**
     * Set selected option value and update corresponding field
     */
    private setSelectedOption;
    /**
     * Select the record on the server
     */
    private selectExternalRecord;
    private clearResults;
    private reset;
    private redraw;
    private onWindowScroll;
    static ɵfac: i0.ɵɵFactoryDeclaration<LookupTextboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<LookupTextboxComponent, "bl5-lookup-textbox", never, {}, {}, never, never, false, never>;
}
