import { ChangeDetectorRef, ElementRef, OnInit } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { ReferenceComponent } from '../reference/reference.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { MapsFieldConverterService } from '../../services/converters/maps-field-converter.service';
import { IMapsControl } from '../../../typedefinitions/models/controls/IMapsControl';
import { IMarker } from '../../../typedefinitions/models/IMarker';
import { IShapeFile } from '../../../typedefinitions/models/IShapeFile';
import { MapProvider } from '../../../typedefinitions/enums/MapProvider';
import { MapSelectionMode } from '../../../typedefinitions/enums/MapSelectionMode';
import { MapStyle } from '../../../typedefinitions/enums/MapStyle';
import * as i0 from "@angular/core";
type LatLng = {
    lat: number;
    lng: number;
};
/**
 * Maps base component class
 */
export declare abstract class MapsComponent extends ReferenceComponent<IMapsControl> implements OnInit {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Maps component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Toastr service for showing pop up messages
     */
    protected toastr: ToastrService;
    /**
     * Maps field converter service
     */
    protected converter: MapsFieldConverterService;
    /**
     * Character used as a location separator in the string response value.
     * @private
     */
    private LOCATION_SEPARATOR;
    /**
     * Specifies a maps provider. Options are `BingMaps`, `GoogleMaps` and `ArcGis`.
     * @protected
     */
    protected get provider(): MapProvider;
    /**
     * Specifies the marker selection mode. Options are `None`, `Single` and `Multiple`.
     * @protected
     */
    protected get selectionMode(): MapSelectionMode;
    /**
     * Style of the map being rendered. Options are `Road`, `Aerial` and `AerialWithLabels`.
     * @protected
     */
    protected get mapStyle(): MapStyle;
    /**
     * The Geolocation that receives center/focus when the maps control is loaded.
     * Default: field response value if not empty, otherwise the `InitialLocation` from the `dataObject`, otherwise 0,0 (somewhere in the Atlantic).
     * @protected
     */
    protected get initialLocation(): string;
    /**
     * The initial zoom level of the maps view. Values can be any integer from 1 to 20.
     * @protected
     */
    protected get zoomLevel(): number;
    /**
     * The lower limit zoom level of the maps view. This value must be smaller than or equal to the MaxZoomLevel property value.
     * @protected
     */
    protected get minZoomLevel(): number;
    /**
     * The upper limit zoom level of the maps view. This value must be greater than or equal to the MinZoomLevel property value.
     * @protected
     */
    protected get maxZoomLevel(): number;
    /**
     * The maximum number of locations that can be selected/created on the map. Applies only for SelectionMode = Multiple. Default: 1.
     * Similar to the Cardinality of the set control.
     * @protected
     */
    protected get maxLocations(): number;
    /**
     * Flag indicating if the amount of selected locations is below the max location's threshold.
     * When false, the user can no longer add or select locations without removing or deselecting locations first.
     * @protected
     */
    protected get isLocationCountBelowThreshold(): boolean;
    /**
     * Determines whether locations can be added to the map. Default: false
     * @protected
     */
    protected get allowAddLocations(): boolean;
    /**
     * Additional maps layers info. Shapefiles are only supported when using Bing or ArcGIS as maps provider, but differ per provider.
     * @protected
     */
    protected get shapeFiles(): IShapeFile[];
    /**
     * Not supported.
     * @protected
     */
    protected get mapsPath(): string;
    /**
     * Not supported.
     * @protected
     */
    protected get mobilePackage(): string;
    /**
     * The API key is a unique identifier used for authenticating of maps API requests at the selected Provider.
     * @protected
     */
    protected get apiKey(): string;
    /**
     * Flag indicating if the selected and unselected images for markers have been set.
     * @protected
     */
    protected get hasMarkerImages(): boolean;
    /**
     * Resource name of the image that should be used if a geolocation is selected. The image should exist in the resource database. If the property is not set, the default selected marker of the provider is shown.
     * @protected
     */
    protected get selectedImageName(): string;
    /**
     * Media url for the image that should be used if a geolocation is selected.
     * @protected
     */
    protected get selectedImageUrl(): string;
    /**
     * Resource name of the image that should be used for unselected static markers. The image should exist in the resource database. If the property is not set, the default unselected marker of the provider is shown.
     * @protected
     */
    protected get unselectedImageName(): string;
    /**
     * Media url for the image that should be used for unselected static markers.
     * @protected
     */
    protected get unselectedImageUrl(): string;
    /**
     * Retrieves the selected locations from the response value.
     * @protected
     * @returns a list of selected locations from the response value.
     */
    protected get selectedLocations(): string[];
    /**
     * Updates the selected locations in the response value with a given value.
     * Sets the navigation mode to insert mode, executes on-value-changed actions and applies auto-enter logic if required.
     * @param values
     * @protected
     */
    protected set selectedLocations(values: string[]);
    /**
     * The selected user locations from the response value. Filters out selected the static markers from the selected locations of the response value.
     * @returns a list of selected user locations from the response value.
     */
    get selectedUserLocations(): string[];
    /**
     * Static markers that should be shown on the map. These markers can be either selected or unselected, but never be removed from the map.
     */
    get markers(): IMarker[];
    /**
     * Maps base component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param toastr Service for showing pop up messages
     * @param converter Maps field converter service
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Maps component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * Toastr service for showing pop up messages
     */
    toastr: ToastrService, 
    /**
     * Maps field converter service
     */
    converter: MapsFieldConverterService);
    /**
     * Extends the base control's ngOnInit function and check for a provided api key
     */
    ngOnInit(): void;
    /**
     * Activates the field and executes the on-zoom-level-changed actions
     */
    onZoomLevelChanged(): void;
    /**
     * Activates the field and if allowed, adds the selected geolocation to the selected locations in the response value.
     * @param location a comma-separated geolocation's latitude-longitude value.
     * @returns flag indicating if the selected locations have been updated as a result of the click action
     * @protected
     */
    protected onMapsClick(location: string): boolean;
    /**
     * Activates the field and handles the marker click event.
     * User locations are removed when clicked, while for static markers the value of the selected flag is toggled.
     * @param location a comma-separated geolocation's latitude-longitude value.
     * @returns flag indicating if the selected locations have been updated as a result of the click action
     * @protected
     */
    protected onMarkerClick(location: string): boolean;
    /**
     * Handles a static marker's click event.
     * @param marker The marker for which to handle the click event.
     * @returns flag the change to the user locations.
     * @protected
     */
    protected onStaticMarkerClick(marker: IMarker): boolean;
    /**
     * Remove a given user location from the selected locations
     * @param location the user location to remove.
     * @returns flag the change to the user locations.
     * @protected
     */
    protected onUserLocationClick(location: string): boolean;
    /**
     * Converts string coordinates to an object with Latitude-Longitude values
     * @param coords
     * @protected
     */
    protected toLatLng(coords: string): Optional<LatLng>;
    /**
     * Sets the selected flag on a given marker if it is set in the selected locations list and returns the flag's result value.
     * @param marker The marker for which to check, set and return the `Selected` state.
     * @protected
     */
    protected isMarkerSelected(marker: IMarker): boolean;
    /**
     * Removes a given locations from the selected locations list
     * @param location the location to remove from the selected locations list
     * @private
     */
    private spliceLocation;
    static ɵfac: i0.ɵɵFactoryDeclaration<MapsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MapsComponent, "ng-component", never, {}, {}, never, never, false, never>;
}
export {};
