import { ElementRef, ChangeDetectorRef, OnInit, OnDestroy } from '@angular/core';
import { ReferenceComponent } from '../../reference/reference.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { NumberFieldConverterService } from '../../../services/converters/number-field-converter.service';
import { RealFieldConverterService } from '../../../services/converters/real-field-converter.service';
import { IFieldInfo } from '../../../../typedefinitions/models/observables/IFieldInfo';
import { INavigationModeStrategy } from '../../../../typedefinitions/models/INavigationModeStrategy';
import { INumberTextBoxControl } from '../../../../typedefinitions/models/controls/INumberTextBoxControl';
import * as i0 from "@angular/core";
/**
 * Number textbox component class
 */
export declare class NumberTextboxComponent extends ReferenceComponent<INumberTextBoxControl> implements OnInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Number textbox component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Number field converter service
     */
    protected numberConverter: NumberFieldConverterService;
    /**
     * Real field converter service
     */
    protected realConverter: RealFieldConverterService;
    private textChange;
    private textChangeSubscription?;
    private activeControlChangeSubscription?;
    private isBeingEdited;
    private hasDecimals;
    /**
     * Maximum field length input property
     */
    fieldMaxLength: number;
    /**
     * Text value input property
     */
    textValue: string;
    /**
     * When a survey is run on a mobile device AND only simple numeric input is allowed,
     * then the numbers only regular expression pattern is applied via this property to trigger the numeric keyboard
     */
    get pattern(): Optional<string>;
    /**
     * Number textbox class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param numberConverter Number field converter service
     * @param realConverter Real field converter service
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Number textbox component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * Number field converter service
     */
    numberConverter: NumberFieldConverterService, 
    /**
     * Real field converter service
     */
    realConverter: RealFieldConverterService);
    /**
     * Initializes the number textbox component by subscribing to events and assigning settings.
     */
    ngOnInit(): void;
    /**
     * Cleans up resources for this component, such as removing subscriptions.
     */
    ngOnDestroy(): void;
    /**
     * Overrides the implementation to determine the width. The number textbox width depends on the field maximum length and the text-margin.
     */
    setContentWidth(): void;
    /**
     * Handles the change of values of the corresponding field
     * @param fieldInfo updated field info
     */
    handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Processes control changes, extends the base-class method by updating the decimal separator
     * @param newDataObject Updated number textbox data object
     */
    handleControlUpdate(newDataObject: INumberTextBoxControl): void;
    /**
     * Handles any changes in the input field and allows to inspect the whole input value.
     * Should add thousands separator when needed
     * @param event on input event object
     */
    onInput(event: Event): void;
    /**
     * Handles the on focus event of this component.
     */
    onFocus(): void;
    /**
     * Handles the on blur event of the component.
     * Should only adjust the ui when needed, not the DataValue
     */
    onBlur(): void;
    /**
     * Set specific logic for insert strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Retrieves the font css classes (watermark font class included)
     */
    getFontCssClasses(): string[];
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Sets text from a paste command on the component
     * @param text Text to set on the control
     */
    setText(text: string): void;
    /**
     * Clears the text from the component after a cut command
     */
    clearText(): void;
    /**
     * Handles the text-change event (regulated by debouncing the textChanged event)
     * Sets the DataValue
     */
    private pushChange;
    /**
     * Determine if the numeric keyboard should be displayed.
     * The type of input MUST be 'text' because when it's 'numeric' the onInput event differs and causes the input field to accept all characters on mobile devices.
     */
    private displayNumericKeyboard;
    /**
     * Determine if the accepted input only consists of numbers without decimals separator and minus sign.
     */
    private acceptsOnlySimpleNumbers;
    private getConverter;
    /**
     * Adjust the display value of the component
     * @param value
     * @param significantDigits
     */
    private setTextValue;
    private getDecimalSeparator;
    private numberStringContainsDecimals;
    private trySetText;
    private setElementWidth;
    static ɵfac: i0.ɵɵFactoryDeclaration<NumberTextboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NumberTextboxComponent, "bl5-number-textbox", never, { "fieldMaxLength": { "alias": "fieldMaxLength"; "required": false; }; "textValue": { "alias": "textValue"; "required": false; }; }, {}, never, never, false, never>;
}
