import { ElementRef, ChangeDetectorRef, OnInit, OnDestroy } from '@angular/core';
import { BaseComponent } from '../base/base.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { FieldConverterService } from '../../services/converters/field-converter.service';
import { IActionsEventHandler } from '../../../typedefinitions/models/IActionsEventHandler';
import { IControlInfo } from '../../../typedefinitions/models/IControlInfo';
import { IDataValueControl } from '../../../typedefinitions/models/controls/IDataValueControl';
import { IDataValueReference } from '../../../typedefinitions/models/controls/references/IDataValueReference';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IFieldReference } from '../../../typedefinitions/models/controls/references/IFieldReference';
import { IInputControl } from '../../../typedefinitions/models/controls/IInputControl';
import * as i0 from "@angular/core";
/**
 * The `ReferenceComponent` class implements all basic functionality of components with reference
 * fields. These kind of components usually require some user input (e.g. `StringTextboxComponent`).
 */
export declare abstract class ReferenceComponent<T extends IDataValueControl> extends BaseComponent<T> implements OnInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Reference component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    private fieldSubscription?;
    /**
     * The referenced field or field property that is being observed for changes.
     */
    private referenceSubject;
    /**
     * The referenced field or field property info.
     */
    protected get fieldInfo(): Optional<IFieldInfo>;
    /**
     * The referenced field or field property info.
     * This setter triggers the next emit of the field subscription and set the event source ID to the current control.
     * This allows the control to ignore events that were generated by the control itself.
     * @param fieldInfo Field info
     */
    protected set fieldInfo(fieldInfo: Optional<IFieldInfo>);
    /**
     * A boolean that indicates if the control should handle subscription updates that were triggered by itself.
     */
    protected handleOwnSubscriptionUpdates: boolean;
    /**
     * Reference field name
     */
    get fieldName(): string;
    /**
     * Reference field property name
     */
    get fieldPropertyName(): Optional<string>;
    /**
     * Reference component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     */
    protected constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Reference component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef);
    /**
     * Subscribes to reference on component initialisation
     */
    ngOnInit(): void;
    /**
     * Unsubscribe from reference on component destruction
     */
    ngOnDestroy(): void;
    /**
     * Retrieves the input controls for the current reference
     * @returns the reference subjects input controls
     */
    getNeighbours(): IControlInfo[];
    /**
     * Executes all actions defined in a given action event handler on the control
     * @param actionsEventHandler
     * @param fieldInfo
     */
    executeActions(actionsEventHandler: IActionsEventHandler, fieldInfo?: IFieldInfo): void;
    /**
     * Return the array of css classes to apply
     */
    getCssClasses(): string[];
    /**
     * Returns a system text from the system texts dictionary in the control definition
     * @param textId Id of the text
     * @param alt Alternate text to return if the system text is not found, default value is an empty string.
     */
    protected getSystemText(textId: string, alt?: string): string;
    /**
     * Method used to determine an input field's offset width
     * @param maxLength The maximum length property of the field's data value
     * @param placeholderLength The length of the placeholder
     * @param editMaskLength Length of the edit mask if set
     * @returns the offset width based on the given properties
     */
    protected determineOffsetWidth(maxLength: Optional<number>, placeholderLength?: number, editMaskLength?: number): number;
    /**
     * Method used to determine an input field's offset width
     * @param maxCharacters Maximum amount of characters allowed on the input
     * @returns the offset width based on the given properties
     */
    protected determineOffsetWidth2(maxCharacters: number): number;
    /**
     * Checks if the component is an input control
     * @param control Data value control to type check
     */
    protected isInputControl(control: IDataValueControl): control is IInputControl;
    /**
     * Field reference type check cast
     * @param obj Data value reference to type check
     */
    protected hasFieldReference(obj: IDataValueReference): obj is IFieldReference;
    /**
     * Override this method in subclasses to process field changes.
     * @param fieldInfo Updated field info
     */
    protected handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Apply the auto enter logic, using the template method design pattern. The `checkAutoEnter`
     * method can be implemented in overridden classes to apply custom checks.
     * @param autoEnterEnabled Flag indicating whether 'AutoEnter' is enabled (`true`) or not (`false`)
     * @param converter Field converter service
     * @param fieldInfo Field info
     * @param args Optional additional arguments that might be needed to check if the auto-enter should be applied
     */
    protected applyAutoEnter(autoEnterEnabled: boolean, converter: FieldConverterService, fieldInfo: IFieldInfo, args?: any[]): boolean;
    /**
     * Validates if the control is in auto-enter state
     * @param autoEnterEnabled Flag indicating whether 'AutoEnter' is enabled (`true`) or not (`false`)
     * @param converter Field converter service
     * @param fieldInfo Field info
     * @param args Optional additional arguments that might be needed to check if the auto-enter should be applied
     * @returns true, if auto-enter should be applied, otherwise false
     */
    protected checkAutoEnter(autoEnterEnabled: boolean, converter: FieldConverterService, fieldInfo: IFieldInfo, args?: any[]): boolean;
    /**
     * Sets the current field as active field in the render state
     * @param triggerFocus flag
     * @protected
     */
    protected activateField(triggerFocus?: boolean): void;
    /**
     * Perform auto enter action (going to the next field).
     */
    protected doAutoEnter(): void;
    /**
     * Sets up the field subscription for this component.
     */
    private subscribeToReference;
    static ɵfac: i0.ɵɵFactoryDeclaration<ReferenceComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ReferenceComponent<any>, "ng-component", never, {}, {}, never, never, false, never>;
}
