import { ChangeDetectorRef, ElementRef, OnDestroy, OnInit } from '@angular/core';
import { ReferenceComponent } from '../reference/reference.component';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { SetFieldConverterService } from '../../services/converters/set-field-converter.service';
import { CSSStyleObject } from '../../../typedefinitions/models/style/CSSStyleObject';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { ISetTextBoxControl } from '../../../typedefinitions/models/controls/ISetTextBoxControl';
import * as i0 from "@angular/core";
/**
 * Set textbox component class
 */
export declare class SetTextboxComponent extends ReferenceComponent<ISetTextBoxControl> implements OnInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Set textbox component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Set field converter service
     */
    protected converter: SetFieldConverterService;
    /**
     * A string subject observable that allows for text change values to be multicasted to many observables
     */
    private textChange;
    /**
     * Text change subscription
     */
    private textChangeSubscription?;
    /**
     * Sets the default width of the textbox
     */
    private textBoxWidth;
    /**
     * Object used for font style copying
     */
    private fontStyle;
    /**
     * the string value on the input element
     */
    textValue: string;
    /**
     * Value for the size attribute which specifies the visible width, in characters, of the input element
     */
    size: number;
    /**
     * Value for the maxlength attribute which specifies the maximum number of characters allowed in the input element
     */
    maxLength: Optional<number>;
    /**
     * Watermark/placeholder text
     */
    placeholder: string;
    /**
     * Index of the focused option item
     */
    targetIndex: number;
    /**
     * Set textbox component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param converter Set field converter service
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Set textbox component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * Set field converter service
     */
    converter: SetFieldConverterService);
    /**
     * Initializes the set textbox component by subscribing to events and assigning settings.
     */
    ngOnInit(): void;
    /**
     * Cleans up resources for this component by, among other things, removing subscriptions.
     */
    ngOnDestroy(): void;
    /**
     * Overrides the base components set content width function if the control size is set to auto and there are font sizes available by which to determine the width.
     */
    setContentWidth(): void;
    /**
     * Override this method in subclasses to process control changes.
     * @param newDataObject Updated set control data object
     */
    handleControlUpdate(newDataObject: ISetTextBoxControl): void;
    /**
     * Handles change of the value after editing (doesn't fire on every keystroke).
     */
    handleChange(): void;
    /**
     * Event handler triggered by every keystroke
     * @param event
     */
    onInput(event: Event): void;
    /**
     * Handles the onblur event of the component.
     */
    onBlur(): void;
    /**
     * Sets the control's field as visited when the enter key is while pressed on the control's input
     * @param event Keyboard event
     */
    handleKeyDown(event: KeyboardEvent): void;
    /**
     * Set specific logic for keyboard insert strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Retrieves the font css classes (watermark font class included)
     */
    getFontCssClasses(): string[];
    /**
     * Extends the base's get style object method and additionally assigns the font style property
     */
    getStyleObject(): CSSStyleObject;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Sets text from a paste command on the component
     * @param text Text to set on the control
     */
    setText(text: string): void;
    /**
     * Clears the text from the component after a cut command
     */
    clearText(): void;
    /**
     * If the component is subscribed to a field and it's data is changed then this method will be called.
     * Process the updated field in this method.
     * @param fieldInfo Field info
     */
    protected handleFieldUpdate(fieldInfo: IFieldInfo): void;
    private setPlaceholder;
    private pushChange;
    static ɵfac: i0.ɵɵFactoryDeclaration<SetTextboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SetTextboxComponent, "bl5-set-textbox", never, {}, {}, never, never, false, never>;
}
