import { AfterViewInit, ChangeDetectorRef, ElementRef, OnInit, OnDestroy } from '@angular/core';
import { ReferenceComponent } from '../../reference/reference.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { StringFieldConverterService } from '../../../services/converters/string-field-converter.service';
import { CSSStyleObject } from '../../../../typedefinitions/models/style/CSSStyleObject';
import { IFieldInfo } from '../../../../typedefinitions/models/observables/IFieldInfo';
import { IStringDropdownListControl } from '../../../../typedefinitions/models/controls/IStringDropdownListControl';
import { IHasDropdownList } from '../../../../typedefinitions/models/IHasDropdownList';
import { INavigationModeStrategy } from '../../../../typedefinitions/models/INavigationModeStrategy';
import { ISelectListItem } from '../../../../typedefinitions/models/ISelectListItem';
import * as i0 from "@angular/core";
/**
 * String dropdown list component class
 */
export declare class StringDropDownListComponent extends ReferenceComponent<IStringDropdownListControl> implements IHasDropdownList, OnInit, AfterViewInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el dropdown list component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * String field converter service
     */
    protected converter: StringFieldConverterService;
    private controlElementRef;
    private buttonElementRef;
    private watermarkSizerRef;
    private listElementRef;
    private displayTextElementRef;
    /**
     * The height of the selected item
     */
    private selectedItemHeight;
    /**
     * debounced handleKeyEvent
     */
    private debouncedHandleKeyEvent;
    private debouncedHandleKeyEventSubscription?;
    /**
     * Temporary storage for keystrokes
     */
    private keyEvent;
    /**
     * String dropdown list main html element
     */
    private get controlElement();
    /**
     * Watermark sizer div html element
     */
    private get watermarkSizer();
    /**
     * Unsorted list html element
     */
    private get listElement();
    private get displayTextElement();
    /**
     * Css classes to apply on the input element
     */
    inputClasses: string[];
    /**
     * The input element's model
     */
    model: string;
    /**
     * Flag indicating if the dropdown list is open/expanded, used for accessibility
     */
    isExpanded: boolean;
    /**
     * Readonly button id string
     */
    get buttonId(): string;
    /**
     * Value for the maxlength attribute which specifies the maximum number of characters allowed in the input element
     */
    maxLength: Nullable<number>;
    /**
     * The option list element id
     */
    get optionListId(): string;
    /**
     * String dropdown list html button element
     */
    get buttonElement(): HTMLButtonElement;
    /**
     * Watermark/placeholder font
     */
    watermarkFont: string;
    /**
     * Watermark/placeholder font style
     */
    watermarkFontStyleObj: CSSStyleObject;
    /**
     * Select option item list
     */
    optionList: ISelectListItem[];
    /**
     * The longest item text by which to determine the list width
     */
    listItemSizerText: string;
    /**
     * Returns the css classes to apply on the dropdown list items
     */
    get listItemClass(): string[];
    /**
     * Flag indicating if the dropdown option list is populated
     */
    get hasOptions(): boolean;
    /**
     * Readonly property returning the value of the first selected value
     */
    get selectedValue(): string;
    /**
     * Flag indicating whether the list options are currently visible
     */
    get isListOpen(): boolean;
    /**
     * Dropdown option list css classes
     */
    optionListClass: string[];
    /**
     * Dropdown option list css styles object
     */
    optionListStyle: any;
    /**
     * Dropdown option item css styles object
     */
    optionItemStyle: any;
    /**
     * Dropdown option list visible flag
     */
    optionsVisible: boolean;
    /**
     * Dropdown option tab index
     */
    get optionTabIndex(): number;
    /**
     * Index of the focused option item
     */
    targetIndex: number;
    /**
     * Display text for the selected language as shown in the button
     */
    displayText: Optional<string>;
    /**
     * String dropdown list component class constructor
     * @param sp The service provider service provides easy access to several commonly used services
     * @param el Element reference object
     * @param cd Change detector reference object
     * @param converter String field converter service
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el dropdown list component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * String field converter service
     */
    converter: StringFieldConverterService);
    /**
     * Initializes subscriptions
     */
    ngOnInit(): void;
    /**
     * Extends parent control function. Adds scroll event listeners on component initialisation
     */
    ngAfterViewInit(): void;
    /**
     * Performs cleanup tasks on component destruction
     */
    ngOnDestroy(): void;
    /**
     * Handles the onKeyUp event of the component's input element
     */
    onKeyUp(): void;
    /**
     * Handle changed field values
     * @param fieldInfo Updated field info
     */
    handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Override this method in subclasses to process control changes.
     * @param newDataObject Updated dropdown list data object
     */
    handleControlUpdate(newDataObject: IStringDropdownListControl): void;
    /**
     * Calculates the width of the component when set to auto and with stylesheets
     */
    setContentWidth(): void;
    /**
     * Calculates the height of the component when set to auto and with stylesheets
     */
    setContentHeight(): void;
    /**
     * Extends the base class' get css classes function.
     * Returns the array of css classes to apply.
     */
    getCssClasses(): string[];
    /**
     * Overrides the base class' get font css class function and writes the font related classes to an additional separate array
     */
    getFontCssClasses(): string[];
    /**
     * The window resize event triggers the list to hide
     */
    onWindowResize(): void;
    /**
     * The outside click event triggers the list to hide
     */
    onWindowMousedown(event: any): void;
    /**
     * A window swipe event triggers the list to hide
     */
    onWindowTouchMove(event: any): void;
    /**
     * A touch outside event triggers the list to hide
     */
    onWindowTouchEnd(event: any): void;
    /**
     * Handles the click event of the dropdown button
     * @param event Click event object
     */
    handleButtonClick(event: any): void;
    /**
     * Handles any keypress event on the dropdown button
     * @param event Keyboard event object
     */
    handleButtonKeyPress(event: KeyboardEvent): void;
    /**
     * Handles the mouse-over event on the dropdown menu items
     * @param event Click event object
     * @param index number in list
     */
    handleOptionMouseOver(event: Event, index: number): void;
    /**
     * Handles the selection of a value in the dropdown list.
     * @param option
     * @param event MouseEvent
     * @param listItem
     */
    handleOptionClick(option?: ISelectListItem, listItem?: HTMLLIElement, event?: MouseEvent): void;
    /**
     * Hides the option list when the user clicks outside it
     */
    onClickOutside(): void;
    /**
     * Toggle open/close the dropdown list when the space bar was used
     * @param event
     */
    toggleList(event: KeyboardEvent | MouseEvent): void;
    /**
     * Creates an option element id based on the option index
     * @param index Option index
     */
    getOptionId(index: number): string;
    /**
     * Creates an option label element id based on the option value
     * @param value Option value
     */
    getOptionLabelId(value: string): string;
    /**
     * Retrieves an option item by its value
     * @param value Option value
     */
    getOptionItemByValue(value: string): Optional<ISelectListItem>;
    /**
     * Set specific logic for keyboard navigation insert-mode strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for keyboard navigation navigation-mode strategy
     */
    getKeyboardNavigationStrategy(): INavigationModeStrategy;
    /**
     * Retrieves the empty strategy for keyboard
     */
    getKeyboardEmptyStrategy(): INavigationModeStrategy;
    /**
     * Selects a targeted value
     */
    selectValue(): void;
    /**
     * Selects the next page in a list with options that exceed the set page size
     */
    previousPage(): void;
    /**
     * Selects the next page in a list with options that exceed the set page size
     */
    nextPage(): void;
    /**
     * Selects the previous value
     */
    previousValue(): void;
    /**
     * Selects the next value
     */
    nextValue(): void;
    /**
     * Selects the first value
     */
    firstValue(): void;
    /**
     * Selects the last value
     */
    lastValue(): void;
    /**
     * Shows the dropdown option list
     */
    openDropDownList(): void;
    /**
     * Hides the dropdown option list
     */
    closeDropDownList(): void;
    /**
     * Sets focus to the dropdown select button
     */
    focusTextbox(): void;
    /**
     * Sets text from a paste command on the component
     * @param text Text to set on the control
     */
    setText(text: string): void;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Clears the text from the component after a cut command
     */
    clearText(): void;
    /**
     * Resets the option list style and positioning
     */
    protected resetList(): void;
    /**
     * Extends base functionality of the apply-styles-and-dimensions function and applies option list styles
     */
    protected applyStylesAndDimensions(): void;
    /**
     * Applies option list css classes
     */
    private setOptionsListClass;
    private setOptionsListBackgroundStyle;
    private setOptionsListFontStyle;
    /**
     * Populates the options list
     * @param fieldInfo Field info
     */
    private setOptions;
    /**
     * Sets the display text after a field update
     * @param fieldInfo Field info
     */
    private setDisplayText;
    /**
     * Set a single selected option
     * @param value Option value
     */
    private setSingleOption;
    /**
     * Extract the watermark font so that it can be used on the correct items, the button doesn't have a placeholder attribute,
     * use the Font{0}-wm as Font{0} on the select-text <div>
     */
    private setWatermarkFont;
    private hideList;
    /**
     * Resets list style properties
     */
    private applyOptionListStyle;
    private applyFonts;
    /**
     * Determines in which direction the list should show and brings the list into the viewport
     */
    private showList;
    /**
     * Scroll to the list item with the current target index
     */
    private focusTargetIndex;
    private handleKeyEvent;
    private onWindowScroll;
    private onListScroll;
    private getPageSize;
    private clearWatermarkFont;
    private hideListOnExternalEvent;
    static ɵfac: i0.ɵɵFactoryDeclaration<StringDropDownListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<StringDropDownListComponent, "bl5-string-dropdownlist", never, {}, {}, never, never, false, never>;
}
