import { ChangeDetectorRef, ElementRef, OnDestroy, OnInit, AfterViewInit } from '@angular/core';
import { Subject } from 'rxjs';
import { ReferenceComponent } from '../../reference/reference.component';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { FieldConverterService } from '../../../services/converters/field-converter.service';
import { StringFieldConverterService } from '../../../services/converters/string-field-converter.service';
import { IFieldInfo } from '../../../../typedefinitions/models/observables/IFieldInfo';
import { INavigationModeStrategy } from '../../../../typedefinitions/models/INavigationModeStrategy';
import { IStringTextBoxControl } from '../../../../typedefinitions/models/controls/IStringTextBoxControl';
import * as i0 from "@angular/core";
/**
 * String textbox component class
 */
export declare class StringTextboxComponent extends ReferenceComponent<IStringTextBoxControl> implements OnInit, OnDestroy, AfterViewInit {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el String textbox component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * String field converter service
     */
    protected converter: StringFieldConverterService;
    /**
     * Text change subscription
     */
    private textChangeSubscription?;
    /**
     * Sets the default width of the textbox
     */
    private textBoxWidth;
    /**
     * Input validation result flag
     */
    private isInputInvalid;
    /**
     * When set, the edit-mask restricts user input. Used in the view
     */
    private mask;
    private maskModifiers;
    /**
     * input control element reference
     * static : false since it is wrapped in an ngIf or an ngFor, accessible in ngAfterViewInit
     */
    private inputControlRef;
    /**
     * max-length property of string field
     */
    private get maxFieldLength();
    /**
     * Open field textarea indicator flag
     */
    private get isOpenField();
    /**
     * The length of the edit mask
     * @returns {boolean} true when the edit mask is set
     */
    private get editMaskLength();
    /**
     * Flag indicating if the control is not displaying a text area and the edit mask is set
     * @returns {boolean} true when the edit mask is set
     */
    private get hasEditMask();
    private get escapedEditMask();
    /**
     * input control element
     */
    private get inputControl();
    /**
     * columns property of text-area
     */
    cols: number;
    /**
     * rows property of text-area
     */
    rows: number;
    /**
     * A string subject observable that allows for text change values to be multicasted to many observables
     */
    textChange: Subject<string>;
    /**
     * Multi-line string textbox indicator flag
     */
    get isTextArea(): boolean;
    /**
     * max-length property used for determining the maximum amount of characters in a string textbox
     */
    get maxLength(): Optional<number>;
    /**
     * Value for the size attribute which specifies the visible width, in characters, of the input element
     */
    size: number;
    /**
     * the string value on the active input element
     */
    textValue: string;
    get inputType(): string;
    /**
     * String textbox component class constructor
     * @param sp Service provider service
     * @param el Element reference
     * @param cd Change detector reference
     * @param converter String field converter service
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el String textbox component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * String field converter service
     */
    converter: StringFieldConverterService);
    /**
     * Initializes the string textbox component by subscribing to events and assigning settings.
     */
    ngOnInit(): void;
    /**
     * If needed, initializes the edit-mask after the view is initialized
     */
    ngAfterViewInit(): void;
    /**
     * Cleans up resources for this component by, among other things, removing subscriptions.
     */
    ngOnDestroy(): void;
    /**
     * Handles the onblur event of the component
     */
    onBlur(): void;
    /**
     * Handles the oninput event of the component
     * This event occurs before the onKeyUp
     * @param event
     */
    onInput(event: Event): void;
    /**
     * Handles the change of values of the corresponding field
     * @param fieldInfo updated field info
     */
    handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * Processes control changes, extends the base-class method by updating edit-mask settings
     * @param newDataObject updated data object
     */
    handleControlUpdate(newDataObject: IStringTextBoxControl): void;
    /**
     * Overrides the set content width base implementation to determine the width. The string textbox width depends on the field maximum length and the text-margin.
     * This function only executes when Width property is set to auto
     */
    setContentWidth(): void;
    /**
     * Overrides the set content height base implementation to determine the height. The string textbox height depends on the type of control, used font and other variables.
     * This function only executes when Height property is set to auto
     */
    setContentHeight(): void;
    /**
     * Set specific logic for insert strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Retrieves the font css classes (watermark font class included)
     */
    getFontCssClasses(): string[];
    /**
     * Determine the current position of the component.
     */
    getPosition(): Nullable<DOMRect>;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Sets text from a paste command on the component
     * @param text Text to set on the control
     */
    setText(text: string): void;
    /**
     * Clears the text from the component after a cut command
     */
    clearText(): void;
    /**
     * Custom auto enter check: auto-enter is always disabled if the component is a textarea
     * @param autoEnterEnabled Flag indicating if auto-enter should be applied for this field
     * @param converter field converter service
     * @param fieldInfo Field info
     */
    protected checkAutoEnter(autoEnterEnabled: boolean, converter: FieldConverterService, fieldInfo: IFieldInfo): boolean;
    private hasErrors;
    private setTextValue;
    /**
     * @returns mask set (true) or no mask (false)
     */
    private setMask;
    private getMaskOptions;
    /**
     * 'accept' event fired on input when mask value has changed
     * This changes the value
     */
    private onAccept;
    private onComplete;
    private determineEditMaskModifiers;
    private isModifier;
    private isDefaultDefinition;
    private setElementWidth;
    private getEscapedCharacter;
    /**
     * Handles change of the value after editing (doesn't fire on every keystroke).
     */
    private pushChange;
    static ɵfac: i0.ɵɵFactoryDeclaration<StringTextboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<StringTextboxComponent, "bl5-string-textbox", never, {}, {}, never, never, false, never>;
}
