import { ChangeDetectorRef, ElementRef, OnInit, OnDestroy } from '@angular/core';
import { DomSanitizer } from '@angular/platform-browser';
import { BaseComponent } from '../../base/base.component';
import { ComponentService } from '../../../services/component.service';
import { ModelService } from '../../../services/model.service';
import { ServiceProviderService } from '../../../services/serviceprovider.service';
import { CSSStyleObject } from '../../../../typedefinitions/models/style/CSSStyleObject';
import { IBaseComponentViewModel } from '../../../../typedefinitions/models/view/IBaseViewModel';
import { IBaseControl } from '../../../../typedefinitions/models/controls/IBaseControl';
import { IColor } from '../../../../typedefinitions/models/IColor';
import { IGridUnit } from '../../../../typedefinitions/models/IGridUnit';
import { ITableRowComponentViewModel } from '../../../../typedefinitions/models/view/ITableComponentViewModel';
import { ITableRowControl } from '../../../../typedefinitions/models/controls/ITableRowControl';
import { GridType } from '../../../../typedefinitions/enums/GridType';
import * as i0 from "@angular/core";
/**
 * Table row component class
 */
export declare class TableRowComponent extends BaseComponent<ITableRowControl> implements ITableRowComponentViewModel, OnInit, OnDestroy {
    /**
     * model service The model service is a helper service for creating child components
     */
    protected modelService: ModelService;
    /**
     * sp The service provider service provides easy access to several commonly used services
     */
    protected sp: ServiceProviderService;
    /**
     * component service The component service manages page components
     */
    private componentService;
    /**
     * el Component element wrapper
     */
    protected el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * sanitizer Sanitizes a value for use in the given SecurityContext
     */
    private sanitizer;
    private sizeTreeReadySubscription?;
    private get tooltip();
    /**
     * Flag indicating whether showing the tooltip should be disabled or not.
     * It gets disabled when a mobile device is detected or when no tooltip is set.
     * Returns true when the tooltip should be disabled, otherwise false.
     */
    private get isTooltipDisabled();
    /**
     * Index of the current row component in the parent table
     */
    rowIndex: number;
    /**
     * Color of this row
     */
    rowColor: IColor;
    /**
     * Column widths
     */
    columns: IGridUnit[];
    /**
     * Flag indicating if this row should be handled as an even row.
     * This is not determined by the index value alone.
     */
    isEvenRow: boolean;
    /**
     * Setting to determine which grid lines to show
     */
    gridLines: GridType;
    /**
     * Width of the shown grid lines
     */
    gridLineWidth: number;
    /**
     * Color of the shown grid lines
     */
    gridLineColor: IColor;
    /**
     * Aria role attribute
     */
    get role(): string;
    /**
     *
     * @param child
     * @returns
     */
    cellRole(child: IBaseComponentViewModel): string | null;
    get cellScope(): "" | "col";
    /**
     * Control id
     */
    get id(): string;
    /**
     * Row css classes
     */
    rowClass: string;
    /**
     * Row css styles
     */
    rowStyle: any;
    /**
     * Child components
     */
    children: IBaseComponentViewModel[];
    /**
     * Column styles
     */
    columnStyles: any[];
    /**
     * Cell styles
     */
    cellStyles: any[];
    /**
     * List of spanned and therefor skipped columns
     */
    hiddenBecauseOfColumnSpans: boolean[];
    /**
     * Table row component class constructor
     * @param modelService Model service
     * @param sp Service provider service
     * @param componentService Component service
     * @param el Element reference
     * @param cd Change detector reference
     * @param sanitizer Dom sanitizer
     */
    constructor(
    /**
     * model service The model service is a helper service for creating child components
     */
    modelService: ModelService, 
    /**
     * sp The service provider service provides easy access to several commonly used services
     */
    sp: ServiceProviderService, 
    /**
     * component service The component service manages page components
     */
    componentService: ComponentService, 
    /**
     * el Component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * sanitizer Sanitizes a value for use in the given SecurityContext
     */
    sanitizer: DomSanitizer);
    /**
     * Subscribes to the size tree ready event subscription
     */
    ngOnInit(): void;
    /**
     * Unsubscribes from all open subscription
     */
    ngOnDestroy(): void;
    /**
     * Processes control changes
     * @param newDataObject The updated data object
     */
    handleControlUpdate(newDataObject: IBaseControl): void;
    /**
     * Retrieves the column span for a specific child or undefined if there is no span
     * @param index Child's index
     */
    getColumnSpan(index: number): Optional<number>;
    /**
     * Return an array of css classes to apply
     */
    getCssClasses(): string[];
    /**
     * Return css styles to apply
     */
    getStyleObject(): CSSStyleObject;
    /**
     * Mouse over event handler
     * @param event Mouse event
     */ onMouseOver: (event: MouseEvent) => void;
    /**
     * Mouse leave event handler
     */ onMouseLeave: () => void;
    /**
     * Disables the size tree set width function for this component
     */
    sizeTreeSetWidth(): void;
    /**
     * Disables the size tree set height function for this component
     */
    sizeTreeSetHeight(): void;
    /**
     * Disables the size tree ready function for this component
     */
    sizeTreeReady(): void;
    /**
     * Extended entry point for handling styling and dimensions
     */
    protected applyStylesAndDimensions(): void;
    /**
     * Calculates values to assign to the controlSize object
     */
    protected updateControlSize(): void;
    /**
     * Registers the component in the size tree, but doesn't connect it to the tree
     */
    protected configureControlSize(): void;
    /**
     * Retrieves a cell child by column and row index
     * @param children
     * @param col
     * @param row
     */
    private findChild;
    private applyColumnGridLines;
    private applyColumnTextAlignmentStyles;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableRowComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TableRowComponent, "tr[data-bl5-table-row]", never, { "rowIndex": { "alias": "rowIndex"; "required": false; }; "rowColor": { "alias": "rowColor"; "required": false; }; "columns": { "alias": "columns"; "required": false; }; "isEvenRow": { "alias": "isEvenRow"; "required": false; }; "gridLines": { "alias": "gridLines"; "required": false; }; "gridLineWidth": { "alias": "gridLineWidth"; "required": false; }; "gridLineColor": { "alias": "gridLineColor"; "required": false; }; }, {}, never, never, false, never>;
}
