import { ElementRef, ChangeDetectorRef, OnInit, OnDestroy, AfterViewInit } from '@angular/core';
import { ReferenceComponent } from '../reference/reference.component';
import { FieldConverterService } from '../../services/converters/field-converter.service';
import { ServiceProviderService } from '../../services/serviceprovider.service';
import { TimeFieldConverterService } from '../../services/converters/time-field-converter.service';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IHasDropdownList } from '../../../typedefinitions/models/IHasDropdownList';
import { INavigationModeStrategy } from '../../../typedefinitions/models/INavigationModeStrategy';
import { ITimeControl } from '../../../typedefinitions/models/controls/ITimeControl';
import { ITimeViewModel } from '../../../typedefinitions/models/view/ITimeViewModel';
import * as i0 from "@angular/core";
/**
 * Time component class
 */
export declare class TimeComponent extends ReferenceComponent<ITimeControl> implements IHasDropdownList, OnInit, AfterViewInit, OnDestroy {
    /**
     * sp Service provider service
     */
    protected sp: ServiceProviderService;
    /**
     * el Time component element wrapper
     */
    el: ElementRef;
    /**
     * cd Provides change detection functionality
     */
    protected cd: ChangeDetectorRef;
    /**
     * Time field converter service
     */
    protected converter: TimeFieldConverterService;
    /**
     * Time component input field reference
     * static : true since it is not wrapped in an ngIf or an ngFor, accessible in ngOnInit
     */
    private inputContainerRef;
    /**
     * Time component input field reference
     * static : true since it is not wrapped in an ngIf or an ngFor, accessible in ngOnInit
     */
    private inputElRef;
    /**
     * Time picker button element reference
     * static : false since it is wrapped in an ngIf or an ngFor, accessible in ngAfterViewInit
     */
    private buttonRef;
    /**
     * Time picker view component reference
     * static : true since it is not wrapped in an ngIf or an ngFor, accessible in ngOnInit
     */
    private timePickerRef;
    private get inputContainer();
    private get inputElement();
    private get timePickerButton();
    private get timePicker();
    /**
     * Subscription to the application wide scroll event
     */
    private scrollSubscription?;
    private timeChangeSubscription?;
    private activeFieldChangedSubscription?;
    private timeChange;
    /**
     * Edit mask restriction to apply on user input
     */
    private mask;
    /**
     * Flag indicating if time should be included in DataValue
     */
    private includeTime;
    private get cultureInfo();
    private get step();
    /**
     * Host-bound width css style property of the time picker element
     */
    timePickerWidth: Optional<string>;
    /**
     * Host-bound absolute horizontal position of the time picker element relatively to the left side of the page
     */
    timePickerLeft: Optional<string>;
    /**
     * Host-bound absolute vertical position of the time picker element relatively to the top of the page
     */
    timePickerTop: Optional<string>;
    /**
     * Host-bound background style of the time picker element
     */
    timePickerBackground: Optional<string>;
    /**
     * Selected or user inputted time
     */
    model: Nullable<string>;
    /**
     * Maximum field length property
     */
    fieldMaxLength: number;
    /**
     * Time picker css classes
     */
    timePickerClasses: string[];
    /**
     * Input element's css classes
     */
    inputClasses: string[];
    /**
     * Input element's css style object
     */
    inputStyle: any;
    /**
     * Time picker option list's style object
     */
    dropdownStyle: any;
    /**
     * Time picker options
     */
    timeViews: ITimeViewModel[];
    /**
     * Flag indicating if the time picker button and option list are available for use
     */
    hasTimePickerAppearance: boolean;
    /**
     * Flag indicating if any of the time picker option list is currently visible
     */
    timePickerIsVisible: boolean;
    /**
     * Aria accessibility flag property is expanded. True when the date picker is visible, otherwise false.
     */
    isExpanded: boolean;
    /**
     * Index of the time picker's option list's focused option item
     */
    targetIndex: number;
    /**
     * Readonly time picker button id string
     */
    get buttonId(): string;
    /**
     * Readonly time list id string
     */
    get listId(): string;
    /**
     * Readonly time option tab index
     */
    get optionTabIndex(): number;
    /**
     * Time component class constructor
     * @param sp Service provider service
     * @param el Element wrapper reference object
     * @param cd Change detector reference
     * @param converter Time field converter service
     */
    constructor(
    /**
     * sp Service provider service
     */
    sp: ServiceProviderService, 
    /**
     * el Time component element wrapper
     */
    el: ElementRef, 
    /**
     * cd Provides change detection functionality
     */
    cd: ChangeDetectorRef, 
    /**
     * Time field converter service
     */
    converter: TimeFieldConverterService);
    /**
     * A callback method that is invoked immediately after the default change detector has checked the directive's data-bound properties for the first time,
     * and before any of the view or content children have been checked.
     * It is invoked only once when the directive is instantiated.
     * Extends the parent control's on init function, adds event listeners and subscriptions.
     */
    ngOnInit(): void;
    /**
     * A callback method that performs custom clean-up, invoked immediately after the directive is destroyed, extends the base control function.
     * Extends the parent control's on destroy function, un-subscribes from all subscriptions.
     */
    ngOnDestroy(): void;
    /**
     * Sets the edit-mask after view initialization
     */
    ngAfterViewInit(): void;
    /**
     * Fired on every keystroke before target value is adjusted
     * This event only occurs when EditMask is disabled, so it should only be used to
     * change the view model.
     * @param event Event
     */
    onInput(event: Event): void;
    /**
     * Whenever the focus event is triggered, notify the edit-mask
     */
    onFocus: () => void;
    /**
     * Handles the onblur event of the component.
     */
    onBlur(): void;
    /**
     * Handles the oncomplete event of the edit mask
     * @param event
     */
    onComplete(event: InputEvent): void;
    /**
     * Window resize listener/handler that hides the list when triggered
     */
    onWindowResize(): void;
    /**
     * If the component is subscribed to a field and it's data is changed, this method will be called by the base component.
     * Process the updated field in this method.
     * @param fieldInfo updated field info
     */
    handleFieldUpdate(fieldInfo: IFieldInfo): void;
    /**
     * The component is subscribed to a control and it's data is changed, this method will be called by the base component.
     * Process the updated control in this method
     * @param newDataObject TimeControl
     */
    handleControlUpdate(newDataObject: ITimeControl): void;
    /**
     * Updates the data value and executes actions when the selected/set time has changed
     */
    handleChange(): void;
    /**
     * Shows/Hides the time list
     * @param event Event
     */
    toggleTimePicker(event: Event): void;
    /**
     * Hides the time list
     */
    closeTimePicker(): void;
    /**
     * Handles the time list item click event
     * @param time Selected time
     * @param event Keyboard/Mouse event
     */
    selectTime(time: any, event: KeyboardEvent | MouseEvent): void;
    /**
     * Retrieves font css classes, extends the parent function
     */
    getFontCssClasses(): string[];
    /**
     * Overrides the base components set content width function if the control size is set to auto and there are font sizes available by which to determine the width.
     */
    setContentWidth(): void;
    /**
     * Set specific logic for keyboard navigation insert-mode strategy
     */
    getKeyboardInsertStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for keyboard navigation navigation-mode strategy
     */
    getKeyboardNavigationStrategy(): INavigationModeStrategy;
    /**
     * Set specific logic for keyboard navigation in accessibility-mode strategy
     */
    getKeyboardEmptyStrategy(): INavigationModeStrategy;
    /**
     * Flag indicating whether the times list is currently visible
     */
    get isListOpen(): boolean;
    /**
     * Selects a targeted value
     */
    selectValue(): void;
    /**
     * Selects the next page in a list with options that exceed the set page size
     */
    previousPage(): void;
    /**
     * Selects the next page in a list with options that exceed the set page size
     */
    nextPage(): void;
    /**
     * Selects the previous value
     */
    previousValue(): void;
    /**
     * Selects the next value
     */
    nextValue(): void;
    /**
     * Selects the first value
     */
    firstValue(): void;
    /**
     * Selects the last value
     */
    lastValue(): void;
    /**
     * Shows the times list
     */
    openDropDownList(): void;
    /**
     * Hides the times list
     */
    closeDropDownList(): void;
    /**
     * Sets focus to the time input field
     */
    focusTextbox(): void;
    /**
     * Creates time list item ids based on their index
     * @param index index
     */
    getTimeListItemId(index: number): string;
    /**
     * Retrieves the component's text for a copy or cut command
     * @returns plain component text
     */
    getText(): string;
    /**
     * Clears the text from the component after a cut command
     */
    clearText(): void;
    /**
     * Overridden method to apply custom auto enter checking for the date component.
     */
    protected checkAutoEnter(autoEnterEnabled: boolean, converter: FieldConverterService, fieldInfo: IFieldInfo): boolean;
    private setTextValue;
    private isTimePickerLeftAligned;
    /**
     *
     * @param event
     */
    private showTimePicker;
    private resetTimePicker;
    /**
     * Generate time elements for the view
     */
    private generateTimes;
    /**
     * Set target index by the current text value
     */
    private configureTargetIndex;
    private applyBackground;
    private calculatePosition;
    /**
     * Scroll to the list item with the current target index
     */
    private focusTargetIndex;
    private getPageSize;
    /**
     * Determine if the control should render with high contrast colors or not
     */
    private isHighContrast;
    private onWindowScroll;
    private applyFont;
    /**
     * Should adjust the pattern when the edit mask is enabled
     * @returns
     */
    private formatShortTimePattern;
    /**
     * Sets the edit mask on the selected element
     */
    private setMask;
    /**
     * Create the EditMask object
     */
    private createMask;
    static ɵfac: i0.ɵɵFactoryDeclaration<TimeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TimeComponent, "bl5-time", never, {}, {}, never, never, false, never>;
}
