import { HttpClient } from '@angular/common/http';
import { EventService } from '../event.service';
import { PayloadService } from '../payload.service';
import { AuditTrailServerInfoService } from './audit-trail-server-info.service';
import { IAuditTrailEvent } from '../../../typedefinitions/events/IAuditTrailEvent';
import { ICustomAuditTrailEvent } from '../../../typedefinitions/events/ICustomAuditTrailEvent';
import { IAuditTrailService } from '../../../typedefinitions/services/IAuditTrailService';
import { AnswerStatus } from '../../../typedefinitions/enums/AnswerStatus';
import { AuditTrailLevel } from '../../../typedefinitions/enums/AuditTrailLevel';
import * as i0 from "@angular/core";
/**
 * The audit trail service provides functionality for tracking user behaviour
 */
export declare class AuditTrailService implements IAuditTrailService {
    private eventService;
    private payloadService;
    private serverInfoService;
    private http;
    /**
     * Audit trail http post path
     */
    private _auditTrailPath;
    /**
     * The audit trail configuration array (server info and audit trail level).
     */
    private configArr;
    /**
     * Index of the current configuration
     */
    private configIndex;
    /**
     * The audit trail per configuration
     */
    private trailArr;
    /**
     * The maximum number of audit events to send along with a http post to the server.
     */
    private maxPayloadEvents;
    /**
     * The time in milliseconds to poll for events.
     */
    private pollingInterval;
    /**
     * Maximum number of simultaneous audit trail http requests
     */
    private maxConcurrentRequests;
    /**
     * The observable interval timer.
     */
    private timer;
    /**
     * The subscription to the interval timer.
     */
    private timerSubscription?;
    /**
     * Field changed subscription
     */
    private fieldChangedSubscription?;
    /**
     * Flag indicator that shows if the audit trail has a configuration set and thus is active, or not
     */
    private get isActive();
    /**
     * Current active audit trail configuration
     */
    private get config();
    /**
     * Audit trails in wait, grouped by configuration
     */
    private get trail();
    /**
     * Flag indicator for outstanding audit-trail send-events
     */
    get hasOutStandingEvents(): boolean;
    /**
     * Get outstanding audit-trail send-events
     */
    get outStandingEvents(): IAuditTrailEvent[];
    /**
     * Get the current timestamp in the correct format
     * e.g. 2014-01-05T09:24:45.003+05:00
     */
    get timeStamp(): string;
    /**
     * Audit trail http post path getter
     */
    get auditTrailPath(): string;
    /**
     * Audit trail http post path setter
     */
    set auditTrailPath(path: string);
    /**
     * Audit trail service class constructor
     * @param eventService Central hub containing global application events
     * @param payloadService Constructs server payloads for services' http requests
     * @param serverInfoService Central hub for managing audit trail server info.
     * @param http Http-client injectable class with methods to perform HTTP requests
     */
    constructor(eventService: EventService, payloadService: PayloadService, serverInfoService: AuditTrailServerInfoService, http: HttpClient);
    /**
     * Subscribes to the audit trail server info service subscription
     */
    initialize(): void;
    /**
     * Logs an action event if the minimum audit trail level for this action meets the configured  level
     * @param actionName Name of the action to log
     * @param controlId Id of the control on which the action has taken place
     * @param minimumLevel Minimum audit trail log level to meet for the logging to take place, default is Answer
     * @param args (optional) Extra optional arguments to add to the log message.
     */
    logActionEvent(actionName: string, controlId: string, minimumLevel?: AuditTrailLevel, args?: string[]): void;
    /**
     * Logs a keystroke event if the minimum audit trail level for this action meets the configured level
     * @param event The keystroke event to log
     */
    logKeyStrokeEvent(event: KeyboardEvent): void;
    /**
     * Logs an enter field event if the configured audit trail level is `Field` or higher
     * @param fieldName Name of the entered field
     * @param answerStatus Current answer status of the entered field
     * @param value Current value as string or special answer value of the entered field
     * @param isSpecialAnswer If true, the value is a special answer value with an answer status of 2.
     */
    logEnterFieldEvent: (fieldName: string, answerStatus: AnswerStatus, value: string, isSpecialAnswer: boolean) => void;
    /**
     * Logs a leave field event if the configured audit trail level is `Field` or higher
     * @param fieldName Name of the field that has been left
     * @param answerStatus Current answer status of the left field
     * @param value Current value as string or special answer value of the left field
     * @param isSpecialAnswer If true, the value is a special answer value with an answer status of 2.
     */
    logLeaveFieldEvent: (fieldName: string, answerStatus: AnswerStatus, value: string, isSpecialAnswer: boolean) => void;
    /**
     * Logs a classify event if the configured audit trail level is `Answer` or higher
     * @param code Currently selected classification event code
     * @param classificationAction Classification action code (eg. Expand, Select)
     */
    logClassifyEvent: (code: string, classificationAction: string) => void;
    /**
     * Logs a category event if the configured audit trail level is `Answer` or higher
     * @param isSelected True if the category is checked/selected, otherwise false.
     * @param code The code of the category (radio) button or checkbox for which the value was changed
     */
    logCategoryEvent: (isSelected: boolean, code: number) => void;
    /**
     * Logs a special answer event if the configured audit trail level is `Answer` or higher
     * @param isSelected True if the special is selected, otherwise false.
     * @param name Special answer name
     */
    logSpecialAnswerEvent: (isSelected: boolean, name: string) => void;
    /**
     * Logs a go to uri event if the configured audit trail level is `Answer` or higher
     * @param uri The destination uri
     */
    logGoToURIEvent: (uri: string) => void;
    /**
     * Logs a toggle visibility event if the configured audit trail level is `Answer` or higher
     * @param controlName The name of the control for which the visibility has changed
     */
    logToggleVisibilityEvent: (controlName: string) => void;
    /**
     * Logs an enter field property event if the configured audit trail level is `Answer` or higher
     * @param fieldName Name of the field of which a field property's control has been entered
     * @param fieldPropertyName Name of the field's property of which a control has been entered
     * @param value Current value of the entered field property
     */
    logEnterFieldPropertyEvent: (fieldName: string, fieldPropertyName: string, value: string) => void;
    /**
     * Logs a leave field property event if the configured audit trail level is `Answer` or higher
     * @param fieldName Name of the field of which a field property's control has been left
     * @param fieldPropertyName Name of the field's property of which a control has been left
     * @param value Current value of the left field property
     */
    logLeaveFieldPropertyEvent: (fieldName: string, fieldPropertyName: string, value: string) => void;
    /**
     * Logs a custom collection of properties to the audit trail if audit trail is enabled.
     * @param eventData Collection of properties.
     */
    logCustomAuditTrailEvent: (eventData: ICustomAuditTrailEvent) => void;
    /**
     * Logs a range error event if the configured audit trail level is `Answer` or higher
     * @param fieldName Name of the field which is involved with the range error
     * @param value The current value which triggered the range error
     * @param answerStatus The current answer status of the field
     * @param errorMessage The error message
     */
    logRangeErrorEvent: (fieldName: string, value: string, answerStatus: string, errorMessage: string) => void;
    /**
     * Add settings to the audit logging config and subscribe to events
     */
    private activateAuditLogging;
    /**
     * Ends all subscriptions
     */
    private deactivateAuditLogging;
    /**
     * Get the value as string or special answer string of given field, depending on the answer status.
     * @param fieldInfo Field info
     * @returns value as string or special answer string
     */
    private getFieldAnswerValue;
    /**
     * Checks if the answers status of a field indicates a special answer.
     * @param {IFieldInfo} fieldInfo Field info
     * @returns {boolean} true if the answers status of a field indicates a special answer, otherwise false
     */
    private fieldHasSpecialAnswer;
    /**
     * Starts to poll for work (if not already polling)
     */
    private pollWork;
    /**
     * Stop polling for work by unsubscribing from the timer.
     */
    private stopPolling;
    /**
     * Persistence loop
     */
    private processWork;
    /**
     * Formats keystroke events
     * @param arr Audit-trail event list
     */
    private prepareAuditTrailEvents;
    /**
     * Escapes a string value and returns the replacement string
     * @param value string text to escape
     */
    private escapeValue;
    /**
     * Checks if the last event is a keystroke event
     */
    private lastEventIsKeyStroke;
    /**
     * Generates an action audit trail event
     * @param actionName Name of the action event
     * @param controlId Name of the control that triggered the action event
     * @param args Additional action event arguments
     */
    private createActionEvent;
    /**
     * Generates an enter field audit trail event
     * @param fieldName
     * @param answerStatus
     * @param value
     * @param specialAnswer
     */
    private createEnterFieldEvent;
    /**
     * Generates a leave field audit trail event
     * @param fieldName
     * @param answerStatus
     * @param value
     * @param specialAnswer
     */
    private createLeaveFieldEvent;
    /**
     * Generates a enter/leave field audit trail event
     * @param enter
     * @param fieldName
     * @param answerStatus
     * @param value
     * @param specialAnswer
     */
    private createFieldEvent;
    private createCategoryEvent;
    private createSpecialAnswerEvent;
    private createGoToURIEvent;
    private createToggleVisibilityEvent;
    private createClassifyEvent;
    private createRangeErrorEvent;
    private formatKeyboardEvent;
    /**
     * Generates a enter field property audit trail event
     * @param fieldName
     * @param fieldPropertyName
     * @param value
     * @return audit-trail event
     */
    private createEnterFieldPropertyEvent;
    /**
     * Generates a leave field property audit trail event
     * @param fieldName
     * @param fieldPropertyName
     * @param value
     * @return audit-trail event
     */
    private createLeaveFieldPropertyEvent;
    /**
     * Generates event string for custom audit trail event properties
     * @param customEvent
     */
    private createCustomAuditTrailEvent;
    /**
     * Generates a enter/leave field property audit trail event
     * @param enter
     * @param fieldName
     * @param fieldPropertyName
     * @param value
     * @return audit-trail event
     */
    private createFieldPropertyEvent;
    private createKeyStroke;
    private createEvent;
    static ɵfac: i0.ɵɵFactoryDeclaration<AuditTrailService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AuditTrailService>;
}
