import { FunctionService } from './function.service';
import { HelperService } from '../helper.service';
import { NavigationService } from '../navigation/navigation.service';
import { RenderStateService } from '../renderstate.service';
import { UserAgentService } from '../user-agent.service';
import { IDictionary } from '../../../typedefinitions/models/IDictionary';
import { IExpression } from '../../../typedefinitions/models/expressions/IExpression';
import * as i0 from "@angular/core";
/**
 * The expression service provides functionality for evaluating client side expressions
 */
export declare class ExpressionService {
    private functionService;
    private helperService;
    private navigationService;
    private renderStateService;
    private userAgentService;
    private readonly expressionEvaluator;
    private readonly methodCallExpressionEvaluator;
    private readonly atomicNameExpressionEvaluator;
    private readonly childPropertyValueRetriever;
    /**
     * Expression user defined atomic name properties placeholder
     */
    atomicNameProperties: IDictionary<any>;
    /**
     * Expression service class constructor
     * @param functionService
     * @param helperService
     * @param navigationService
     * @param renderStateService
     * @param userAgentService
     */
    constructor(functionService: FunctionService, helperService: HelperService, navigationService: NavigationService, renderStateService: RenderStateService, userAgentService: UserAgentService);
    /**
     * Evaluates an expression object
     * @param expression evaluation expression
     * @returns expression evaluation result
     */
    evaluateExpression(expression: IExpression): any;
    private createExpressionEvaluator;
    private createMethodCallExpressionEvaluator;
    private createAtomicNameExpressionEvaluator;
    private createChildPropertyValueRetriever;
    /**
     * Evaluates a function expression
     * @param expression
     * @returns expression evaluation result
     */
    private evaluateAppliedFunctionExpression;
    /**
     * Evaluates a method call expression
     * @param expression
     * @returns expression evaluation result
     */
    private evaluateMethodCallExpression;
    /**
     * Evaluates an atomic name expression
     * @param expression
     * @returns expression evaluation result
     */
    private evaluateAtomicNameExpression;
    /**
     * Evaluates a composite name expression
     * @param expression
     * @returns expression evaluation result
     */
    private evaluateComposedNameExpression;
    /**
     * Evaluates an integer constant expression
     * @param expression
     * @returns the constant expression value
     */
    private evaluateIntegerConstantExpression;
    /**
     * Evaluates a string constant expression
     * @param expression
     * @returns the constant expression value
     */
    private evaluateStringConstantExpression;
    /**
     * Evaluates a boolean constant expression
     * @param expression
     * @returns the constant expression value
     */
    private evaluateBooleanConstantExpression;
    /**
     * Evaluates an enumeration value constant expression
     * @param expression
     * @returns the constant expression value
     */
    private evaluateEnumerationConstantExpression;
    /**
     * Evaluates an indexed name expression
     * @param expression object containing a collection and an index number
     * @returns An item from a given/referenced collection by a given/referenced index number
     */
    private evaluateIndexedNameExpression;
    /**
     * Evaluates a conditional expression
     * @param expression object containing a condition, then and else value
     * @returns the then or else expression's result value, depending on the evaluation result of the condition
     * (when the condition result is truthy, the then value's expression result is returned, otherwise we return the else value's expression result)
     */
    private evaluateConditionalExpression;
    /**
     * Evaluates an real constant expression
     * @param expression
     * @returns the constant expression value
     */
    private evaluateRealConstantExpression;
    /**
     * Evaluates an set constant expression
     * @param expression
     * @returns the constant expression value
     */
    private evaluateSetConstantExpression;
    /**
     * Evaluates an range collection expression
     * @param expression
     * @returns the constant expression value
     */
    private evaluateRangeCollectionExpression;
    /**
     * Evaluates a get field method call expression
     * @param fields
     * @param args first argument is the field name
     */
    private callGetField;
    /**
     * Evaluates a get item method call expression
     * @param obj array of objects with a name property
     * @param args value of the first argument is the name of the item to return
     */
    private callGetItem;
    /**
     * Evaluates a get category method call expression
     * @param field containing a value type with categories
     * @param args value of the first argument is the code of category to return
     * @returns object containing field/definition name as name and category code as value
     */
    private callGetCategory;
    /**
     * Evaluates a get property method call expression
     * @param properties
     * @param args value of the first argument is the property name of the property to return
     * @returns a field property
     */
    private callGetProperty;
    /**
     * Evaluates a get property method call expression
     * @param obj object containing route items
     * @param args value of the first argument is the include-groups-flag
     * @returns an error list
     */
    private callGetErrors;
    /**
     * Evaluates if a field contains a given special answer
     * @param field
     * @param args value of the first argument is the special answer value to validate
     * @returns true, if the special answer is allowed for the given field, otherwise false
     */
    private callIsSpecialAnswerAllowed;
    /**
     * Evaluates a get category by code method call expression
     * @param field
     * @param args value of the first argument is the code of category to return
     * @returns object containing field/definition name as name and category code as value
     */
    private callGetCategoryByCode;
    /**
     * Evaluates a get category by name method call expression
     * @param field
     * @param args value of the first argument is the name of category to return
     * @returns object containing field/definition name as name and category code as value
     */
    private callGetCategoryByName;
    /**
     * Evaluates a get role texts method call expression
     * @param routeItem
     * @param args value of the first argument is the name of role-text to return
     * @returns a role text if found, otherwise null
     */
    private callGetRoleText;
    /**
     * Evaluates a role text exists method call expression
     * @param routeItem
     * @param args value of the first argument is the name of role-text to check
     * @returns true, if the role text exists, otherwise false
     */
    private callRoleTextExists;
    /**
     * Retrieves a textbox from the text provider
     * @param textProvider Text provider object from the render state
     * @param args value of the first argument is the id of the textbox
     * @returns text box
     */
    private callGetTextbox;
    /**
     * Retrieves the first eligible item from a given collection
     * @param collection items to evaluate
     * @param args the first argument in this list is the expression against which the collection items are evaluated
     * @returns first eligible item
     */
    private callFirst;
    /**
     * Retrieves the last eligible item from a given collection
     * @param collection items to evaluate
     * @param args the first argument in this list is the expression against which the collection items are evaluated
     * @returns last eligible collection item
     */
    private callLast;
    /**
     * Checks if any items of a given collection are eligible
     * @param collection items to evaluate
     * @param args the first argument in this list is the expression against which the collection items are evaluated
     * @returns true, if an eligible item exists, otherwise false
     */
    private callExists;
    /**
     * Checks if all items in a given collection are eligible
     * @param collection to evaluate
     * @param args the first argument in this list is the expression against which the collection items are evaluated
     * @returns true, if all items in the collection are eligible, otherwise false
     */
    private callAll;
    /**
     * Counts the eligible items in a collection
     * @param collection to evaluate
     * @param args the first argument in this list is the expression against which the collection items are evaluated
     * @returns number of eligible items in the collection
     */
    private callCount;
    /**
     * Retrieves the lowest value in an expression result collection
     * @param collection to evaluate
     * @param args the first argument in this list is the expression against which the collection items are evaluated
     * @returns the lowest value in an expression result collection
     */
    private callMin;
    /**
     * Retrieves the highest value in an expression result collection
     * @param collection to evaluate
     * @param args the first argument in this list is the expression against which the collection items are evaluated
     * @returns the highest value in an expression result collection
     */
    private callMax;
    private callSum;
    /**
     * Retrieves the value type property from a field or field property
     * @param obj
     * @returns value type
     */
    private getValueType;
    /**
     * Retrieves the data type property from a field or field property's value type
     * @param obj field or field property
     * @returns enum value
     */
    private getDataType;
    /**
     * Evaluates a field or field property's data type
     * @param obj field or field property
     * @param dataType
     * @returns evaluation result
     */
    private isDataType;
    /**
     * Retrieves the value as string from the data value of a field or field property
     * @param obj field or field property
     */
    private getStringValue;
    /**
     * Retrieves the value as string from the data value of a field or field property
     * @param obj field or field property
     */
    private getAnswerStatus;
    /**
     * Retrieves the value as string from the data value of a field or field property
     * @param obj field or field property
     */
    private getValueAsString;
    /**
     * Retrieves the special answer from the data value of a field or field property
     * @param obj field or field property
     */
    private getSpecialAnswer;
    /**
     * Return filename string from blob datatype
     * @param obj field or field property
     */
    private getBlobFilename;
    /**
     * Retrieves the value as string from the data value of a field or field property and parses it into an integer
     * @param obj field or field property
     */
    private getValueAsInteger;
    /**
     * Retrieves the value as string from the data value of a field or field property and parses it into a floating point
     * @param obj field or field property
     */
    private getValueAsDecimal;
    /**
     * Retrieves the first error with the is relevant flag active from a list of errors
     * @param errors
     * @returns error
     */
    private findFirstRelevantError;
    /**
     * Retrieves errors from route items
     * @param routeItems
     * @param includeGroups
     * @returns error list
     */
    private getErrors;
    private getPropertyValue;
    /**
     * Tries to get a property value from an object, if needed checks the case-insensitive equivalent of the property names
     * @param obj object from which to retrieve a value
     * @param propertyName object property's name
     * @return property value or false
     */
    private getCaseInsensitivePropertyValue;
    private getCategoryBy;
    private callMinMax;
    private setReturnType;
    static ɵfac: i0.ɵɵFactoryDeclaration<ExpressionService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ExpressionService>;
}
