import { DateTime } from 'luxon';
import { FieldConverterService } from './field-converter.service';
import { CultureInfoService } from '../culture-info.service';
import { ICultureInfo } from '../../../typedefinitions/models/ICultureInfo';
import { IDateConstraints } from '../../../typedefinitions/models/controls/properties/date-picker-settings/IDateConstraints';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IValueType } from '../../../typedefinitions/models/value-types/IValueType';
import { RangeCheckResult } from '../../../typedefinitions/enums/RangeCheckResult';
import * as i0 from "@angular/core";
/**
 * Date field converter service class
 */
export declare class DateFieldConverterService extends FieldConverterService {
    /**
     * cultureInfoService Service used for storing and consulting culture settings
     */
    protected cultureInfoService: CultureInfoService;
    /**
     * Culture Info Service's Culture Info
     * @protected
     */
    protected get cultureInfo(): ICultureInfo;
    private get sanitizedShortDateFormat();
    /**
     * Date field converter service class constructor.
     * @param cultureInfoService Service used for storing and consulting culture settings
     */
    constructor(
    /**
     * cultureInfoService Service used for storing and consulting culture settings
     */
    cultureInfoService: CultureInfoService);
    /**
     * Convert the answer as string to its value-type
     * @param fieldInfo Field info
     */
    convertToDateTime(fieldInfo: IFieldInfo): Nullable<DateTime>;
    /**
     * When a valid date is given, formats and places it on the data model. Otherwise, the given date is used as is.
     * @param date given date value object or string
     * @param fieldInfo Field info
     */
    setDate(date: string | DateTime, fieldInfo: IFieldInfo): void;
    /**
     * Validates the input value against any restrictions defined on the value type
     * @param date
     * @param valueType
     * @returns range check result
     */
    isValid(date: Nullable<string | DateTime>, valueType: IValueType): RangeCheckResult;
    /**
     * Configure errors for the field and returns whether something was modified in the error collection.
     * @param date the value as string
     * @param fieldInfo field info
     */
    applyErrors(date: Nullable<string | DateTime>, fieldInfo: IFieldInfo): boolean;
    /**
     * Validates the input value
     * @param value
     * @param valueType
     * @returns range check result
     */ isAllowed(value: string, valueType: IValueType): RangeCheckResult;
    /**
     * Check if the string is the same as the ValueAsString
     * @param value
     * @param dateFormat
     * @param fieldInfo
     * @returns
     */
    isSame: (value: string, dateFormat: string, fieldInfo: IFieldInfo) => boolean;
    /**
     * Checks if the given date is not listed as disabled.
     * @param {DateTime} date the date to validate.
     * @param {IDateConstraints} dateConstraints restrictions on the selectable and shown dates.
     * @returns {boolean} true if the date is within bounds, otherwise false.
     */
    dateIsEnabled(date: DateTime, { EnabledDays, DisabledDays, DayFilter }: IDateConstraints): boolean;
    /**
     * Check if a given date is within range
     * @param {DateTime} date the date to validate.
     * @param {IDateConstraints} dateConstraints restrictions on the selectable and shown dates.
     * @returns {boolean} true if the date is within bounds, otherwise false.
     */
    private dateIsWithinRange;
    /**
     * Check if a given date is within range
     * @param {DateTime} date the date to validate
     * @param {Optional<number>} minDate the date's lower bound value in milliseconds.
     * @returns {boolean} true if the date is within bounds, otherwise false.
     */
    private dateIsAfterMinDate;
    /**
     * Check if a given date is within range
     * @param {DateTime} date the date to validate.
     * @param {Optional<number>} maxDate the date's upper bound value in milliseconds.
     * @returns {boolean} true if the date is within bounds, otherwise false.
     */
    private dateIsBeforeMaxDate;
    static ɵfac: i0.ɵɵFactoryDeclaration<DateFieldConverterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DateFieldConverterService>;
}
