import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { IEnumerationType } from '../../../typedefinitions/models/value-types/IEnumerationType';
import { IIntegerType } from '../../../typedefinitions/models/value-types/IIntegerType';
import { IValueType } from '../../../typedefinitions/models/value-types/IValueType';
import { RangeCheckResult } from '../../../typedefinitions/enums/RangeCheckResult';
/**
 * The FieldConverterService is the base class for all data type specific converters.
 * Converters are responsible for validating input and setting the correct errors as
 * well as converting the input value to a string suitable for the server.
 */
export declare abstract class FieldConverterService {
    /**
     * Tests if an input string matches the requirements of the field definition.
     * @param input
     * @param valueType
     */
    abstract isValid(input: string, valueType: IValueType): RangeCheckResult;
    /**
     * Tests if an input string contains allowed characters.
     * @param input
     * @param valueType
     */
    abstract isAllowed(input: string, valueType: IValueType): RangeCheckResult;
    /**
     * Sanitize the value against the DataValue
     * @param value
     * @param valueType
     */ sanitize: (value: string, valueType: IValueType) => string;
    /**
     * Returns the string interpretation of the value residing in the provided data value subscription.
     * @param fieldInfo Field info
     */
    convertToString(fieldInfo: IFieldInfo): string;
    /**
     * Configure the answer object for a regular answer.
     * @param valueStr The answer value
     * @param fieldInfo Field info
     */
    setNormalAnswer(valueStr: string, fieldInfo: IFieldInfo): void;
    /**
     * Clear the answer value and set the status to empty.
     * @param fieldInfo Field info
     */
    setEmptyAnswer(fieldInfo: IFieldInfo): void;
    /**
     * Configure the answer object for a special answer.
     * @param valueStr The answer value string
     * @param fieldInfo Field info
     */
    setSpecialAnswer(valueStr: string, fieldInfo: IFieldInfo): void;
    /**
     * Get the response answer as a string value. Returns an empty string
     * if the answer status of the data value is not of type `AnswerStatus.Response`.
     * @param fieldInfo Field info
     */
    getNormalAnswerAsString(fieldInfo: IFieldInfo): string;
    /**
     * Get the special answer as a string value. Returns an empty string
     * if the answer status of the data value is not of type `AnswerStatus.SpecialAnswer`.
     * @param fieldInfo Field info
     */
    getSpecialAnswerAsString(fieldInfo: IFieldInfo): string;
    /**
     * Return the 'value as string' if the field has an answer or special answer.
     * Else an empty string is returned.
     * @param fieldInfo Field info
     */
    getAnswerAsString(fieldInfo: IFieldInfo): string;
    /**
     * Default auto enter logic.
     * @param fieldInfo Field info
     * @param args Optional additional arguments that might be needed to check if the auto-enter should be applied
     */
    autoEnter(fieldInfo: IFieldInfo, args?: any[]): boolean;
    /**
     * Returns whether the provided value type has ranges or not.
     * True if it has ranges, false otherwise.
     * @param valueType
     */
    hasRanges(valueType: IIntegerType): boolean;
    /**
     * Get the maximum character length of a field, according to the value type's max length or ranges.
     * The limit defaults to the NUMBER_MAX_LENGTH constant.
     * @param valueType
     */
    getMaxFieldLength(valueType: IIntegerType): number;
    /**
     * Determine if a negative value is possible for the value type
     * @param valueType
     */
    hasNegativeRange(valueType: IIntegerType): boolean;
    /**
     * Determine if a negative value is possible for the value type
     * @param valueType
     */
    isNegativeOnlyRange(valueType: IIntegerType): boolean;
    /**
     * Determine if a negative value is possible for the value type
     * @param valueType
     */
    getLowerBound(valueType: IIntegerType): Optional<number>;
    /**
     * Determine if a negative value is possible for the value type
     * @param valueType
     */
    getUpperBound(valueType: IIntegerType): Optional<number>;
    /**
     * Test if a number is inside the specified ranges (if any ranges are available).
     * @param value
     * @param valueType
     * @param checkLowerBound (default is true)
     * @param checkUpperBound (default is true)
     */
    isInRange(value: number, valueType: IIntegerType, checkLowerBound?: boolean, checkUpperBound?: boolean): boolean;
    /**
     * Remove all range check errors from the provided data value subscription and return the
     * number of removed errors
     * @param fieldInfo Field info
     */
    removeRangeCheckErrors(fieldInfo: IFieldInfo): number;
    /**
     * Configure errors for the field and returns whether something was modified in the error collection.
     * @param value
     * @param fieldInfo Field info
     */
    applyErrors(value: string, fieldInfo: IFieldInfo): boolean;
    /**
     * Removes all relative range check errors from data value subscription before adding a new range check error at the beginning of the error list
     * @param validationResult Range check result
     * @param erroneousValue
     * @param fieldInfo Field info
     */
    setRangeCheckError(validationResult: RangeCheckResult, erroneousValue: string, fieldInfo: IFieldInfo): void;
    /**
     * Type check to evaluate if a given value-type is of the data-type enumeration
     * @param valueType
     */
    isEnumerationType(valueType: IValueType): valueType is IEnumerationType;
    /**
     * Override this method to give more information about an erroneous value.
     * @param value
     * @param fieldInfo Field info
     */ protected getInvalidValue(value: string, fieldInfo: IFieldInfo): string;
    /**
     * Retrieves the maximum value character length as defined in value type's ranges.
     * @param valueType
     */
    private getMaxRangeLength;
    /**
     *  If field is empty and visited, then set available route error to relevant.
     *  If field has a value, then set available route error to irrelevant.
     *  Returns true if there are any route errors, false otherwise.
     * @param value
     * @param fieldInfo Field info
     */
    private applyRouteErrors;
    /**
     * Convert validation enum to string.
     * @param validationResult
     */
    private getRangeCheckKey;
    /**
     * Comparison of 2 field info objects
     * @param fieldInfo1
     * @param fieldInfo2
     */
    private isEqual;
}
