import { FieldConverterService } from './field-converter.service';
import { HelperService } from '../helper.service';
import { IFieldInfo } from '../../../typedefinitions/models/observables/IFieldInfo';
import { ISetType } from '../../../typedefinitions/models/value-types/ISetType';
import { RangeCheckResult } from '../../../typedefinitions/enums/RangeCheckResult';
import * as i0 from "@angular/core";
/**
 * The converter service for fields of data type set,
 * used for validating input and setting the correct errors as well as converting the input value to a string suitable for the server.
 */
export declare class SetFieldConverterService extends FieldConverterService {
    private helperService;
    private minusSign;
    /**
     * Set field converter service class constructor
     */
    constructor(helperService: HelperService);
    /**
     * Get all selected reference codes
     * @param fieldInfo Field info
     */
    getSelected(fieldInfo: IFieldInfo): string[];
    /**
     * Determines if the given category is selected
     * @param fieldInfo Field info
     * @param category
     * @return true if selected, otherwise false
     */
    isSelected(fieldInfo: IFieldInfo, category: number): boolean;
    /**
     * Determines if currently selected option is the given special answer
     * @param {IFieldInfo} fieldInfo Field info
     * @param {string} specialAnswer
     * @returns {boolean} true if selected, otherwise false
     */
    isSelectedSpecial(fieldInfo: IFieldInfo, specialAnswer: string): boolean;
    /**
     * Adds or removes a category from the answer list
     * @param fieldInfo Field info
     * @param code Category code
     */
    toggleCategory(fieldInfo: IFieldInfo, code: number): boolean;
    /**
     * Add a category to the selection and return if it succeeded
     * @param {IFieldInfo} fieldInfo Field info
     * @param {number} code
     * @returns {boolean} true if the category has successfully been added, otherwise false
     */
    addCategory(fieldInfo: IFieldInfo, code: number): boolean;
    /**
     * Remove a category from the selection.
     */
    removeCategory(fieldInfo: IFieldInfo, code: number): void;
    /**
     * Evaluate auto enter logic for set fields
     * @param fieldInfo Field info
     */
    autoEnter(fieldInfo: IFieldInfo): boolean;
    /**
     * Configure the answer from a string value
     * @param input
     * @param fieldInfo Field info
     */
    setAnswerFromString(input: string, fieldInfo: IFieldInfo): void;
    /**
     * Check if the input exactly matches one of the categories
     * @param input The input value
     * @param setType Value type
     * @returns range check result
     */
    isValid(input: string, setType: ISetType): RangeCheckResult;
    /**
     * Validate if the input string consists of allowed characters.
     * It is considered valid if the string consists of dashes and numeric values.
     * @param input
     * @param setType
     */
    isAllowed(input: string, setType: ISetType): RangeCheckResult;
    /**
     * Override the getInvalidValue method to supply information about the erroneous part of the text
     * @param input
     * @param fieldInfo Field info
     */ protected getInvalidValue(input: string, fieldInfo: IFieldInfo): string;
    /**
     * Determine if the specified category exists for the field.
     * @param fieldInfo Field info
     * @param categoryCode
     */
    private categoryExists;
    /**
     * Verify if it's allowed to add the category
     * @param {IFieldInfo} fieldInfo Field info
     * @param {number} category
     * @returns {boolean} true if adding the value is allowed, otherwise false
     */
    private canAdd;
    /**
     * Format the data value
     * @param fieldInfo Field info
     * @param selectedCategories
     */
    private setAnswer;
    /**
     * Find duplicate values in set field string.
     * @param selection
     * @returns duplicate values
     */
    private getDuplicateValues;
    static ɵfac: i0.ɵɵFactoryDeclaration<SetFieldConverterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SetFieldConverterService>;
}
