import { PlatformLocation } from '@angular/common';
import { Router } from '@angular/router';
import { HttpClient } from '@angular/common/http';
import { ToastrService } from 'ngx-toastr';
import { AuditTrailService } from './audit-trail/audit-trail.service';
import { AuditTrailServerInfoService } from './audit-trail/audit-trail-server-info.service';
import { ClientSidePropertiesService } from './client-side/properties/client-side-properties.service';
import { ClientSideRouteItemEventsService } from './client-side/route-item-events/client-side-route-item-events.service';
import { ClientSideRulesService } from './client-side/rules/client-side-rules.service';
import { CultureInfoService } from './culture-info.service';
import { EventService } from './event.service';
import { FontService } from './font.service';
import { LoggerService } from './logger.service';
import { LookupService } from './lookup.service';
import { MediaService } from './media.service';
import { MeasureTimeService } from './measure-time.service';
import { PayloadService } from './payload.service';
import { RuntimeParametersService } from './runtime-parameters.service';
import { RenderStateService } from './renderstate.service';
import { SecurityService } from './security.service';
import { SizeTreeService } from './sizetree/sizetree.service';
import { SkipLinkService } from './skiplink.service';
import { StorageService } from './storage.service';
import { SubscriptionService } from './subscription.service';
import { TextInfoService } from './text-info.service';
import { UserAgentService } from './user-agent.service';
import { UploadService } from './upload.service';
import { IExecuteServerActionsEvent } from '../../typedefinitions/events/IExecuteServerActionsEvent';
import { IClassificationResult } from '../../typedefinitions/models/IClassificationResult';
import { IEmbeddedFontUrls } from '../../typedefinitions/models/server/IEmbeddedFontUrls';
import { ILayoutSet } from '../../typedefinitions/models/server/ILayoutSet';
import * as i0 from "@angular/core";
/**
 * The data service is a central hub for most server communications.
 */
export declare class DataService {
    private auditTrailService;
    private auditTrailServerInfoService;
    private clientSidePropertiesService;
    private clientSideRouteItemEventsService;
    private clientSideRulesService;
    private cultureInfoService;
    private eventService;
    private fontService;
    private http;
    private lookupService;
    private measureTimeService;
    private mediaService;
    private payloadService;
    private platformLocation;
    private renderStateService;
    private router;
    private runtimeParametersService;
    private securityService;
    private sizeTreeService;
    private skipLinkService;
    private storageService;
    private subscriptionService;
    private textInfoService;
    private uploadService;
    private userAgentService;
    private toastrService;
    private loggerService;
    private startInterviewPath;
    private executeActionsPath;
    private expandClassificationItemPath;
    /**
     * Indicator if a server request has already been sent.
     */
    private awaitingResponse;
    /**
     * The base hyper text reference for the api
     */
    private _baseHref;
    private previewPath;
    private previewXmlPath;
    private previewTimer;
    private lastModified;
    /**
     * Reference to handle server payload subscription
     */
    private readonly handleServerPayloadSubscription?;
    /**
     * Reference to runtime parameter subscription
     */
    private runtimeParametersSubscription?;
    /**
     * A list of layout sets with their names and use conditions
     */
    layoutSets: Nullable<ILayoutSet[]>;
    /**
     * Dictionary object used by the main component to define embedded font definition css.
     * The object consists out of font name properties with an embedded url value.
     */
    embeddedFontUrls: Nullable<IEmbeddedFontUrls>;
    /**
     * The base hyper text reference for the api
     */
    get baseHref(): string;
    /**
     * Data service class constructor. Determines the base url for the api. Initiates the handle server payload subscription.
     * @param auditTrailService
     * @param auditTrailServerInfoService
     * @param clientSidePropertiesService
     * @param clientSideRouteItemEventsService
     * @param clientSideRulesService
     * @param cultureInfoService
     * @param eventService
     * @param fontService
     * @param http
     * @param lookupService
     * @param measureTimeService
     * @param mediaService
     * @param payloadService
     * @param platformLocation
     * @param renderStateService
     * @param sizeTreeService
     * @param skipLinkService
     * @param runtimeParametersService
     * @param router
     * @param securityService
     * @param storageService
     * @param subscriptionService
     * @param textInfoService,
     * @param uploadService,
     * @param userAgentService
     * @param toastrService
     * @param loggerService
     */
    constructor(auditTrailService: AuditTrailService, auditTrailServerInfoService: AuditTrailServerInfoService, clientSidePropertiesService: ClientSidePropertiesService, clientSideRouteItemEventsService: ClientSideRouteItemEventsService, clientSideRulesService: ClientSideRulesService, cultureInfoService: CultureInfoService, eventService: EventService, fontService: FontService, http: HttpClient, lookupService: LookupService, measureTimeService: MeasureTimeService, mediaService: MediaService, payloadService: PayloadService, platformLocation: PlatformLocation, renderStateService: RenderStateService, router: Router, runtimeParametersService: RuntimeParametersService, securityService: SecurityService, sizeTreeService: SizeTreeService, skipLinkService: SkipLinkService, storageService: StorageService, subscriptionService: SubscriptionService, textInfoService: TextInfoService, uploadService: UploadService, userAgentService: UserAgentService, toastrService: ToastrService, loggerService: LoggerService);
    /**
     * Retrieves the runtime parameters and makes a server call to start the survey based on these settings.
     * @param queryString runtime parameters from query string
     * @returns  success
     */
    startSurvey: (queryString?: any) => void;
    /**
     * Used by the classification class to request information for node children when unfolding
     * @param code node id
     * @param libraryFileName
     * @param typeName
     * @returns classification result promise
     */
    expandClassification: (code: string, libraryFileName: string, typeName: string) => Nullable<Promise<IClassificationResult>>;
    /**
     * Executes a list of server actions if there are no range check errors on the page and the application is not already awaiting a response.
     * Should only be called via execute actions function of the action factory.
     * @param event ExecuteActionsEvent containing server action key-value-pairs, a controlID (optional), an eventName (optional) and the shouldApplyPageEvent flag
     * actions KeyValuePairs of actions, with the key being the actionID and the value the actionPayload
     * controlID (optional) ID of the control for which these actions were triggered
     * eventName name of the defined shortcut (e.g. OnCtrlP)
     * shouldApplyPageEvent flag indicating that there are on try page forward events to be executed server side
     */
    protected executeActions(event: IExecuteServerActionsEvent): void;
    private postFailed;
    private handleActionException;
    private handleException;
    private setBaseHref;
    private setPathConstants;
    /**
     * Sets the data service's runtime-parameters property.
     * Sets the api paths based on the runtime-parameters.
     * Attaches the measure time event if flagged in the runtime-parameters.
     * Extends the runtime parameters property with post runtime-parameters.
     * @param runtimeParameters Retrieved runtime-parameters.
     * @param queryString Retrieved query string.
     */
    private handleRuntimeParameters;
    /**
     * Start the survey
     * @param payload request payload
     * @returns  result promise
     */
    private startInterview;
    /**
     * @param payload request payload
     * @returns  result promise
     */
    private executeServerActions;
    private initializeMeasureTimeService;
    private getServerParkInfo;
    private startSuccess;
    /**
     * Updates the application using the newly received info
     * @param payload
     */
    private handleServerPayload;
    private handleOutputFile;
    /**
     * Request a preview page
     */
    private startPreview;
    private initializePreview;
    private handlePreviewData;
    private startPolling;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DataService>;
}
