import { EventEmitter } from '@angular/core';
import { IAction } from '../../typedefinitions/models/actions/IAction';
import { IActionsEventHandler } from '../../typedefinitions/models/IActionsEventHandler';
import { IActionKeyValuePair } from '../../typedefinitions/models/IActionKeyValuePair';
import { IBaseControl } from '../../typedefinitions/models/controls/IBaseControl';
import { IExecuteServerActionsEvent } from '../../typedefinitions/events/IExecuteServerActionsEvent';
import { IFieldChangedEvent } from '../../typedefinitions/events/IFieldChangedEvent';
import { IFieldInfo } from '../../typedefinitions/models/observables/IFieldInfo';
import { IHandleActionEvent } from '../../typedefinitions/events/IHandleActionEvent';
import { IHandleActionsEvent } from '../../typedefinitions/events/IHandleActionsEvent';
import { IMenuItem } from '../../typedefinitions/models/IMenuItem';
import { IPayload } from '../../typedefinitions/models/server/payload/IPayload';
import { IPixelSize } from '../../typedefinitions/models/IPixelSize';
import { ITimeslotsResponse } from '../../typedefinitions/models/server/ITimeslotsResponse';
import * as i0 from "@angular/core";
/**
 * The event service is the central hub in Blaise containing global application events
 * to which other classes can subscribe. When subscribing to an event, classes can be
 * decoupled from one another.
 */
export declare class EventService {
    /**
     * Emitted every time a scroll is detected.
     */
    scrollEvent: EventEmitter<Event>;
    /**
     * Emitted when the browser window starts to be resized.
     */
    windowResizeEvent: EventEmitter<void>;
    /**
     * Emitted when the resizing of the browser window has been completed.
     * Contains an object with the final width and height of the window expressed in pixels.
     */
    windowResizedEvent: EventEmitter<IPixelSize>;
    /**
     * Emitted when the value of a field is changed. Contains a `DataValueSubscription` object.
     */
    fieldValueChangedEvent: EventEmitter<IFieldInfo>;
    /**
     * Emitted when the visibility value of a control is changed.
     */
    controlVisibilityChanged: EventEmitter<IBaseControl | IMenuItem | Array<IBaseControl | IMenuItem>>;
    /**
     * Emitted when the visibility value of one or more controls is changed.
     */
    cspControlVisibilityChanged: EventEmitter<Array<IBaseControl | IMenuItem>>;
    /**
     * Emitted when the current page has been initialized. This is the case when the complete component tree for the page has been constructed.
     */
    pageInitializedEvent: EventEmitter<never>;
    /**
     * Emitted when the active field on the page changes. When the focus jumps to another control or the user navigates to another page for example.
     */
    activeFieldChangedEvent: EventEmitter<IFieldChangedEvent>;
    /**
     * Emitted right after the application has been able to determine that all CSS
     * has been loaded.
     */
    cssLoadedEvent: EventEmitter<void>;
    /**
     * Emitted asynchronously when the splash screen needs to be shown to the user. This usually is case when a task might take some time to finish.
     */
    showSplashEvent: EventEmitter<void>;
    /**
     * Emitted asynchronously when the splash screen needs to be hidden from the user. This usually is the case when a task has finished.
     */
    hideSplashEvent: EventEmitter<void>;
    /**
     * Emitted asynchronously when the size tree has finished calculating the width and height of all components.
     * Before this event is emitted, the dimensions of a component might not be final.
     */
    sizeTreeReadyEvent: EventEmitter<string>;
    /**
     * Emitted when the next field has been made active.
     */
    nextFieldEvent: EventEmitter<void>;
    /**
     * Emitted when the previous field has been made active.
     */
    previousFieldEvent: EventEmitter<void>;
    /**
     * Emitted when the navigation mode has been changed.
     */
    navigationModeChangedEvent: EventEmitter<boolean>;
    /**
     * Emitted when a new server payload is received
     */
    newServerPayloadEvent: EventEmitter<IPayload>;
    /**
     * Emitted when an appointment related server payload is received.
     */
    newAppointmentPayloadEvent: EventEmitter<ITimeslotsResponse>;
    /**
     * emitted when all http post are done
     */
    auditTrailProcessedEvent: EventEmitter<void>;
    /**
     * emitted when a new server payload is received
     */
    newAuditTrailServerInfoEvent: EventEmitter<IPayload>;
    /**
     * emit to initialize the audit-trail
     */
    auditTrailInitializeEvent: EventEmitter<void>;
    /**
     * data service execute actions event emitter
     */
    executeServerActionsEvent: EventEmitter<IExecuteServerActionsEvent>;
    /**
     * action service handle actions event emitter
     */
    handleActionsEvent: EventEmitter<IHandleActionsEvent>;
    /**
     * action service handle actions event emitter
     */
    handleActionEvent: EventEmitter<IHandleActionEvent>;
    /**
     * Emitted when an external record is selected
     */
    selectExternalRecordStart: EventEmitter<void>;
    /**
     * Emitted when selected an external record is completed
     */
    selectExternalRecordCompleted: EventEmitter<void>;
    /**
     * Emits the data service execute actions event with the correct parameters
     * @param actions
     * @param controlId
     * @param eventName
     * @param shouldApplyPageEvent
     */
    emitExecuteServerActionsEvent(actions: IActionKeyValuePair[], controlId?: string, eventName?: string, shouldApplyPageEvent?: boolean): void;
    /**
     * Emits an action service handle actions event with the correct parameters
     * @param actionsEventHandler
     * @param controlId
     */
    emitHandleActionsEvent(actionsEventHandler: IActionsEventHandler, controlId?: string): void;
    /**
     * Emits an action service handle action event with the correct parameters
     * @param actionObj
     * @param controlId
     * @param eventName
     */
    emitHandleActionEvent(actionObj: IAction, controlId?: string, eventName?: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EventService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EventService>;
}
