import { Injector } from '@angular/core';
import { EventService } from '../event.service';
import { SubscriptionService } from '../subscription.service';
import { RenderStateService } from '../renderstate.service';
import { ComponentService } from '../component.service';
import { IBaseComponentViewModel2 } from '../../../typedefinitions/models/view/IBaseViewModel';
import { IDataValue } from '../../../typedefinitions/models/IDataValue';
import { Direction } from '../../../typedefinitions/enums/Direction';
import { NavigationMode } from '../../../typedefinitions/enums/NavigationMode';
import * as i0 from "@angular/core";
/**
 * The navigation service manages the application's navigation mode
 */
export declare class NavigationService {
    private eventService;
    private subscriptionService;
    private renderStateService;
    private componentService;
    private injector;
    /**
     * Allows storing of and resetting to the previous field value.
     */
    previousFieldValue: Nullable<IDataValue>;
    /**
     * Interview navigation mode
     */
    navigationMode: NavigationMode;
    /**
     * Navigation service class constructor. Subscribes to render state changes.
     * @param eventService
     * @param subscriptionService
     * @param renderStateService
     * @param componentService
     * @param injector
     */
    constructor(eventService: EventService, subscriptionService: SubscriptionService, renderStateService: RenderStateService, componentService: ComponentService, injector: Injector);
    /**
     * Toggles the navigation mode between navigation and edit
     */
    toggleNavigationMode(): void;
    /**
     * Switches the keyboard navigation to edit mode, only if the KeyboardNavigation runtime setting is not equal to "None".
     * @param escalate Flag indication if changing navigation mode to insert mode should have further consequences. Default true.
     */
    setInsertMode(escalate?: boolean): void;
    /**
     * Sets the navigation mode to a specified mode
     * @param mode The navigation mode to change to
     * @param escalate Flag indication if changing mode should have further consequences. Default true.
     */
    setNavigationMode(mode: NavigationMode, escalate?: boolean): void;
    /**
     * Handle the f2 key pressed. Run corresponding button commands.
     * @param event KeyboardEvent
     */
    f2KeyPressed(event: KeyboardEvent): void;
    /**
     * Handle the enter key pressed. Run corresponding button commands.
     * @param event
     */
    enterKeyPressed(event: KeyboardEvent): void;
    /**
     * Handle the left arrow key pressed. Run corresponding button commands.
     * @param event
     */
    leftKeyPressed(event: KeyboardEvent): void;
    /**
     * Handle the right arrow key pressed. Run corresponding button commands.
     * @param event
     */
    rightKeyPressed(event: KeyboardEvent): void;
    /**
     * Handle the up key arrow pressed. Run corresponding button commands.
     * @param event
     */
    upKeyPressed(event: KeyboardEvent): void;
    /**
     * Handle the down arrow key pressed. Run corresponding button commands.
     * @param event
     */
    downKeyPressed(event: KeyboardEvent): void;
    /**
     * Handle the page-up key pressed. Run corresponding button commands.
     * @param event
     */
    pageUpKeyPressed(event: KeyboardEvent): void;
    /**
     * Handle the page-down key pressed. Run corresponding button commands.
     * @param event
     */
    pageDownKeyPressed(event: KeyboardEvent): void;
    /**
     * Handle the home key pressed. Run corresponding button commands.
     * @param event
     */
    homeKeyPressed(event: KeyboardEvent): void;
    /**
     * Handle the end key pressed. Run corresponding button commands.
     * @param event
     */
    endKeyPressed(event: KeyboardEvent): void;
    /**
     * Handle the tab key pressed. Run corresponding button commands.
     * @param event
     */
    tabKeyPressed(event: KeyboardEvent): void;
    /**
     * Handle the shift + tab key pressed. Run corresponding button commands.
     * @param event
     */
    shiftTabPressed(event: KeyboardEvent): void;
    /**
     * Handle the escape key pressed. Run corresponding button commands.
     * @param event
     */
    escapePressed(event: KeyboardEvent): void;
    /**
     * Handle the space key pressed. Run corresponding button commands.
     * @param event
     */
    spacePressed(event: KeyboardEvent): void;
    /**
     * Find a component by event target. If it is not available, the data attribute 'data-component-id' of the object that caused the event will be queried.
     * @param event
     */
    findComponent(event: KeyboardEvent): Nullable<IBaseComponentViewModel2>;
    /**
     * Look for adjacent fields in a specified direction
     * @param event
     * @param dir
     * @returns the field name of an adjacent control
     */
    findAdjacentField(event: KeyboardEvent, dir: Direction): Nullable<string>;
    /**
     * Look for adjacent controls in a specified direction
     * @param event
     * @param dir
     * @returns the id of an adjacent control
     */
    findAdjacentControl(event: KeyboardEvent, dir: Direction): Nullable<string>;
    /**
     * Get the field name of a control left to the current field. An empty string is returned if no suitable field was found.
     * @param currentFieldName
     * @param currentComponent
     */
    private getFieldLeft;
    /**
     * Get the field name of a control right to the current field. An empty string is returned if no suitable field was found.
     * @param currentFieldName
     * @param currentComponent
     */
    private getFieldRight;
    /**
     * Get the field name of a control above the current field. An empty string is returned if no suitable field was found.
     * @param currentFieldName
     * @param currentComponent
     */
    private getFieldUp;
    /**
     * Get the field name of a control below the current field. An empty string is returned if no suitable field was found.
     * @param currentFieldName
     * @param currentComponent
     */
    private getFieldDown;
    /**
     * Calculate the bounding box of the input controls of a field
     */
    private getInputControlsRect;
    /**
     * Recursively check if the control id is part of the content area.
     * @param controlId
     */
    private inContentArea;
    /**
     * Handles render state changes by configuring the navigation mode and saving the field value for later usage
     */
    private handleRenderStateChange;
    /**
     * Keep reference to the current field value in order to be able to restore it when requested
     * @param value
     */
    private saveFieldValue;
    /**
     * Determine the specific implementation depending on the navigation mode and the component that fired the event.
     * @param event
     * @returns a fitting navigation mode strategy
     */
    private getNavigationStrategy;
    /**
     * Find the closest control in a specified direction using the Euclidean distance.
     * @param currentPosition Rectangle of current control
     * @param dir The search direction
     * @param mappings Mapping from control id to control rectangle on the page.
     * @param filter A filter function that determines which control mappings are included in the comparison
     * @returns the id of the closest control
     */
    private findClosestControlId;
    /**
     * Calculate the euclidean distance between two points
     * @param rect1
     * @param rect2
     */
    private getDistance;
    /**
     * Calculate the angle between two points in degrees
     * @param cx
     * @param cy
     * @param ex
     * @param ey
     */
    private angle;
    /**
     * Calculate the angle between two points in 360 degrees
     * @param cx
     * @param cy
     * @param ex
     * @param ey
     */
    private angle360;
    /**
     * Returns a mapping table with all control id's and client rectangles of the specified neighbours
     * @param neighbours
     */
    private getNeighbourPositions;
    /**
     * Execute an array of commands.
     * @param commands
     * @param event
     */
    private runCommands;
    /**
     * Returns the default navigation strategy, unless it is overridden
     */
    private getDefaultNavigationStrategy;
    /**
     * Returns the default insert strategy, unless it is overridden
     */
    private getDefaultInsertStrategy;
    /**
     * Returns the default empty strategy, unless it is overridden
     */
    private getDefaultEmptyStrategy;
    /**
     * Returns the id of the next visible control based on the tab index
     * @param index the tab index of the current control
     * @returns the id of the next visible control based on the tabindex or null if no such control was found
     */
    nextVisibleControlIdByTabIndex(index: number): Nullable<string>;
    /**
     * Returns the id of the previous visible control based on the tab index of the current control
     * @param index the tab index of the current control
     * @returns the id of the previous visible control based on the tabindex or null if no such control was found
     */
    previousVisibleControlIdByTabIndex(index: number): Nullable<string>;
    /**
     * Return all visible controls with a tabIndex attribute
     * @returns an array with all visible controls based on display, visibility and dimensions
     */
    private allVisibleControlsWithTabIndex;
    static ɵfac: i0.ɵɵFactoryDeclaration<NavigationService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NavigationService>;
}
