import { ElementRef } from '@angular/core';
import { ColorService } from './color.service';
import { EventService } from './event.service';
import { HelperService } from './helper.service';
import { MediaService } from './media.service';
import { StyleGeneratorService } from './style-generator.service';
import { TimerService } from './timer.service';
import { IRichText } from '../../typedefinitions/models/richText/IRichText';
import * as i0 from "@angular/core";
/**
 * The rich text converter service converts a rich text object to rich and dynamic html string
 */
export declare class RichTextConverterService {
    private colorService;
    private eventService;
    private helperService;
    private mediaService;
    private styleGeneratorService;
    private timerService;
    private readonly data;
    private readonly handle;
    private readonly click;
    private readonly focus;
    private readonly blur;
    private readonly mouseenter;
    private readonly mouseleave;
    private readonly mousedown;
    private readonly mouseup;
    private readonly runEvents;
    private readonly change;
    private readonly load;
    private readonly eventsFunctionObj;
    private readonly eventsStrObj;
    /**
     * Rich text converter service class constructor.
     * @param colorService
     * @param eventService
     * @param helperService
     * @param mediaService
     * @param styleGeneratorService
     * @param timerService
     */
    constructor(colorService: ColorService, eventService: EventService, helperService: HelperService, mediaService: MediaService, styleGeneratorService: StyleGeneratorService, timerService: TimerService);
    /**
     * Converts a rich text object to a plain text string
     * @param richText
     */
    convertToPlainText(richText: IRichText): string;
    /**
     * Converts a rich text object to rich, dynamic html string
     * @param richText
     * @param autoWidth default: true
     * @param useWordBreak default: false
     */
    convertToHTML(richText: IRichText, autoWidth?: boolean, useWordBreak?: boolean): string;
    /**
     * Bind click handlers to dynamically generated HTML
     * @param ref
     */
    checkDynamicActions(ref: ElementRef): void;
    private getPlainTextFromElement;
    private getPlainTextFromParagraph;
    private getPlainTextFromRun;
    private getPlainTextFromRunElement;
    private getPlainTextFromTable;
    private getPlainTextFromTableRow;
    private getPlainTextFromTableCell;
    private createRichTextElement;
    /**
     * Creates a paragraph element
     * @param paragraph
     */
    private createParagraph;
    /**
     * Creates a run element
     * @param run
     * @param alignment
     */
    private createRun;
    /**
     * Creates an HTML element based on the provided element definition
     * @param elementDef element definition
     * @param fontDef
     * @param headerSize
     * @param language
     * @param alignment (optional)
     */
    private createRunElement;
    /**
     * Create a text element based on a simple text string
     * @param simpleText
     * @param fontDef
     * @param headerSize
     */
    private createSimpleTextElement;
    /**
     * Creates a text element
     * @param elementDef text element definition
     * @param fontDef
     * @param headerSize
     * @param language
     */
    private createTextElement;
    /**
     * Creates an image element
     * @param elementDef element definition
     */
    private createImageElement;
    /**
     * Creates an hyperlink element
     * @param elementDef element definition
     * @param fontDef element's font definition
     */
    private createHyperlinkElement;
    /**
     * Creates an ellipse shape element
     * @param elementDef element definition
     */
    private createEllipseElement;
    /**
     * Creates a line shape element
     * @param elementDef element definition
     */
    private createLineElement;
    /**
     * Creates a rectangle shape element
     * @param elementDef element definition
     */
    private createRectangleElement;
    /**
     * Creates a button element
     * @param elementDef
     * @param fontDef
     */
    private createButtonElement;
    /**
     * Creates an audio control element
     * @param elementDef
     */
    private createAudioControlElement;
    /**
     * Creates a video control element
     * @param elementDef
     */
    private createVideoControlElement;
    /**
     * Creates a timer (element)
     * @param elementDef
     */
    private createTimerElement;
    /**
     * Creates a label element
     * @param elementDef element definition
     */
    private createLabelElement;
    /**
     * Creates a textbox element
     * @param elementDef element definition
     */
    private createTextBoxElement;
    /**
     * Creates an element's base properties
     * @param elementDef element definition
     * @param classes css classes
     * @param styles css styling
     */
    private createRunElementProperties;
    /**
     * Creates a table element
     * @param tableDef
     */
    private createTable;
    /**
     * Creates a grid-lines definition object from table definition properties
     * @param tableDef
     */
    private createGridLineDefinition;
    /**
     * Creates table rows
     * @param rowDefs row definitions
     * @param columnDefs column definitions
     * @param gridLineDef grid line definition
     */
    private createTableRows;
    /**
     * Creates a table row
     * @param rowDef row definition
     * @param rowIndex
     * @param columnDefs column definitions
     * @param gridLinesDef grid line definition
     */
    private createTableRow;
    /**
     * Creates table cells
     * @param rowDef row definition
     * @param rowIndex
     * @param columnDefs column definitions
     * @param gridLinesDef grid line definition
     */
    private createTableCells;
    /**
     * Creates a table cell
     * @param columnDef column definition
     * @param cellDef cell definition
     * @param rowIndex row index number
     * @param gridLineDefinition (optional) grid line definition
     */
    private createTableCell;
    /**
     * Execute actions that are defined on the element's click event
     * @param element
     */
    private handleDynamicClick;
    /**
     * Execute actions that are defined on the element's event
     * @param element
     * @param actionAttr
     * @param eventName
     */
    private handleActions;
    private getUriFromDefinition;
    private createFontStyleFromDefinition;
    private generateCellStyleString;
    private getStyleProperty;
    private getStyleValue;
    private generateActionString;
    private generateStyleString;
    private formatText;
    private unescape;
    private setAccessibilityProperties;
    private getMediaSource;
    private getMediaSourceUrl;
    private generateWHOStyleString;
    private generateUnitSizeString;
    private generateGridUnitSizeString;
    private createDashArray;
    /**
     * Flags an element as enabled when the element's visibility property is visible or undefined AND when the element's enabled property is undefined or flagged as true
     * @param elementDef run element definition
     * @private
     * @returns Flag indicating if the element is enabled
     */
    private isEnabled;
    /**
     * Flags an element as visible when the element's visibility property is visible or undefined
     * @param elementDef
     * @private
     * @returns Flag indicating if the element is visible
     */
    private isVisible;
    private hasActions;
    static ɵfac: i0.ɵɵFactoryDeclaration<RichTextConverterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<RichTextConverterService>;
}
