import { GridUnitSize } from './GridUnitSize';
import { UnitSize } from './UnitSize';
import { IControlSize } from './IControlSize';
import { IThickness } from '../../../typedefinitions/models/IThickness';
/**
 * Base control size calculation class forms the base class for several control size calculation classes.
 */
export declare abstract class BaseControlSize implements IControlSize {
    /**
     * Branch/Leaf name
     */
    name: string;
    /**
     * Previous width
     * @protected
     */
    protected prevWidth: Nullable<number>;
    /**
     * Previous height
     * @protected
     */
    protected prevHeight: Nullable<number>;
    /**
     * Width version used for width calculations relative to parent or child controls
     */
    widthVersion: number;
    /**
     * Height version used for height calculations relative to parent or child controls
     */
    heightVersion: number;
    /**
     * Width value in pixels
     */
    pixelWidth: Nullable<number>;
    /**
     * Height value in pixels
     */
    pixelHeight: Nullable<number>;
    /**
     * Parent control size
     */
    parent: IControlSize;
    /**
     * Width (grid) unit size
     */
    width: UnitSize | GridUnitSize;
    /**
     * Height (grid) unit size
     */
    height: UnitSize | GridUnitSize;
    /**
     * Border thickness
     */
    border: IThickness;
    /**
     * Margin thickness
     */
    margin: IThickness;
    /**
     * Grid column span
     */
    colSpan: number;
    /**
     * Grid row span
     */
    rowSpan: number;
    /**
     * Flag indicating if the control is NOT collapsed. So either visible or hidden, in a visibility state were its width and height matter.
     */
    exploded: boolean;
    /**
     * Base control size class constructor. Initializes the width and height container properties
     * @param {string} name Branch/Leaf name
     */
    protected constructor(
    /**
     * Branch/Leaf name
     */
    name: string);
    /**
     * Returns the child control sizes of the control
     * @returns {Array<IControlSize>} child controls sizes
     */
    abstract getChildren(): IControlSize[];
    /**
     * Adds a child's control size to the list
     * @param {IControlSize} child
     */
    abstract addChild(child: IControlSize): void;
    /**
     * Recursively clears the list of child control sizes of the control
     */
    abstract clearChildren(): void;
    /**
     * Calculates the pixel width and height of the control
     * @param {number} version
     */
    calculate(version: number): void;
    /**
     * Calculates the pixel width of the control if the given version number is greater than the current width calculation version
     * @param {number} version new width calculation version
     * @returns {Nullable<number>} pixel width or null
     */
    calculateWidth(version: number): Nullable<number>;
    /**
     * Calculates the pixel height if the given version number is greater than the current height calculation version
     * @param {number} version new height calculation version
     * @returns {Nullable<number>} pixel height or null
     */
    calculateHeight(version: number): Nullable<number>;
    /**
     * Saves the current width and height values for change detection purposes.
     */
    saveState(): void;
    /**
     * Determines if the dimensions have changed since the last size tree calculation.
     * @returns {boolean} true if the dimensions have changed
     */
    dimensionsChanged(): boolean;
    /**
     * Returns the width including margin
     * @param {number} version width calculation version
     * @returns {number} width including margin
     */
    getOuterWidth(version: number): number;
    /**
     * Returns the height including margin
     * @param {number} version height calculation version
     * @returns {number} height including margin
     */
    getOuterHeight(version: number): number;
    /**
     * Returns the width without border
     * @param {number} version width calculation version
     * @returns {number} width without border
     */
    getInnerWidth(version: number): number;
    /**
     * Returns the height without border
     * @param {number} version
     * @returns {number} height without border
     */
    getInnerHeight(version: number): number;
    /**
     * Returns the calculated width if it's ready. Else null will be returned.
     * @returns {Nullable<number>} calculated width or null
     */
    getWidth(): Nullable<number>;
    /**
     * Returns the calculated height if it's ready. Else null will be returned.
     * @returns {Nullable<number>} calculated height or null
     */
    getHeight(): Nullable<number>;
    /**
     * Verifies if calculating the control size has finished.
     * @returns {boolean} true if ready
     */
    isReady(): boolean;
    /**
     * Verifies if the calculation of the control's width has finished.
     * @returns {boolean} true if ready
     */
    widthReady(): boolean;
    /**
     * Verifies if the calculation of the control height has finished.
     * @returns {boolean} true if ready
     */
    heightReady(): boolean;
    /**
     * Calculates/Determines the control's auto width value
     * @param {number} version width calculation version
     * @returns {number} auto width value in pixels
     * @protected
     */
    protected abstract calculateAutoWidth(version: number): number;
    /**
     * Calculated/Determines the control's auto height value
     * @param {number} version height calculation version
     * @returns {number} auto height value in pixels
     * @protected
     */
    protected abstract calculateAutoHeight(version: number): number;
    /**
     * Returns the control's fixed pixel width value
     * @returns {number} pixel width value
     * @protected
     */
    protected calculateFixedWidth(): number;
    /**
     * Returns the control's fixed pixel height value
     * @returns {number} pixel height value
     * @protected
     */
    protected calculateFixedHeight(): number;
    /**
     * Calculates the stretch pixel width
     * @returns {number} stretch pixel width
     */
    protected calculateStretchWidth(): number;
    /**
     * Calculates the stretch pixel height
     * @returns {number} calculated stretch height
     */
    protected calculateStretchHeight(): number;
}
