import { IThickness } from '../../../typedefinitions/models/IThickness';
import { GridUnitType } from '../../../typedefinitions/enums/GridUnitType';
import { IControlSize } from './IControlSize';
import { ICellContainer } from './ICellContainer';
import { GridUnitSize } from './GridUnitSize';
/**
 * The cell control size class a property container used by the size tree for managing cell sizes
 */
export declare class CellControlSize implements IControlSize {
    /**
     * colIndex column index of the cell control
     */
    readonly colIndex: number;
    /**
     * rowIndex row index of the cell control
     */
    readonly rowIndex: number;
    private child;
    /**
     * Property containing the saved width value for change detection purposes.
     */
    protected prevWidth: Nullable<number>;
    /**
     * Property containing the saved height value for change detection purposes.
     */
    protected prevHeight: Nullable<number>;
    /**
     * Width version
     */
    widthVersion: number;
    /**
     * Height version
     */
    heightVersion: number;
    /**
     * This cell's width unit value and type property container
     */
    width: GridUnitSize;
    /**
     * This cell's height unit value and type property container
     */
    height: GridUnitSize;
    /**
     * Property containing the cell's border information
     */
    border: IThickness;
    /**
     * Property containing the cell's spacing information
     */
    margin: IThickness;
    /**
     * This cell's (calculated) pixel width value
     */
    pixelWidth: Nullable<number>;
    /**
     * This cell's (calculated) pixel height value
     */
    pixelHeight: Nullable<number>;
    /**
     * The grid of which this cell is a child
     */
    parent: ICellContainer;
    /**
     * Column span
     */
    colSpan: number;
    /**
     * Row span
     */
    rowSpan: number;
    /**
     * Property indicating the cells' visibility (collapse) state
     */
    exploded: boolean;
    /**
     * Readonly property name contains the constructed cell name based on its column and row position in the grid
     */
    readonly name: string;
    /**
     * Cell control size class constructor.
     * @param colIndex column index of the cell control
     * @param rowIndex row index of the cell control
     * @param widthUnit grid unit type for the cell's width
     * @param widthValue cell's width value
     * @param heightUnit grid unit type for the cell's height
     * @param heightValue cell's height value
     */
    constructor(
    /**
     * colIndex column index of the cell control
     */
    colIndex: number, 
    /**
     * rowIndex row index of the cell control
     */
    rowIndex: number, widthUnit: GridUnitType, widthValue: number, heightUnit: GridUnitType, heightValue: number);
    /**
     * Add child
     * @param child
     */
    addChild(child: IControlSize): void;
    /**
     * Calculate
     * @param version
     */
    calculate(version: number): void;
    /**
     * Calculate width
     * @param version
     * @returns width
     */
    calculateWidth(version: number): number;
    /**
     * Calculate height
     * @param version
     * @returns height
     */
    calculateHeight(version: number): number;
    /**
     * Returns the child's control size in an array
     * @returns {Array<IControlSize>} a single child control size in an array or an empty array
     */
    getChildren(): IControlSize[];
    /**
     * Recursively deep clear children of this cell
     */
    clearChildren(): void;
    /**
     * Get width
     * @returns the pixel width, if ready and greater than 0, otherwise null or 0.
     */
    getWidth(): Nullable<number>;
    /**
     * Get height
     * @returns the pixel height, if ready and greater than 0, otherwise null or 0.
     */
    getHeight(): Nullable<number>;
    /**
     * Get outer width
     * @param version
     * @returns a calculated width including left and right margin widths
     */
    getOuterWidth(version: number): number;
    /**
     * Get outer height
     * @param version
     * @returns a calculated height including top and bottom margin heights
     */
    getOuterHeight(version: number): number;
    /**
     * Get inner width
     * @param version
     * @returns a calculated width excluding left and right border widths
     */
    getInnerWidth(version: number): number;
    /**
     * Get inner height
     * @param version
     * @returns a calculated height excluding top and bottom border heights
     */
    getInnerHeight(version: number): number;
    /**
     * Checks if calculations are ready
     * @returns {boolean} true if width and height have been calculated
     */
    isReady(): boolean;
    /**
     * Checks if width calculations are ready
     * @returns {boolean} true if width has been calculated
     */
    widthReady(): boolean;
    /**
     * Checks if height calculations are ready
     * @returns {boolean} true if height has been calculated
     */
    heightReady(): boolean;
    /**
     * Checks if the child control has a span value on columns that exceeds the default of one
     * @returns {boolean} true if the cell contains a child with a column span greater than one
     */
    containsWidthSpanChild(): boolean;
    /**
     * Checks if the child control has a span value on rows that exceeds the default of one
     * @returns {boolean} true if the cells contains a child with a row span greater than one
     */
    containsHeightSpanChild(): boolean;
    /**
     * Checks if the child control has a span value on rows or columns greater than one
     * @returns {boolean} true if the cells contains a child with a row or column span greater than one
     */
    containsSpanChild(): boolean;
    /**
     * Checks the size of the child control against the size of this cell
     * @returns {boolean} true if the cell contains a child that is larger than the cell.
     */
    hasOverflowingChild(): boolean;
    /**
     * Save current width and height values for change detection purposes.
     */
    saveState(): void;
    /**
     * Determine if the dimensions have changed since the last tree calculation.
     */
    dimensionsChanged(): boolean;
    /**
     * Calculate the content width by calculating the size of an assigned child
     * @param version
     * @returns pixel width of the cell's child's outer width
     */
    private calculateAutoWidth;
    /**
     * Calculate the content height by calculating the size of an assigned child
     * @param version
     * @returns pixel height of the cell's child's outer height
     */
    private calculateAutoHeight;
    /**
     * Calculate the total width of other columns that are not star sized
     * @param version
     * @returns total pixel width of the cell's sibling columns
     */ private calculateOtherWidth;
    /**
     * Calculate the total height of other rows that are not star sized
     * @param version
     * @returns total pixel height of the cell's sibling rows
     */ private calculateOtherHeight;
    /**
     * Calculate the width for this cell according to its number of stars
     * @param version
     * @returns pixel width of the cell
     */
    private calculateStarWidth;
    /**
     * Calculate the height for this cell according to its number of stars
     * @param version
     * @returns pixel height of the cell
     */
    private calculateStarHeight;
    /**
     * Calculates the pixel width for this cell based on its percentage size
     * @returns pixel width of the cell
     */
    private calculatePercentageWidth;
    /**
     * Calculates the pixel height for this cell based on its percentage size
     * @returns pixel height of the cell
     */
    private calculatePercentageHeight;
}
