import { IThickness } from '../../../typedefinitions/models/IThickness';
import { UnitSize } from './UnitSize';
import { GridUnitSize } from './GridUnitSize';
/**
 * Defines properties required for control size calculations used by the size tree
 */
export interface IControlSize {
    /**
     * Width version used for width calculations relative to parent or child controls
     */
    widthVersion: number;
    /**
     * Height version used for height calculations relative to parent or child controls
     */
    heightVersion: number;
    /**
     * Branch/Leaf name
     */
    name: string;
    /**
     * Nullable width value in pixels
     */
    pixelWidth: Nullable<number>;
    /**
     * Nullable height value in pixels
     */
    pixelHeight: Nullable<number>;
    /**
     * Parent control size
     */
    parent: IControlSize;
    /**
     * Width (grid) unit size
     */
    width: UnitSize | GridUnitSize;
    /**
     * Height (grid) unit size
     */
    height: UnitSize | GridUnitSize;
    /**
     * Border thickness
     */
    border: IThickness;
    /**
     * Margin thickness
     */
    margin: IThickness;
    /**
     * Grid column span
     */
    colSpan: number;
    /**
     * Grid row span
     */
    rowSpan: number;
    /**
     * Flag indicating if the control is NOT collapsed. So either visible or hidden, in a visibility state were its width and height matter.
     */
    exploded: boolean;
    /**
     * Returns the child control sizes of the control
     * @returns {Array<IControlSize>} child control sizes
     */
    getChildren(): IControlSize[];
    /**
     * Adds a child's control size to the list
     * @param {IControlSize} child
     */
    addChild(child: IControlSize): void;
    /**
     * Clears the list of child control sizes of the control
     */
    clearChildren(): void;
    /**
     * Calculates the pixel width and height
     * @param {number} version
     */
    calculate(version: number): void;
    /**
     * Calculates the pixel width of the control if the given version number is greater than the current width calculation version
     * @param {number} version new width calculation version
     * @returns {Nullable<number>} pixel width or null
     */
    calculateWidth(version: number): Nullable<number>;
    /**
     * Calculates the pixel height if the given version number is greater than the current height calculation version
     * @param {number} version new height calculation version
     * @returns {Nullable<number>} pixel height or null
     */
    calculateHeight(version: number): Nullable<number>;
    /**
     * Store calculated state for change detection purposes
     */
    saveState(): void;
    /**
     * Indicates if dimension have changed since last sizetree calculation.
     * @returns {boolean} true if dimension have changed since last sizetree calculation, otherwise false.
     */
    dimensionsChanged(): boolean;
    /**
     * Retrieve width including margin
     * @param version
     * @returns the outer width pixels value
     */
    getOuterWidth(version: number): number;
    /**
     * Retrieve height including margin
     * @param version
     * @returns the outer height pixel value
     */
    getOuterHeight(version: number): number;
    /**
     * Retrieve width excluding border
     * @param version
     * @returns the inner width pixel value
     */
    getInnerWidth(version: number): number;
    /**
     * Retrieve height excluding border
     * @param version
     * @returns the inner height pixel value
     */
    getInnerHeight(version: number): number;
    /**
     * Calulculates the control width
     * @returns the calculated width value
     */
    getWidth(): Nullable<number>;
    /**
     * Calculates the control height
     * @returns the calculated width value
     */
    getHeight(): Nullable<number>;
    /**
     * Verify if calculating the control size has finished.
     * @returns {boolean} true if ready
     */
    isReady(): boolean;
    /**
     * Verify if calculating the control width has finished.
     * @returns {boolean} true if ready
     */
    widthReady(): boolean;
    /**
     * Verify if calculating the control height has finished.
     * @returns {boolean} true if ready
     */
    heightReady(): boolean;
}
