import { ComponentService } from '../component.service';
import { EventService } from '../event.service';
import { FontService } from '../font.service';
import { PerformanceService } from '../performance/performance.service';
import { RenderStateService } from '../renderstate.service';
import { IBaseControl } from '../../../typedefinitions/models/controls/IBaseControl';
import { IControlSize } from './IControlSize';
import * as i0 from "@angular/core";
/**
 * The size tree service calculates control sizes
 */
export declare class SizeTreeService {
    /**
     * ComponentService
     */
    protected componentService: ComponentService;
    /**
     * EventService
     */
    protected eventService: EventService;
    /**
     * FontService
     */
    protected fontService: FontService;
    /**
     * PerformanceService
     */
    protected performanceService: PerformanceService;
    /**
     * RenderStateService
     */
    protected renderStateService: RenderStateService;
    private _containerWindow;
    private _controlSizeHashTable;
    private _calcVersion;
    private _windowResizedSubscription?;
    private _cssLoadedSubscription?;
    private _pageInitializedSubscription?;
    private _visibilityChangedSubscription?;
    private _mutationObserver;
    private _mutationObserverConfig;
    private printLogging;
    private printTreeWhenReady;
    /**
     * flag indicating whether the blaise-style CSS stylesheet has loaded
     */
    cssLoaded: boolean;
    /**
     * Size tree ready flag
     */
    isReady: boolean;
    /**
     * Scrollbar size value
     */
    scrollbarSize: number;
    /**
     * Flag indicating if the window container control is childless
     */
    get emptyRoot(): boolean;
    /**
     * Size tree service class constructor
     * @param componentService
     * @param eventService
     * @param fontService
     * @param performanceService
     * @param renderStateService
     */
    constructor(
    /**
     * ComponentService
     */
    componentService: ComponentService, 
    /**
     * EventService
     */
    eventService: EventService, 
    /**
     * FontService
     */
    fontService: FontService, 
    /**
     * PerformanceService
     */
    performanceService: PerformanceService, 
    /**
     * RenderStateService
     */
    renderStateService: RenderStateService);
    /**
     * (re)calculate the dimensions of each tree item.
     */
    calculate(): void;
    /**
     * Clears the window container control and adds the root control
     * @param root
     */
    setRootControlSize(root: IControlSize): void;
    /**
     * Sets the window container control size in pixels
     * @param width window container control width
     * @param height window container control height
     */
    setWindowSize(width: number, height: number): void;
    /**
     * Initializes the size tree by clearing any stored current child controls and sizes
     * @param windowWidth
     * @param windowHeight
     * @param scrollbarSize
     */
    initialize(windowWidth: number, windowHeight: number, scrollbarSize: number): void;
    /**
     * Control size creation factory
     * @param {IBaseControl} control Control for which to create a control size
     * @returns {Nullable<IControlSize>} size info for the given control
     */
    createControlSize(control: IBaseControl): Nullable<IControlSize>;
    /**
     * Add a component to the tree
     * @param child
     * @param parent
     */
    connect(child: IControlSize, parent: IControlSize): void;
    /**
     * Depth first search for a size object in the tree
     * @param id
     */
    find(id: string): Nullable<IControlSize>;
    /**
     * Recursively set all auto sized controls to the non-ready state by erasing the content width and height.
     */
    resetAutos(resetAutoWidth: boolean, resetAutoHeight: boolean): void;
    /**
     * Recursively set all auto sized controls to the non-ready state by erasing the content width and height.
     * @param controlSize
     * @param resetAutoWidth
     * @param resetAutoHeight
     */
    resetAutosRecursive(controlSize: IControlSize, resetAutoWidth: boolean, resetAutoHeight: boolean): void;
    /**
     * Log a textual version of the size-tree
     */
    printTree(level?: number): void;
    /**
     *
     * @param trigger
     * @param resetAutoWidth
     * @param resetAutoHeight
     * @private
     */
    private execute;
    /**
     * Depth first search for a size object in the tree
     * @param {string} name Branch/Leaf name
     * @param {IControlSize} controlSize Root control size
     * @returns {Nullable<IControlSize>} the found control size or null
     */
    private findRecursive;
    /**
     * Display log message to console
     * @param args
     */
    private log;
    /**
     * Display warning message in console
     * @param args
     */
    private warn;
    /**
     * Print a tree-node and it's children recursively
     * @param node
     * @param level
     */
    private printNode;
    /**
     * Detect controls with an auto size that only contain stretch children.
     * @param node
     */
    private detectAutoStretchCombinations;
    /**
     * Detect auto size grids with a star sized column
     */
    private detectAutoStarCombinations;
    /**
     * Get string version of unit size and value.
     * @param value
     * @param units
     * @param isGridUnitType
     * @returns unit size and value text
     */
    private getUnitSizeText;
    private handleMutationObserver;
    static ɵfac: i0.ɵɵFactoryDeclaration<SizeTreeService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SizeTreeService>;
}
