import { ColorService } from './color.service';
import { FontService } from './font.service';
import { HelperService } from './helper.service';
import { MediaService } from './media.service';
import { StylablePropertyService } from './stylable-property.service';
import { UserAgentService } from './user-agent.service';
import { CSSStyleObject } from '../../typedefinitions/models/style/CSSStyleObject';
import { IBaseControl } from '../../typedefinitions/models/controls/IBaseControl';
import { IBrush } from '../../typedefinitions/models/IBrush';
import { IFontInfo } from '../../typedefinitions/models/IFontInfo';
import { IHasFont, IHasFontName, IHasFontObject } from '../../typedefinitions/models/controls/properties/IHasFont';
import { ITableLayout } from '../../typedefinitions/models/ITableLayout';
import { IThickness } from '../../typedefinitions/models/IThickness';
import { IRealType } from '../../typedefinitions/models/value-types/IRealType';
import { IColor } from '../../typedefinitions/models/IColor';
import { ICornerRadius } from '../../typedefinitions/models/ICornerRadius';
import { IAlignmentStyle } from '../../typedefinitions/models/style/IAlignmentStyle';
import { IBackgroundStyle } from '../../typedefinitions/models/style/IBackgroundStyle';
import { IHorizontalAlignmentStyle } from '../../typedefinitions/models/style/IHorizontalAlignmentStyle';
import { IImageStyle } from '../../typedefinitions/models/style/IImageStyle';
import { IStrokeStyle } from '../../typedefinitions/models/style/IStrokeStyle';
import { IVerticalAlignmentStyle } from '../../typedefinitions/models/style/IVerticalAlignmentStyle';
import { HorizontalAlignment } from '../../typedefinitions/enums/HorizontalAlignment';
import { ImageStretch } from '../../typedefinitions/enums/ImageStretch';
import { VerticalAlignment } from '../../typedefinitions/enums/VerticalAlignment';
import { Visibility } from '../../typedefinitions/enums/Visibility';
import * as i0 from "@angular/core";
/**
 * Style generator service generates css style objects and strings for stylable properties and controls.
 */
export declare class StyleGeneratorService {
    private colorService;
    private fontService;
    private helperService;
    private mediaService;
    private stylablePropertyService;
    private userAgentService;
    /**
     * Style generator service class constructor
     * @param colorService
     * @param fontService
     * @param helperService
     * @param mediaService
     * @param stylablePropertyService
     * @param userAgentService
     */
    constructor(colorService: ColorService, fontService: FontService, helperService: HelperService, mediaService: MediaService, stylablePropertyService: StylablePropertyService, userAgentService: UserAgentService);
    /**
     * Applies border styling to a control
     * @param element https://docs.angularjs.org/api/ng/function/$ component element which can receive a border
     * @param control Object containing styling information
     */
    applyStrokeStyles(element: Element, control: IBaseControl): void | IStrokeStyle;
    /**
     * Generates a style object
     * @param control Object containing styling information
     * @param ignoreProperties properties to ignore
     * @returns style object
     */
    generateStyleObject(control: IBaseControl, ignoreProperties?: string[]): CSSStyleObject;
    /**
     * Generates a style object
     * @param control Object containing styling information
     * @param ignoreProperties properties to ignore
     * @returns style object
     */
    generateStyleObjectWithFont(control: IBaseControl & IHasFontObject, ignoreProperties?: string[]): CSSStyleObject;
    /**
     * Generates a style object
     * @param control
     * @param ignoreProperties
     * @returns
     */
    generateStyleObjectWithCombinedFont(control: IBaseControl & IHasFont & IHasFontName, ignoreProperties?: string[]): CSSStyleObject;
    /**
     * Generates an image scale style object
     * @param imageStretch image scale type
     * @param pixelWidth
     * @param pixelHeight
     * @returns image style object
     */
    generateImageScaleStyle(imageStretch: ImageStretch, pixelWidth?: number, pixelHeight?: number): IImageStyle;
    /**
     * Generates an alignment style object
     * @param control Object containing styling information
     * @param forText Indicates if the style object is created for a text container
     * @param flexDisplay If true, uses the flex alignment method
     */
    generateAlignmentObject(control: IBaseControl, forText?: boolean, flexDisplay?: boolean): IAlignmentStyle;
    /**
     * Generates a background style object
     * @param brush
     * @param defaultBg the background value to set as default. By default, this is `transparent`.
     */
    generateBackgroundStyle(brush: IBrush, defaultBg?: string): IBackgroundStyle;
    /**
     * Generates a border color style object
     * @param properties
     */
    generateBorderColorStyle(properties: IColor): CSSStyleObject;
    /**
     * Generates a border width style object
     * @param borderSize
     */
    generateBorderWidthStyle(borderSize: IThickness | number): CSSStyleObject;
    /**
     * Generates a border radius style object
     * @param properties
     */
    generateBorderRadiusStyle(properties: ICornerRadius): CSSStyleObject;
    /**
     * Generates a margin style object
     * @param properties
     */
    generateMarginStyle(properties: IThickness): CSSStyleObject;
    /**
     * Generates a padding style object
     * @param properties
     */
    generatePaddingStyle(properties: IThickness): CSSStyleObject;
    /**
     * Generates a visibility style class string
     * @param visibility
     */
    generateVisibilityStyle(visibility: Visibility): CSSStyleObject;
    /**
     * Generates a visibility style class string
     * @param visibility
     */
    getVisibilityClass(visibility: Visibility): string;
    /**
     * Generates a horizontal text alignment class string for IE and Edge specifically
     * @param alignment
     */
    getTextAlignmentClass(alignment: HorizontalAlignment): string;
    /**
     * Generates a horizontal text alignment style object
     * @param alignment
     */
    generateHorizontalTextAlignmentStyle(alignment: HorizontalAlignment): IHorizontalAlignmentStyle;
    /**
     * Generates a vertical text alignment style object
     * @param alignment
     */
    generateVerticalTextAlignmentStyle(alignment: VerticalAlignment): IVerticalAlignmentStyle;
    /**
     * Apply top padding for vertical text alignment
     * @param element
     * @param window
     * @param verticalTextAlignment
     */
    applyTopPaddingForVerticalTextAlignment(element: HTMLElement, window: Window, verticalTextAlignment: VerticalAlignment): void;
    /**
     * Helper function that generates an image background style object
     * @param sourceUrl
     * @param stretch
     */
    generateImageBackgroundStyle(sourceUrl: string, stretch: ImageStretch): CSSStyleObject;
    /**
     * Determine the maximum number of characters for a field based on the watermark (placeholder) and the value type ranges.
     * @param placeholder
     * @param valueType
     * @param max
     * @param thousandSeparator
     */
    getFieldMaxLength(placeholder: string, valueType: IRealType, max: number, thousandSeparator?: boolean): number;
    /**
     * Add grid lines style
     * @param dataObject
     * @param tableLayout
     */
    addGridLinesStyle(dataObject: IBaseControl, tableLayout: ITableLayout): void;
    /**
     * Get enabled class
     * @param enabled
     */
    getEnabledClass(enabled: boolean): string;
    /**
     * Copies font related properties from a style object to a new style object
     * @param original
     */
    copyFontStyle(original: CSSStyleObject): CSSStyleObject;
    /**
     * Generates a css font object based on properties of a server font object
     * @param font
     * @returns css font style object
     */
    generateFontStyle(font: IFontInfo): CSSStyleObject;
    /**
     * Generates a css font object based on properties of a server defined combined font object
     * @param FontName combined font key
     * @param Font fallback font information
     * @returns css font style object
     */
    generateCombinedFontStyle({ FontName, Font }: IHasFont): CSSStyleObject;
    /**
     * Retrieves the outline style from the control object's outline style property
     * @param control
     * @returns outline style as string
     */
    getOutlineStyle(control: IBaseControl): string;
    /**
     * Retrieves the outline width from the control object's outline width property
     * @param control
     * @returns outline pixel width
     */
    getOutlineWidth(control: IBaseControl): string;
    /**
     * Retrieves the outline color from the control object's outline color property
     * @param control
     * @returns outline rgba color
     */
    getOutlineColor(control: IBaseControl): string;
    /**
     * Retrieves the outline offset value from the control object's outline offset property
     * @param control
     * @returns outline offset value in pixels
     */
    getOutlineOffset(control: IBaseControl): string;
    /**
     * Retrieves the single line border information from the control properties
     * @param control
     * @returns border width in pixels or an empty string
     */
    getBorder(control: IBaseControl): string;
    /**
     * Retrieves the border width from the control object's stroke width property
     * @param control
     * @returns border width in pixels or an empty string
     */
    getBorderWidth(control: IBaseControl): string;
    /**
     * Retrieves the border style from the control object's stroke style property
     * @param control
     * @returns border style solid, dashed, dotted or none (default)
     */
    getBorderStyle(control: IBaseControl): string;
    /**
     * Retrieves the border color from the control object's stroke color property
     * @param control
     * @returns border rgba color
     */
    getBorderColor(control: IBaseControl): string;
    /**
     * Generates an alignment style object
     * @param control Object containing styling information
     */
    generateAlignmentCssVarsObject(control: IBaseControl): CSSStyleObject;
    /**
     * Helper function that determines a linear gradient direction by a start- and end-point
     * @param startPoint
     * @param endPoint
     * @returns gradient direction
     */
    private getLinearGradientDirection;
    /**
     * Helper function that generates a spacing style value string
     * @param properties Object containing properties top, right, bottom and/or left
     * @returns spacing style value string
     */
    private generateSpacingStyle;
    /**
     * Helper function that generates a horizontal overflow style object, depending on the width unit
     * @param properties
     * @param widthUnit
     */
    private generateHorizontalOverflowStyle;
    /**
     * Helper function that generates a vertical overflow style object, depending on the height unit
     * @param properties
     * @param heightUnit
     */
    private generateVerticalOverflowStyle;
    static ɵfac: i0.ɵɵFactoryDeclaration<StyleGeneratorService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<StyleGeneratorService>;
}
