import { BehaviorSubject, Observable, Subscription } from 'rxjs';
import { EventService } from './event.service';
import { IActionsEventHandler } from '../../typedefinitions/models/IActionsEventHandler';
import { IAuditTrailServerInfo } from '../../typedefinitions/models/server/IAuditTrailServerInfo';
import { IBaseControl } from '../../typedefinitions/models/controls/IBaseControl';
import { IClientSideShortcut } from '../../typedefinitions/models/server/IClientSideShortcut';
import { IDictionary } from '../../typedefinitions/models/IDictionary';
import { IError } from '../../typedefinitions/models/IError';
import { IFieldInfo } from '../../typedefinitions/models/observables/IFieldInfo';
import { IFieldPropertyReference } from '../../typedefinitions/models/controls/references/IFieldPropertyReference';
import { IFieldReference } from '../../typedefinitions/models/controls/references/IFieldReference';
import { ILookupState } from '../../typedefinitions/models/server/ILookupState';
import { IMenuItem } from '../../typedefinitions/models/IMenuItem';
import { IPayload } from '../../typedefinitions/models/server/payload/IPayload';
import { IRenderState } from '../../typedefinitions/models/server/IRenderState';
import { IRuntimeParameters } from '../../typedefinitions/models/IRuntimeParameters';
import { ISkipLink } from '../../typedefinitions/models/ISkipLink';
import * as i0 from "@angular/core";
/**
 * The subscription service provides a central hub for managing subjects and subscriptions.
 * Subscribe to subjects from this service to receive updates.
 */
export declare class SubscriptionService {
    protected eventService: EventService;
    private createChildControlSubject;
    /**
     * Dictionary containing control subjects with the control ID as key.
     */
    private _controlSubjects;
    /**
     * Dictionary containing menu-item control subjects with the menu-item control ID as key.
     */
    private _menuItemSubjects;
    /**
     * Root control subject
     */
    private _rootControlSubject;
    /**
     * Render state subject
     */
    private _renderStateSubject;
    /**
     * Client side shortcut array subject
     */
    private _clientSideShortcutsSubject;
    /**
     * Audit-trail server info subject
     */
    private _auditTrailServerInfoSubject;
    /**
     * On try leave page forward actions event handler subject
     */
    private _onTryLeavePageForwardSubject;
    /**
     * Survey-defined runtime parameters subject
     */
    private _runtimeParametersSubject;
    /**
     * A subscribable subject for managing a dictionary of skip links
     */
    private _skipLinksSubject;
    /**
     * A subscribable subject for managing record error changes
     */
    recordErrorsSubject: BehaviorSubject<Array<IError>>;
    /**
     * Field info subject array
     */
    fieldInfoSubjects: Array<BehaviorSubject<IFieldInfo>>;
    /**
     * An observable stream that emits when any field generates a new value.
     */
    allFieldsObservable: Nullable<Observable<IFieldInfo>>;
    /**
     * All fields subscription
     */
    allFieldsSubscription?: Subscription;
    /**
     * Lookup state subject array
     */
    lookupStateSubjects: Array<BehaviorSubject<ILookupState>>;
    /**
     * A dictionary that links control IDs to field names
     */
    referenceDictionary: IDictionary<string>;
    /**
     * Subscription service class constructor
     * @param eventService central hub for global application events
     */
    constructor(eventService: EventService);
    /**
     * Initializes the root control and render state subscriptions with a new server payload.
     * Always calls {@link cleanup} before parsing the payload.
     * @param payload Server payload containing required page information.
     */
    initialize(payload: IPayload): boolean;
    /**
     * Retrieves a subscribable field info subject using either an object reference, a field name or a field and property name.
     * @param arg0 An object reference or a field name
     * @param arg1 (optional) A field property name
     * @returns subscribable reference subject
     */
    getFieldSubject(arg0: string | IFieldReference | IFieldPropertyReference, arg1?: Nullable<string>): Optional<BehaviorSubject<IFieldInfo>>;
    /**
     * Retrieves a subscribable data value subject using either an object reference, a field name or a field and property name.
     * @param args An object reference or a field name and optionally a field property name
     * @returns field info
     */
    getFieldInfo(...args: any[]): Optional<IFieldInfo>;
    /**
     * Retrieves a subscribable lookup state subject by a given field name
     * @param fieldName field name
     * @returns subscribable lookup state subject
     */
    getLookupStateSubjectByFieldName(fieldName: string): Optional<BehaviorSubject<ILookupState>>;
    /**
     * Retrieves a lookup state by a given field name
     * @param fieldName field name
     * @returns lookup state
     */
    getLookupStateByFieldName(fieldName: string): Optional<ILookupState>;
    /**
     * Recursively create subscribable control subjects for a control and all its children
     * @param control any component
     */
    createControlSubjects(control: IBaseControl): void;
    /**
     * Get a control subject from the dictionary for a given control id key
     * @param id control key used to retrieve the control subject
     * @returns subscribable control subject
     */
    getControlSubjectById(id: string): Optional<BehaviorSubject<IBaseControl>>;
    /**
     * Get a control for a given control id key
     * @param id control key used to retrieve the control
     * @returns control
     */
    getControlById(id: string): Optional<IBaseControl>;
    /**
     * Get menu-item control subject from the dictionary for a given menu-item control id key
     * @param id menu-item control key used to retrieve the menu item control subject
     * @returns subscribable menu-item control subject
     */
    getMenuItemSubjectById(id: string): Optional<BehaviorSubject<IMenuItem>>;
    /**
     * Retrieves the subscribable render state subject
     */
    get renderStateSubject(): BehaviorSubject<Nullable<IRenderState>>;
    /**
     * Retrieves the subscribable root control subject
     */
    get rootControlSubject(): BehaviorSubject<Nullable<IBaseControl>>;
    /**
     * Updates the root control subject
     */
    set rootControl(rootControl: Nullable<IBaseControl>);
    /**
     * Retrieves the subscribable client side shortcuts subject
     */
    get clientSideShortcutsSubject(): BehaviorSubject<IClientSideShortcut[]>;
    /**
     * Updates the client side shortcuts subject
     * @param clientSideShortcuts list of user-defined client-side shortcuts
     */
    set clientSideShortcuts(clientSideShortcuts: IClientSideShortcut[]);
    /**
     * Returns the subscribable audit-trail server info subject
     */
    get auditTrailServerInfoSubject(): BehaviorSubject<Nullable<IAuditTrailServerInfo>>;
    /**
     * Retrieves the audit-trail server info
     */
    get auditTrailServerInfo(): Nullable<IAuditTrailServerInfo>;
    /**
     * Retrieves the audit-trail server info
     */
    set auditTrailServerInfo(auditTrailServerInfo: Nullable<IAuditTrailServerInfo>);
    /**
     * Retrieves the survey-defined subscribable runtime parameters subject
     */
    get runtimeParametersSubject(): BehaviorSubject<Nullable<IRuntimeParameters>>;
    /**
     * Gets the survey-defined runtime parameters
     * @returns runtime parameters
     */
    get runtimeParameters(): Nullable<IRuntimeParameters>;
    /**
     * Gets the survey-defined runtime parameters
     * @returns runtime parameters
     */
    set runtimeParameters(runtimeParameters: Nullable<IRuntimeParameters>);
    /**
     * Retrieves the subscribable skip links dictionary subject
     */
    get skipLinksSubject(): BehaviorSubject<IDictionary<ISkipLink>>;
    /**
     * Gets the skip links
     * @returns skip links
     */
    get skipLinks(): IDictionary<ISkipLink>;
    /**
     * Updates the skip links dictionary
     * @returns runtime parameters
     */
    set skipLinks(skipLinks: IDictionary<ISkipLink>);
    /**
     * Gets an array of available skip links
     * @returns skip links
     */
    get skipLinksArray(): ISkipLink[];
    /**
     * Retrieves on try leave page forward actions event handler object
     */
    get onTryLeavePageForward(): Nullable<IActionsEventHandler>;
    /**
     * Updates the on try leave page forward actions event handler subject
     * @param actionsEventHandler on try leave page forward actions event handler
     */
    set onTryLeavePageForward(actionsEventHandler: Nullable<IActionsEventHandler>);
    /**
     * Clean up all subscriptions, subjects and objects
     */
    private cleanup;
    /**
     * Creates a behavior subject for a control and adds it to the dictionary
     * @param control control for which to create a subscribable subject
     */
    private createControlSubject;
    /**
     * Creates behavior subjects for a list of menu item controls and adds them to the dictionary
     * @param menuItems menu item controls for which to create subscribable subjects
     */
    private createMenuItemSubjects;
    /**
     * Creates a behavior subject for a menu item control and adds it to the dictionary
     * @param item menu item control for which to create a subscribable subject
     */
    private createMenuItemSubscription;
    /**
     * Creates field info subject from a list of fields and their properties and adds them to a list.
     * Creates one merged observable for all the field info subjects and subscribes to changes of that observable.
     * @param fields list of fields
     */
    private createSubscriptionsForFields;
    /**
     * Creates a subscribable field info subject and adds it as an entry to the list of field info subjects
     * @param fieldInfo field info object for which to create a subscribable subject
     * @return subscribable field info subject
     */
    private addFieldInfoSubject;
    /**
     * Creates lookup state behavior subjects for a list of fields and adds them a list
     * @param fields fields for which to create subscribable lookup state subjects
     */
    private createLookupStateSubjectsForFields;
    /**
     * Creates lookup state behavior subject for a field and adds it a list
     * @param field field for which to create a subscribable lookup state subject
     */
    private addLookupStateSubject;
    /**
     * Creates a lookup state object
     * @param fieldName Name of the field for which to create a lookup state object
     * @param dataSource Field's data source info
     * @param lookupInformation Field's lookup info
     */
    private createLookupStateObject;
    /**
     * Populates the reference dictionary with control ID properties with field name values
     */
    private createReferenceDictionary;
    /**
     * Retrieves a field info subject for a field property by its field name and a field property name
     * @param fieldName name of the field for which to retrieve a property's field info subject
     * @param fieldPropertyName name of the field's property for which to retrieve field info subject
     * @returns field info subject
     */
    private getFieldSubjectByFieldPropertyName;
    /**
     * Retrieves a field info subject for a field or field property by field name
     * @param fieldName name of the field for which to retrieve a data value subscription
     * @returns field info subject
     */
    private getFieldSubjectByFieldName;
    private updateRecordErrorsSubject;
    /**
     * Field reference type check function
     * @param obj possible field reference
     */
    private isFieldReference;
    /**
     * Field property reference type check function
     * @param obj possible field reference
     */
    private isFieldPropertyReference;
    private lowerCaseStringCompare;
    static ɵfac: i0.ɵɵFactoryDeclaration<SubscriptionService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SubscriptionService>;
}
