/**
 * **Landmark roles:** Roles that are regions of the page intended as navigational landmarks. All of these roles inherit from the landmark base type and, except for application, all are imported from the Role Attribute.
 *
 * * application | A region declared as a web application, as opposed to a web document.
 * * article | A section of a page that consists of a composition that forms an independent part of a document, page, or site.
 * * banner | A region that contains mostly site-oriented content, rather than page-specific content.
 * * complementary | A supporting section of the document, designed to be complementary to the main content at a similar level in the DOM hierarchy, but remains meaningful when separated from the main content.
 * * content info | A large perceivable region that contains information about the parent document.
 * * directory | A list of references to members of a group, such as a static table of contents.
 * * document | A region containing related information that is declared as document content, as opposed to a web application.
 * * form | A landmark region that contains a collection of items and objects that, as a whole, combine to create a form. See related search.
 * * log | A type of live region where new information is added in meaningful order and old information may disappear. See related marquee. Note: Elements with the role log have an implicit aria-live value of polite.
 * * main | The main content of a document.
 * * navigation | A collection of navigational elements (usually links) for navigating the document or related documents.
 * * note | A section whose content is parenthetic or ancillary to the main content of the resource.
 * * region | A large perceivable section of a web page or document, that the author feels is important enough to be included in a page summary or table of contents, for example, an area of the page containing live sporting event statistics.
 * * search | A landmark region that contains a collection of items and objects that, as a whole, combine to create a search facility. See related form.
 * * status | A container whose content is advisory information for the user but is not important enough to justify an alert, often but not necessarily presented as a status bar. See related alert. Note: Elements with the role status have an implicit aria-live value of polite.
 *
 * **Widget roles:** Roles that act as standalone user interface widgets or as part of larger, composite widgets.
 *
 * * alert | A message with important, and usually time-sensitive, information. See related alertdialog and status. Note: Elements with the role alert have an implicit aria-live value of assertive.
 * * alertdialog | A type of dialog that contains an alert message, where initial focus goes to an element within the dialog. See related alert and dialog.
 * * button | An input that allows for user-triggered actions when clicked or pressed. See related link.
 * * checkbox | A check-able input that has three possible values: true, false, or mixed.
 * * column-header | A cell containing header information for a column.
 * * combobox | A presentation of a select; usually similar to a textbox where users can type ahead to select an option, or type to enter arbitrary text as a new item in the list. See related listbox.
 * * definition | A definition of a term or concept.
 * * dialog | A dialog is an application window that is designed to interrupt the current processing of an application in order to prompt the user to enter information or require a response. See related alertdialog.
 * * directory | A list of references to members of a group, such as a static table of contents.
 * * grid | A grid is an interactive control which contains cells of tabular data arranged in rows and columns, like a table.
 * * grid-cell | A cell in a grid or tree grid.
 * * group | A set of user interface objects which are not intended to be included in a page summary or table of contents by assistive technologies.
 * * heading | A heading for a section of the page.
 * * img | A container for a collection of elements that form an image.
 * * link | An interactive reference to an internal or external resource that, when activated, causes the user agent to navigate to that resource. See related button.
 * * list | A group of non-interactive list items. See related list-box.
 * * list-box | A widget that allows the user to select one or more items from a list of choices. See related combobox and list.
 * * list-item | A single item in a list or directory.
 * * marquee | A type of live region where non-essential information changes frequently. See related log. Note: Elements with the role marquee maintain the default aria-live value of off.
 * * math | Content that represents a mathematical expression.
 * * menu | A type of widget that offers a list of choices to the user.
 * * menubar | A presentation of menu that usually remains visible and is usually presented horizontally.
 * * menuitem | An option in a group of choices contained by a menu or menubar.
 * * menu-item-checkbox | A check-able menuitem that has three possible values: true, false, or mixed.
 * * menu-item-radio | A check-able menuitem in a group of menu-item-radio roles, only one of which can be checked at a time.
 * * option | A selectable item in a select list.
 * * presentation | An element whose implicit native role semantics will not be mapped to the accessibility API.
 * * progressbar | An element that displays the progress status for tasks that take a long time. Note: Elements with the role progressbar have an implicit aria-readonly value of true.
 * * radio | A check-able input in a group of radio roles, only one of which can be checked at a time.
 * * radio-group | A group of radio buttons.
 * * row | A row of cells in a grid.
 * * row-group | A group containing one or more row elements in a grid.
 * * row-header | A cell containing header information for a row in a grid.
 * * scrollbar | A graphical object that controls the scrolling of content within a viewing area, regardless of whether the content is fully displayed within the viewing area.  Note: Elements with the role scrollbar have an implicit aria-orientation value of vertical.
 * * separator | A divider that separates and distinguishes sections of content or groups of menu items.
 * * slider | A user input where the user selects a value from within a given range.
 * * spin-button | A form of range that expects the user to select from among discrete choices.
 * * tab | A grouping label providing a mechanism for selecting the tab content that is to be rendered to the user.
 * * tab-list | A list of tab elements, which are references to tab panel elements.
 * * tab-panel | A container for the resources associated with a tab, where each tab is contained in a tab list.
 * * textbox | Input that allows free-form text as its value.
 * * timer | A type of live region containing a numerical counter which indicates an amount of elapsed time from a start point, or the time remaining until an end point.
 * * toolbar | A collection of commonly used function buttons represented in compact visual form.
 * * tooltip | A contextual popup that displays a description for an element.
 * * tree | A type of list that may contain sublevel nested groups that can be collapsed and expanded.
 * * tree-grid | A grid whose rows can be expanded and collapsed in the same manner as for a tree.
 * * tree-item | An option item of a tree. This is an element within a tree that may be expanded or collapsed if it contains a sublevel group of tree items.
 */
export declare enum AriaRole {
    /**
     * A message with important, and usually time-sensitive, information. See related alertdialog and status.
     * Note: Elements with the role alert have an implicit aria-live value of assertive.
     */
    Alert = "alert",
    /**
     * A type of dialog that contains an alert message, where initial focus goes to an element within the dialog. See related alert and dialog.
     */
    Alertdialog = "alertdialog",
    /**
     * An input that allows for user-triggered actions when clicked or pressed. See related link.
     */
    Button = "button",
    /**
     * A checkable input that has three possible values: true, false, or mixed.
     */
    Checkbox = "checkbox",
    /**
     * A presentation of a select; usually similar to a textbox where users can type ahead to select an option, or type to enter arbitrary text as a new item in the list. See related listbox.
     */
    Combobox = "combobox",
    /**
     * A dialog is an application window that is designed to interrupt the current processing of an application in order to prompt the user to enter information or require a response. See related alertdialog.
     */
    Dialog = "dialog",
    /**
     * A grid is an interactive control which contains cells of tabular data arranged in rows and columns, like a table.
     */
    Grid = "grid",
    /**
     * A cell in a grid or treegrid.
     */
    Gridcell = "gridcell",
    /**
     * An interactive reference to an internal or external resource that, when activated, causes the user agent to navigate to that resource. See related button.
     */
    Link = "link",
    /**
     * A widget that allows the user to select one or more items from a list of choices. See related combobox and list.
     */
    Listbox = "listbox",
    /**
     * A type of live region where new information is added in meaningful order and old information may disappear. See related marquee.
     * Note: Elements with the role log have an implicit aria-live value of polite.
     */
    Log = "log",
    /**
     * A type of live region where non-essential information changes frequently. See related log.
     * Note: Elements with the role marquee maintain the default aria-live value of off.
     */
    Marquee = "marquee",
    /**
     * A type of widget that offers a list of choices to the user.
     */
    Menu = "menu",
    /**
     * A presentation of menu that usually remains visible and is usually presented horizontally.
     */
    Menubar = "menubar",
    /**
     * An option in a group of choices contained by a menu or menubar.
     */
    Menuitem = "menuitem",
    /**
     * A check-able menu item that has three possible values: true, false, or mixed.
     */
    Menuitemcheckbox = "menuitemcheckbox",
    /**
     * A check-able menu item in a group of menuitemradio roles, only one of which can be checked at a time.
     */
    Menuitemradio = "menuitemradio",
    /**
     * A selectable item in a select list.
     */
    Option = "option",
    /**
     * An element whose implicit native role semantics will not be mapped to the accessibility API.
     */
    Presentation = "presentation",
    /**
     * An element that displays the progress status for tasks that take a long time.
     * Note: Elements with the role progressbar have an implicit aria-readonly value of true.
     */
    Progressbar = "progressbar",
    /**
     * A check-able input in a group of radio roles, only one of which can be checked at a time.
     */
    Radio = "radio",
    /**
     * A group of radio buttons.
     */
    Radiogroup = "radiogroup",
    /**
     * An element with role="row" is a row of cells within a tabular structure. A row contains one or more cells, grid cells or column headers,
     * and possibly a row header, within a grid, table or treegrid, and optionally within a rowgroup.
     */
    Row = "row",
    /**
     * A graphical object that controls the scrolling of content within a viewing area, regardless of whether the content is fully displayed within the viewing area.
     * Note: Elements with the role scrollbar have an implicit aria-orientation value of vertical.
     */
    Scrollbar = "scrollbar",
    /**
     * A user input where the user selects a value from within a given range.
     */
    Slider = "slider",
    /**
     * A form of range that expects the user to select from among discrete choices.
     */
    Spinbutton = "spinbutton",
    /**
     * A container whose content is advisory information for the user but is not important enough to justify an alert, often but not necessarily presented as a status bar. See related alert.
     * Note: Elements with the role status have an implicit aria-live value of polite.
     */
    Status = "status",
    /**
     * A grouping label providing a mechanism for selecting the tab content that is to be rendered to the user.
     */
    Tab = "tab",
    /**
     * A list of tab elements, which are references to tab panel elements.
     */
    Tablist = "tablist",
    /**
     * A container for the resources associated with a tab, where each tab is contained in a tab list.
     */
    Tabpanel = "tabpanel",
    /**
     * Input that allows free-form text as its value.
     */
    Textbox = "textbox",
    /**
     * A type of live region containing a numerical counter which indicates an amount of elapsed time from a start point, or the time remaining until an end point.
     */
    Timer = "timer",
    /**
     * A contextual popup that displays a description for an element.
     */
    Tooltip = "tooltip",
    /**
     * A type of list that may contain sublevel nested groups that can be collapsed and expanded.
     */
    Tree = "tree",
    /**
     * A grid whose rows can be expanded and collapsed in the same manner as for a tree.
     */
    Treegrid = "treegrid",
    /**
     * An option item of a tree. This is an element within a tree that may be expanded or collapsed if it contains a sublevel group of tree items.
     */
    Treeitem = "treeitem"
}
