/**
 * The aria options interface describes the properties of the aria accessibility class.
 * [ARIA](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA) for more information.
 * [ARIA cheat sheet](https://dev.to/w3tsa/aria-cheatsheet-k9e)
 */
export interface IAriaOptions {
    /**
     * Indicates the current "checked" state of checkboxes and radio buttons.
     */
    checked: boolean;
    /**
     * Indicates the current "selected" state of an element.
     */
    selected: boolean;
    /**
     * Defines a string value that labels an interactive element.
     */
    label: string;
    /**
     * Defines the element that is labelled by the element this is applied to.
     */
    labelFor?: string;
    /**
     * Identifies the element (or elements) that labels the element it is applied to.
     */
    labelledBy: string;
    /**
     * Indicates that the element is perceivable but disabled, so it is not editable or otherwise operable.
     */
    disabled: Optional<boolean>;
    /**
     * Indicates whether the element is exposed to an accessibility API.
     */
    hidden: boolean;
    /**
     * Indicates the entered value does not conform to the format expected by the application.
     */
    invalid: boolean;
    /**
     * A space-separated list of id property values.
     * Identifies an element (or elements) in order to define a visual, functional, or contextual relationship between a parent and its child elements when the DOM hierarchy cannot be used to represent the relationship.
     */
    owns: string;
    /**
     * Is set on an element to indicate if a control is expanded or collapsed, and whether or not the controlled elements are displayed or hidden.
     * The expanded state can have the following values:
     * * **true**: The element is expanded.
     * * **false**: The element is not expanded.
     * * **undefined**: Default. The element state is unknown.
     */
    expanded: boolean;
    /**
     * Identifies the element (or elements) that describes the element on which the attribute is set.
     */
    describedBy: string;
    /**
     *
     * * **inline**: The system provides text after the caret as a suggestion for how to complete the field.
     * * **list**: A list of choices appears from which the user can choose, but the edit box retains focus.
     * * **both**: A list of choices appears and the currently selected suggestion also appears inline.
     * * **none**: No input completion suggestions are provided.
     */
    autoComplete: string;
    /**
     * The id property value of the descendent element.
     */
    activeDescendant: string;
    /**
     * Defines a human-readable, author-localized description for the role of an element.
     */
    role: string;
    /**
     * Indicates that an element will be updated, and describes the types of updates the user agents, assistive technologies, and user can expect from the live region.
     * * **off**: Default. Updates should not be announced.
     * * **polite**: Updates should only be announced if the user is idle.
     * * **assertive**: Updates should be announced to the user as soon as possible.
     * * **rude**: Updates should be announced immediately, interrupting the user if necessary.
     */
    live: string;
    /**
     * Indicates what notifications the user agent will trigger when the accessibility tree within a live region is modified.
     * This space-delimited list can consist of one or more of the following values:
     * * **additions**: Insertion of nodes into the live region should be considered relevant.
     * * **removals**: Deletion of nodes should be considered relevant.
     * * **text**: Changes to the textual content of existing nodes should be considered relevant.
     * * **all**: Equivalent to additions removals text.
     */
    relevant?: string;
    /**
     * Indicates whether assistive technologies such as a screen reader will present all, or only parts of, the changed region based on the change notifications defined by the aria-relevant attribute.
     * A value that specifies how to present change notifications.
     * * **true**: Present the region as a whole when changes are detected.
     * * **false**: Default. Present only the changed regions.
     */
    atomic: boolean;
    /**
     * Indicates an element is being modified and that assistive technologies may want to wait until the changes are complete before informing the user about the update.
     * The busy state can consist of the following values:
     * * **true**: The region is loading.
     * * **false**: Default. Clear the busy state.
     * * **error**: The region is invalid.
     */
    busy: boolean;
    /**
     * Indicates that user input is required on the element before a form may be submitted.
     */
    required: boolean;
}
