import { IAuditTrailEvent } from '../events/IAuditTrailEvent';
import { ICustomAuditTrailEvent } from '../events/ICustomAuditTrailEvent';
import { AuditTrailLevel } from '../enums/AuditTrailLevel';
/**
 * The audit trail service provides functionality for tracking user behaviour
 */
export interface IAuditTrailService {
    /**
     * Flag indicator for outstanding audit-trail send-events
     */
    readonly hasOutStandingEvents: boolean;
    /**
     * Outstanding audit-trail send-events
     */
    readonly outStandingEvents: IAuditTrailEvent[];
    /**
     * The current timestamp in the correct format
     */
    readonly timeStamp: string;
    /**
     * Audit trail http post path
     */
    auditTrailPath: string;
    /**
     * Subscribes to the audit trail server info service subscription
     */
    initialize: () => void;
    /**
     * Logs an action event if the minimum audit trail level for this action meets the configured  level
     * @param actionName Name of the action to log
     * @param controlId Id of the control on which the action has taken place
     * @param minimumLevel Minimum audit trail log level to meet for the logging to take place, default is Answer
     * @param args (optional) Extra optional arguments to add to the log message.
     */
    logActionEvent: (actionName: string, controlId: string, minimumLevel?: AuditTrailLevel, args?: string[]) => void;
    /**
     * Logs a keystroke event if the minimum audit trail level for this action meets the configured level
     * @param event The keystroke event to log
     */
    logKeyStrokeEvent: (event: KeyboardEvent) => void;
    /**
     * Logs an enter field event if the configured audit trail level is `Field` or higher
     * @param fieldName Name of the entered field
     * @param answerStatus Current answer status of the entered field
     * @param value Current value as string or special answer value of the entered field
     * @param isSpecialAnswer If true, the value is a special answer value with an answer status of 2.
     */
    logEnterFieldEvent: (fieldName: string, answerStatus: number, value: string, specialAnswer: boolean) => void;
    /**
     * Logs a leave field event if the configured audit trail level is `Field` or higher
     * @param fieldName Name of the field that has been left
     * @param answerStatus Current answer status of the left field
     * @param value Current value as string or special answer value of the left field
     * @param isSpecialAnswer If true, the value is a special answer value with an answer status of 2.
     */
    logLeaveFieldEvent: (fieldName: string, answerStatus: number, value: string, specialAnswer: boolean) => void;
    /**
     * Logs a classify event if the configured audit trail level is `Answer` or higher
     * @param code Currently selected classification event code
     * @param classificationAction Classification action code (eg. Expand, Select)
     */
    logClassifyEvent: (code: string, classificationAction: string) => void;
    /**
     * Logs a category event if the configured audit trail level is `Answer` or higher
     * @param isSelected True if the category is checked/selected, otherwise false.
     * @param code The code of the category (radio) button or checkbox for which the value was changed
     */
    logCategoryEvent: (isSelected: boolean, code: number) => void;
    /**
     * Logs a special answer event if the configured audit trail level is `Answer` or higher
     * @param isSelected True if the special is selected, otherwise false.
     * @param name Special answer name
     */
    logSpecialAnswerEvent: (isSelected: boolean, name: string) => void;
    /**
     * Logs a go to uri event if the configured audit trail level is `Answer` or higher
     * @param uri The destination uri
     */
    logGoToURIEvent: (uri: string) => void;
    /**
     * Logs a toggle visibility event if the configured audit trail level is `Answer` or higher
     * @param controlName The name of the control for which the visibility has changed
     */
    logToggleVisibilityEvent: (controlName: string) => void;
    /**
     * Logs an enter field property event if the configured audit trail level is `Answer` or higher
     * @param fieldName Name of the field of which a field property's control has been entered
     * @param fieldPropertyName Name of the field's property of which a control has been entered
     * @param value Current value of the entered field property
     */
    logEnterFieldPropertyEvent: (fieldName: string, fieldPropertyName: string, value: string) => void;
    /**
     * Logs a leave field property event if the configured audit trail level is `Answer` or higher
     * @param fieldName Name of the field of which a field property's control has been left
     * @param fieldPropertyName Name of the field's property of which a control has been left
     * @param value Current value of the left field property
     */
    logLeaveFieldPropertyEvent: (fieldName: string, fieldPropertyName: string, value: string) => void;
    /**
     * Logs a custom collection of properties to the audit trail if audit trail is enabled.
     * @param eventData Collection of properties.
     */
    logCustomAuditTrailEvent: (eventData: ICustomAuditTrailEvent) => void;
    /**
     * Logs a range error event if the configured audit trail level is `Answer` or higher
     * @param fieldName Name of the field which is involved with the range error
     * @param value The current value which triggered the range error
     * @param answerStatus The current answer status of the field
     * @param errorMessage The error message
     */
    logRangeErrorEvent: (fieldName: string, value: string, answerStatus: string, errorMessage: string) => void;
}
