import { IBaseControl } from '../models/controls/IBaseControl';
import { IDictionary } from '../models/IDictionary';
/**
 * The custom property service is used to make working with custom properties easier.
 * As these properties can have any name, editors cannot provide auto-completion for
 * them when working with controls.
 */
export interface ICustomPropertyService {
    /**
     * Checks if all provided custom properties exist on a given control.
     * @param {IBaseControl} control The control for which to check the custom properties
     * @param {Array<string>} properties The names of the custom properties
     * @returns {boolean} true if all specified custom properties are found, otherwise false
     */
    hasCustomProperties: (control: IBaseControl, ...properties: string[]) => boolean;
    /**
     * Indicates whether a given control contains a specified custom property
     * @param {IBaseControl} control The control for which to check the custom property
     * @param {string} property The name of the custom property
     * @returns {boolean} true if the custom property was found, otherwise false
     */
    hasCustomProperty: (control: IBaseControl, property: string) => boolean;
    /**
     * Retrieves values for all provided custom properties and returns them as a dictionary.
     * @param {IBaseControl} control The control for which to check the custom properties
     * @param {Array<string>} properties The names of the custom properties
     * @returns {IDictionary<any>} Dictionary object with property name as key
     */
    getValuesForCustomProperties: (control: IBaseControl, ...properties: string[]) => IDictionary<any>;
    /**
     * Returns the value for a specified custom property from a given control
     * @param {IBaseControl} control The control from which to retrieve the custom property value
     * @param {string} property The name of the custom property for which to return a value
     * @returns {any} If found, the value for the provided custom property, otherwise null
     */
    getValueForCustomProperty: (control: IBaseControl, property: string) => any;
    /**
     * Tries to retrieve values for all provided custom properties and returns them as a dictionary.
     * @param {IBaseControl} control The control for which to check the custom properties
     * @param {Array<string>} properties The names of the custom properties
     * @param {Function} out callback function with an object with all found properties as argument
     * @returns {boolean} true if all specified custom properties are found, otherwise false
     */
    tryGetValuesForCustomProperties: (control: IBaseControl, properties: string[], out: (valueObj: object) => void) => boolean;
    /**
     * Tries to return the value for a specified custom property from a given control
     * @param {IBaseControl} control The control for which to check the custom property
     * @param {string} property The name of the custom property
     * @param {Function} out callback function with the found property aas argument
     * @returns {boolean} true if the custom property was found, otherwise false
     */
    tryGetValueForCustomProperty: (control: IBaseControl, property: string, out: (value: any) => void) => boolean;
    /**
     * Sets the value for a specified custom property on a given control
     * @param {IBaseControl} control The control on which to set the custom property value
     * @param {string} property The name of the custom property for which to set a value
     * @param {any} value The value to be set on the custom property
     */
    setValueForCustomProperty: (control: IBaseControl, property: string, value: any) => void;
}
