/**
 * Key code service is used to evaluate the kind of key pressed
 */
export interface IKeyCodesService {
    /**
     * Checks whether the key pressed is alphabetic
     * @param {number} key The key code
     * @param {Optional<Array<number>>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is a roman alphabet key, otherwise false
     */
    isAlpha: (key: number, allowed?: number[]) => boolean;
    /**
     * Checks whether the key pressed is alphanumeric
     * @param {number} key The key code
     * @param {Optional<Array<number>>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is an alphanumeric key, otherwise false
     */
    isAlphaNumeric: (key: number, allowed?: number[]) => boolean;
    /**
     * Checks whether the key is a valid decimal separator
     * @param {number} key The key code
     * @param {Optional<Array<number>>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is a valid decimal separator, otherwise false
     */
    isDecimalSeparatorKey: (key: number, allowed?: number[]) => boolean;
    /**
     * Checks whether the key is an edit key (Backspace or Delete)
     * @param {number} key The key code
     * @param {Array<number>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is an edit key, otherwise false
     */
    isEditKey: (key: number, allowed: number[]) => boolean;
    /**
     * Checks whether the pressed keys are CTRL+C, CTRL+X, CTRL+V or CTRL+A
     * @param {number} key The key code
     * @param {Optional<boolean>} ctrl (optional) flag
     * @returns {boolean} true, if the pressed keys are copy, cut, paste or select all command keys, otherwise false
     */
    isCopyOrPasteKey: (key: number, ctrl?: boolean) => boolean;
    /**
     * Checks whether the key is a function key (F1 - F12)
     * @param {number} key The key code
     * @param {Optional<Array<number>>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is a function key, otherwise false
     */
    isFunctionKey: (key: number, allowed?: number[]) => boolean;
    /**
     * Checks whether the key is a digit key
     * @param {number} key The key code
     * @param {Optional<Array<number>>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is a digit key, otherwise false
     */
    isDigitKey: (key: number, allowed?: number[]) => boolean;
    /**
     * Checks whether the key pressed is numeric
     * @param {number} key The key code
     * @param {Optional<Array<number>>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is numeric, otherwise false
     */
    isNumPadKey: (key: number, allowed?: number[]) => boolean;
    /**
     * Checks whether the key is a num-pad key
     * @param {number} key The key code
     * @param {Optional<Array<number>>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is a num-pad key, otherwise false
     */
    isZeroKey: (key: number, allowed?: number[]) => boolean;
    /**
     * Checks whether the key is a zero key
     * @param {number} key The key code
     * @param {Optional<Array<number>>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is a zero key, otherwise false
     */
    isMinusKey: (key: number, allowed?: number[]) => boolean;
    /**
     * Checks whether the key is the minus key
     * @param {number} key The key code
     * @param {Optional<Array<number>>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is the minus key, otherwise false
     */
    isNumeric: (key: number, allowed?: number[]) => boolean;
    /**
     * Checks whether the key pressed is a possible date separator
     * @param {number} key The key code
     * @param {Optional<Array<number>>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is a possible date separator, otherwise false
     */
    isDateSeparatorKey: (key: number, allowed?: number[]) => boolean;
    /**
     * Checks whether the key pressed is a possible time separator
     * @param {number} key The key code
     * @param {Array<number>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is a possible time separator, otherwise false
     */
    isTimeSeparatorKey: (key: number, allowed: number[]) => boolean;
    /**
     * Checks whether the key pressed is a possible am-pm designator key
     * @param {string} character
     * @param {string} amPm
     * @returns {boolean} true, if the key pressed is a possible am-pm designator key, otherwise false
     */
    isAmPmDesignatorKey: (character: string, amPm: string) => boolean;
    /**
     * Checks whether the key pressed is a navigation key
     * @param {number} key The key code
     * @param {Optional<Array<number>>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is a navigation key, otherwise false
     */
    isNavigationKey: (key: number, allowed?: number[]) => boolean;
    /**
     * Checks whether the key pressed is an arrow key
     * @param {number} key The key code
     * @param {Optional<Array<number>>} allowed (optional) Array of additional allowed keystrokes
     * @returns {boolean} true, if the key pressed is an arrow key, otherwise false
     */
    isArrowKey: (key: number, allowed?: number[]) => boolean;
}
