import { IDataEntrySettingsInfo } from '../models/server/IDataEntrySettingsInfo';
import { IDictionary } from '../models/IDictionary';
import { IFieldInfo } from '../models/observables/IFieldInfo';
import { IError } from '../models/IError';
import { IField } from '../models/IField';
import { IFieldProperty } from '../models/IFieldProperty';
import { IGroup } from '../models/IGroup';
import { IInvolvedField } from '../models/IInvolvedField';
import { IRouteItemReference } from '../models/IRouteItemReference';
import { IDataSource } from '../models/server/data-source/IDataSource';
import { ILanguageInfo } from '../models/server/ILanguageInfo';
import { ILayoutModelState } from '../models/server/ILayoutModelState';
import { ILookupInformation } from '../models/server/ILookupInformation';
import { IPage } from '../models/server/IPage';
import { IRenderState } from '../models/server/IRenderState';
import { IRuntimeSettings } from '../models/server/IRuntimeSettings';
import { ISection } from '../models/ISection';
import { ITextBox } from '../models/ITextBox';
import { KeyboardNavigation } from '../enums/KeyboardNavigation';
import { NavigationMode } from '../enums/NavigationMode';
/**
 * The render state service interface
 */
export interface IRenderStateService {
    /**
     * The render state object. When set, the service converts all date and time values to the right format
     */
    renderState: Nullable<IRenderState>;
    /**
     * The read-only property layout model state from the render state
     */
    readonly layoutModelState: Nullable<ILayoutModelState>;
    /**
     * The read-only property active culture id from the render state's layout model state
     */
    readonly activeCultureId: string;
    /**
     * The read-only property language name from the render state's layout model state that represents the currently active language
     */
    readonly languageName: string;
    /**
     * The read-only array property language info from the render state's layout model state that contains all relevant defined languages
     */
    readonly languageInfo: Nullable<ILanguageInfo[]>;
    /**
     * The current language info from the render state's layout model state
     */
    readonly currentLanguage: Optional<ILanguageInfo>;
    /**
     * The read-only property style name from the render state's layout model state as a read-only property
     */
    readonly styleName: string;
    /**
     * The read-only property resource set name from the render state's layout model state
     */
    readonly resourceSetName: string;
    /**
     * The read-only property resource language name from the render state's layout model state
     */
    readonly resourceLanguageName: string;
    /**
     * The read-only property parallel name from the render state's layout model state
     */
    readonly parallelName: string;
    /**
     * The previous parallel name from the render state's layout model state
     */
    previousParallelName: string;
    /**
     * Read-only flag indicating that the parallel name has changed
     */
    readonly parallelNameHasChanged: boolean;
    /**
     * The read-only property rule session id string from the render state's layout model state
     */
    readonly ruleSessionId: string;
    /**
     * The valid appointment flag from the render state's layout model state
     */
    hasValidAppointment: boolean;
    /**
     * The read-only property active field name from the render state's layout model state
     */
    readonly activeFieldName: string;
    /**
     * The read-only property active field property name from the render state's layout model state
     */
    readonly activeFieldPropertyName: Nullable<string>;
    /**
     * Function to set a provided field (property) name as the active field (property) name on the render state's layout model state
     * @param {string} fieldName new active field name
     * @param {Optional<string>} fieldPropertyName (optional)
     * @param {Optional<string>} eventSource (optional)
     * @param {Optional<string>} elementId (optional)
     * @param {Optional<string>} triggerFocus (optional)
     */
    setActiveFieldName: (fieldName: string, fieldPropertyName?: string, source?: string, elementId?: string) => void;
    /**
     * The read-only property actual layout set name from the render state's layout model state
     */
    readonly actualLayoutSetName: string;
    /**
     * The read-only property page index from the render state's layout model state representing the current page's index
     */
    readonly pageIndex: number;
    /**
     * The previous value of the page index, used to monitor change
     */
    previousPageIndex: number;
    /**
     * Read-only flag indicating if the page index has changed with respect to its previous value
     */
    readonly pageIndexHasChanged: boolean;
    /**
     * The read-only property for the highest page index from the render state's layout model state
     */
    readonly maxPageIndex: number;
    /**
     * The read-only property custom page name from the render state's layout model state
     */
    readonly customPageName: string;
    /**
     * The read-only property data entry settings name from the render state's layout model state that represents the name of the currently active data-entry settings
     */
    readonly dataEntrySettingsName: string;
    /**
     * The read-only property data entry settings info from the render state's layout model state that contains all relevant defined data entry settings
     */
    readonly dataEntrySettingsInfo: Nullable<IDataEntrySettingsInfo[]>;
    /**
     * The current data entry settings info from the render state's layout model state as a read-only property
     */
    readonly currentDataEntrySettings: Optional<IDataEntrySettingsInfo>;
    /**
     * The read-only property runtime settings from the render state's layout model state's current data entry settings
     */
    readonly runtimeSettings: Nullable<IRuntimeSettings>;
    /**
     * Flag indicating if the refresh mode of the current runtime settings of the render state's layout model state is set to question
     */
    readonly isRefreshModeQuestion: boolean;
    /**
     * Flag indicating if the optimize-no-style-sheets setting of the current runtime settings of the render state's layout model state is active
     */
    readonly optimizeNoStylesheets: boolean;
    /**
     * Flag indicating if the use skip-links setting of the current runtime settings of the render state's layout model state is active
     */
    readonly useSkipLinks: boolean;
    /**
     * Flag indicating if autofocus is disabled on the current runtime settings of the render state's layout model state
     */
    readonly disableAutoFocus: boolean;
    /**
     * Flag indicating if autofocus event should trigger based on the current runtime settings of the render state's layout model state and the change states of the page index and parallel name
     */
    readonly shouldAutoFocus: boolean;
    /**
     * Flag indicating if the gps functionality is enabled on the current runtime settings of the render state's layout model state
     */
    readonly enableGPS: boolean;
    /**
     * Flag indicating if the high accuracy GPS is activated in the render state's current layout model state's runtime settings
     */
    readonly highGPSAccuracy: boolean;
    /**
     * The read-only property keyboard navigation mode from the render state's layout model state's current data entry settings (`Interviewing`, `DataEditing` or `None`)
     */
    readonly keyboardNavigation: KeyboardNavigation;
    /**
     * Flag indicating if show-fields should be skipped when navigating with a keyboard
     */
    readonly skipShowFieldsAtKeyboardNavigation: boolean;
    /**
     * The read-only property navigation mode from the render state's layout model state's current data entry settings (`Navigation`, `Insert` or `None`)
     */
    readonly navigationMode: NavigationMode;
    /**
     * Flag indicating if the auto-select input content option on the current runtime settings of the render state's layout model state is active
     */
    readonly autoSelectInputContent: boolean;
    /**
     * Flag indicating if css grids should be used on the current runtime settings of the render state's layout model state is active
     */
    readonly useCssGrids: boolean;
    /**
     * The read-only object property page from the render state
     */
    readonly page: Nullable<IPage>;
    /**
     * All fields from the render state's page object
     */
    readonly fields: Nullable<IField[]>;
    /**
     * Retrieves and filters fields from the render state's page object
     * @param {Function} filter (optional) the filter to use. The default filter checks if the field's origin is "Route" and has at least 1 visible input control.
     * @returns {Array<IField>} a list containing fields that succeeded through the filter
     */
    getFilteredFields: (filter?: (field: IField) => boolean) => IField[];
    /**
     * Retrieves a field by name
     * @param {string} fieldName the name of the field to retrieve
     * @returns {Optional<IField>} The retrieved field or undefined
     */
    getFieldByName: (fieldName: string) => Optional<IField>;
    /**
     * Retrieves a field property by name
     * @param {string} fieldName the name of the field for which to retrieve a field property
     * @param {string} fieldPropertyName the name of the field property to retrieve
     * @returns {Optional<IFieldProperty>} The retrieved field property or undefined
     */
    getFieldPropertyByName: (fieldName: string, fieldPropertyName: string) => Optional<IFieldProperty>;
    /**
     * All groups from the render state's page object
     */
    readonly groups: Nullable<IGroup[]>;
    /**
     * Retrieves a group by its name
     * @param {string} groupName the name of the group to retrieve
     * @returns {Optional<IGroup>} The retrieved group or undefined
     */
    getGroupByName: (groupName: string) => Optional<IGroup>;
    /**
     * Retrieves a specific section by its name
     * @param {string} sectionName the name of the section to retrieve
     * @returns {Optional<ISection>} The retrieved section or undefined
     */
    getSectionByName: (sectionName: string) => Optional<ISection>;
    /**
     * Sets the is visited flag of a specified field and its field properties to true
     * @param {string} fieldName
     */
    flagFieldNameAsVisited: (fieldName: string) => void;
    /**
     * Sets the is visited flag of a specified field and its field properties to true
     * @param {IField} field
     */
    flagFieldAsVisited: (field: IField) => void;
    /**
     * Sets the is visited property of all fields with at least 1 visible input control to true
     */
    flagPageAsVisited: () => void;
    /**
     * Retrieves the name of the first field of a group or its subgroups (deep search)
     * @param {string} groupName the name of the group containing the field
     * @returns {Optional<string>} The name of the first found field or null if no field was found
     */
    getFirstFieldNameFromGroup: (groupName: string) => Optional<string>;
    /**
     * Retrieves lookup information from a field by the field's name
     * @param {string} fieldName the name of the field for which to retrieve lookup information
     * @returns {Optional<ILookupInformation>} The retrieved lookup information or undefined
     */
    getLookupInfoForField: (fieldName: string) => Optional<ILookupInformation>;
    /**
     * Retrieves the data source from a field by the field's name
     * @param {string} fieldName the name of the field for which to retrieve the data source
     * @returns {Optional<IDataSource>} The retrieved data source or undefined
     */
    getDataSourceForField: (fieldName: string) => Optional<IDataSource>;
    /**
     * Checks each answered field for errors. If any errors are found, they will be configured for the field and the field will be updated.
     */
    applyPageErrors: () => void;
    /**
     * Flag indicating if the current page has a range check error
     */
    readonly pageHasRangeErrors: boolean;
    /**
     * Retrieves involved fields from the first relevant error of a field.
     * @param {string} fieldName the name of the field for which to retrieve involved fields
     * @param {Array<number>} errorKindFilter list of allowed error kinds for which to retrieve involved fields
     * @returns {Optional<IInvolvedField[]>} an array of involved fields or null if none are found
     */
    getInvolvedFields: (fieldName: string, errorKindFilter: number[]) => Optional<IInvolvedField[]>;
    /**
     * Retrieves involved fields for a specified group
     * @param {string} groupName the name of the group for which to retrieve involved fields
     * @param {boolean} includeGroupErrors
     * @param {Array<number>} errorKindFilter
     * @returns {Optional<Array<IInvolvedField>>} an array of involved fields or undefined if none are found
     */
    getGroupInvolvedFields: (groupName: string, includeGroupErrors: boolean, errorKindFilter: number[]) => Optional<IInvolvedField[]>;
    /**
     * Retrieves involved fields for the current page
     * @param {boolean} includeGroupErrors
     * @param {Array<number>} errorKindFilter
     * @returns {Optional<IInvolvedField[]>} an array of involved fields or undefined if none are found
     */
    getPageInvolvedFields: (includeGroupErrors: boolean, errorKindFilter: number[]) => Optional<IInvolvedField[]>;
    /**
     * Retrieves an error for a specified group
     * @param {string} groupName the name of the group for which to retrieve an error
     * @param {boolean} includeGroupErrors
     * @param {Array<number>} errorKindFilter
     * @returns {Optional<IError>} an error if one was found, otherwise undefined
     */
    getGroupError: (groupName: string, includeGroupErrors: boolean, errorKindFilter: number[]) => Optional<IError>;
    /**
     * Retrieves an error for the current page
     * @param {boolean} includeGroupErrors
     * @param {Array<number>} errorKindFilter
     * @returns {Optional<IError>} an error if one was found, otherwise undefined
     */
    getPageError: (includeGroupErrors: boolean, errorKindFilter: number[]) => Optional<IError>;
    /**
     * Retrieves a route-item with an error for the current page
     * @param {boolean} includeGroupErrors
     * @returns {Optional<IRouteItemReference>}
     */
    getPageErrorAsRouteItem: (includeGroupErrors: boolean) => Optional<IRouteItemReference>;
    /**
     * Retrieves the first relevant error from an array of errors
     * @param {Array<IError>} errors
     * @returns {Optional<IError>>} the first relevant error or undefined if no error relevant was found
     */
    getFirstRelevantError: (errors: IError[]) => Optional<IError>;
    /**
     * Active field from the render state's page fields
     */
    readonly activeField: Optional<IField>;
    /**
     * Active data value subscription from the render state's page fields
     */
    readonly currentActiveField: Optional<IFieldInfo>;
    /**
     * Flag indicating if the current active field is critical
     */
    readonly isCurrentActiveFieldCritical: boolean;
    /**
     * Flag indicating if the current active field is dirty
     */
    readonly isCurrentActiveFieldDirty: boolean;
    /**
     * Flag indicating whether the current custom page name has the receipt page name value
     */
    readonly isLastPage: boolean;
    /**
     * The record error collection from the render state's page object
     */
    readonly recordErrors: Nullable<IError[]>;
    /**
     * Retrieves a field's index from a list of (filtered) fields, using a given field name or the currently active field name (default).
     * @param {Optional<Array<IField>>} fields (optional) field list from which to retrieve an index, the getFilteredFields function result is used when the argument is undefined, null or an empty list.
     * @param {Optional<string>} fieldName (optional) field name for which to retrieve the index from the field list, the current active field name is used if no field name is provided.
     * @returns {number} index of the field in the list or -1 if not found
     */
    getFieldIndexByName: (fields?: IField[], fieldName?: string) => number;
    /**
     * The survey root path from the render state
     */
    readonly surveyRoot: string;
    /**
     * The instrument title set on the render state
     */
    readonly instrumentTitle: string;
    /**
     * the read-only text provider dictionary object property from the render state
     */
    readonly textProvider: IDictionary<ITextBox>;
    /**
     * Retrieves a textbox property value from the text provider dictionary object by id
     * @param {string} textboxId
     * @returns {ITextBox} a text provider text box
     */
    getTextBox: (textboxId: string) => ITextBox;
    /**
     * Sets the textbox property value on the text provider dictionary object
     * @param {string} textboxId id of the textbox for which to set the text
     * @param {string} text to set
     */
    setTextBox: (textboxId: string, text: string) => void;
}
