import { RenderStateService } from './renderstate.service';
import { SecurityService } from './security.service';
import { UserAgentService } from './user-agent.service';
import { IAuditTrailPayload } from '../../typedefinitions/models/server/payload/IAuditTrailPayload';
import { IClassificationPayload } from '../../typedefinitions/models/server/payload/IClassificationPayload';
import { IExecuteActionPayload } from '../../typedefinitions/models/server/payload/IExecuteActionPayload';
import { IFetchLookupPayload } from '../../typedefinitions/models/server/payload/IFetchLookupPayload';
import { IMeasureTimePayload } from '../../typedefinitions/models/server/payload/IMeasureTimePayload';
import { ISelectRecordPayload } from '../../typedefinitions/models/server/payload/ISelectRecordPayload';
import { IStartInterviewPayload } from '../../typedefinitions/models/server/payload/IStartInterviewPayload';
import { IRequestTimeslotsPayload } from '../../typedefinitions/models/server/payload/IRequestTimeslotsPayload';
import { ISetAppointmentPayload } from '../../typedefinitions/models/server/payload/ISetAppointmentPayload';
import { IAuditTrailEvent } from '../../typedefinitions/events/IAuditTrailEvent';
import { IActionKeyValuePair } from '../../typedefinitions/models/IActionKeyValuePair';
import { IAppointmentVariables } from '../../typedefinitions/models/server/IAppointmentVariables';
import { IAuditTrailServerInfo } from '../../typedefinitions/models/server/IAuditTrailServerInfo';
import { IFetchAppointmentListPayload } from '../../typedefinitions/models/server/payload/IFetchAppointmentListPayload';
import { IFetchSurveyListPayload } from '../../typedefinitions/models/server/payload/IFetchSurveyListPayload';
import { ILookupState } from '../../typedefinitions/models/server/ILookupState';
import { IRuntimeParameters } from '../../typedefinitions/models/IRuntimeParameters';
import { IServerParkInfo } from '../../typedefinitions/models/server/IServerParkInfo';
import { IUploadPayload } from '../../typedefinitions/models/server/payload/IUploadPayload';
import * as i0 from "@angular/core";
/**
 * The payload service constructs server payloads for services' http requests
 */
export declare class PayloadService {
    private renderStateService;
    private securityService;
    private userAgentService;
    /**
     * Server park info array where each item contains a server name, port, role and binding info
     */
    serverParkInfo: Nullable<IServerParkInfo[]>;
    /**
     * ParkId
     */
    parkId: Optional<string>;
    /**
     * Encrypted ServerPark Definitions
     */
    esd: Optional<string>;
    /**
     * System web http context current request user host address
     */
    lockId: Nullable<string>;
    /**
     * Time at which the last lock id was set
     */
    lastLockTime: Nullable<string>;
    /**
     * Payload service class constructor
     * @param renderStateService
     * @param securityService
     * @param userAgentService
     */
    constructor(renderStateService: RenderStateService, securityService: SecurityService, userAgentService: UserAgentService);
    /**
     * Creates the execute action request payload
     * @param actions
     * @param controlID
     * @param eventName
     * @param shouldApplyPageEvent
     * @returns execute action request payload
     */
    executeActionPayload(actions: IActionKeyValuePair[], controlID?: string, eventName?: string, shouldApplyPageEvent?: boolean): IExecuteActionPayload;
    /**
     * Creates the classification request payload
     * @param code
     * @param libraryFileName
     * @param typeName
     * @param serverParkInfo
     * @returns classification request payload
     */
    classificationPayload(code: string, libraryFileName: string, typeName: string, serverParkInfo: Nullable<IServerParkInfo>): IClassificationPayload;
    /**
     * Creates the start interview request payload
     * @param runtimeParameters
     * @returns interview request payload
     */
    startInterviewPayload(runtimeParameters: IRuntimeParameters): IStartInterviewPayload;
    /**
     * Creates the fetch lookup request payload
     * @param fieldName
     * @param searchTerm
     * @param maxResultCount
     * @returns fetch lookup request payload
     */
    fetchLookupPayload(fieldName: string, searchTerm: any, maxResultCount?: number): IFetchLookupPayload;
    /**
     * Creates the request time-slots payload
     * @param start Start date
     * @param end End date
     * @param instrumentSelection
     * @param aggregationMode
     * @param interviewerTimeZone
     * @param interviewerTimeIsDST
     * @returns time-slots request payload
     */
    requestTimeSlotsPayload(start: Date, end: Date, instrumentSelection: string, aggregationMode: string, interviewerTimeZone: string, interviewerTimeIsDST: boolean, includeHard: boolean, includeMedium: boolean, includeSoft: boolean): IRequestTimeslotsPayload;
    /**
     * Creates the set appointment payload
     * @param start Start date
     * @param end End date
     * @param appoinmentVariables
     * @returns set appointment payload
     */
    setAppointmentPayload(start: Date, end: Date, appoinmentVariables: IAppointmentVariables): ISetAppointmentPayload;
    /**
     * Creates the select record request payload
     * @param lookupFieldName
     * @param externalFieldNames
     * @param externalFieldValues
     * @param autoEnter
     * @returns select record request payload
     */
    selectRecordPayload(lookupFieldName: string, externalFieldNames: string[], externalFieldValues: any[], autoEnter: boolean): ISelectRecordPayload;
    /**
     * Creates the request search request payload
     * @param lookupState
     * @returns request search request payload
     */
    requestSearchPayload(lookupState: ILookupState): IFetchLookupPayload;
    /**
     * Creates the fetch appointment list request payload
     * @param lookupState
     */
    appointmentListPayload(lookupState: ILookupState): IFetchAppointmentListPayload;
    /**
     * Creates the survey list request payload
     * @param lookupState
     */
    surveyListPayload(lookupState: ILookupState): IFetchSurveyListPayload;
    /**
     * Creates the audit trail request payload
     * @param config
     * @param logEvents
     * @param timestamp the current time timestamp
     * @returns audit trail request payload
     */
    auditTrailPayload(config: Nullable<IAuditTrailServerInfo>, logEvents: IAuditTrailEvent[], timestamp: string): IAuditTrailPayload;
    /**
     * Creates the measure time request payload
     * @param elapsedTime
     * @param totalTime
     * @returns measure time request payload
     */
    measureTimePayload(elapsedTime: number, totalTime: number): IMeasureTimePayload;
    /**
     * Creates the metadata to sent along with a file upload request
     * @param fieldName
     * @param fieldPropertyName (optional)
     */
    uploadPayload(fieldName: string, fieldPropertyName?: string): IUploadPayload;
    /**
     * Extend the payload with the server park information
     */
    private extendParkId;
    static ɵfac: i0.ɵɵFactoryDeclaration<PayloadService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PayloadService>;
}
